@@ -30,7 +30,7 @@
 
 class KArtsServer;
 
-class KDE_EXPORT KPlayObjectFactory
+class TDE_EXPORT KPlayObjectFactory
 {
 public:
 	/**
@@ -76,7 +76,7 @@ class POFHelper;
 	 * use the KDE multimedia framework can be found in the documentation
 	 * for KDE::PlayObject.
 	 */
-class KDE_EXPORT PlayObjectFactory// : public TQObject ### for KDE4 make it a TQObject to be able to receive signals
+class TDE_EXPORT PlayObjectFactory// : public TQObject ### for KDE4 make it a TQObject to be able to receive signals
 {
 public:
 	/**
