@@ -448,7 +448,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
    */
   bool connectDCOPSignal( const TQCString &sender, const TQCString &signal,
                           const TQCString &receiverObj, const TQCString &slot,
-                          bool Volatile) KDE_DEPRECATED;
+                          bool Volatile) TDE_DEPRECATED;
 
   /**
    * Disconnects a DCOP signal.
@@ -476,7 +476,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
    * For backwards compatibility
    */
   bool disconnectDCOPSignal( const TQCString &sender, const TQCString &signal,
-                          const TQCString &receiverObj, const TQCString &slot) KDE_DEPRECATED;
+                          const TQCString &receiverObj, const TQCString &slot) TDE_DEPRECATED;
 
   /**
    * Reimplement this function to handle app-wide function calls unassociated w/an object.
@@ -739,7 +739,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
    * For backwards compatibility with KDE 2.x
    * // KDE4 remove
    */
-  static TQCString dcopServerFileOld(const TQCString &hostname=0) KDE_DEPRECATED;
+  static TQCString dcopServerFileOld(const TQCString &hostname=0) TDE_DEPRECATED;
 
   /**
    * Return the path of iceauth or an empty string if not found.
