@@ -34,7 +34,7 @@
 #include <tdelocale.h>
 #include <kfinddialog.h>
 #include <kreplacedialog.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstaticdeleter.h>
 
 #include <tqpopupmenu.h>
@@ -1155,13 +1155,13 @@ void KateRendererConfig::setSchemaInternal( int schema )
 
     // same std colors like in KateDocument::markColor
   TQColor mark[7];
-  mark[0] = Qt::blue;
-  mark[1] = Qt::red;
-  mark[2] = Qt::yellow;
-  mark[3] = Qt::magenta;
-  mark[4] = Qt::gray;
-  mark[5] = Qt::green;
-  mark[6] = Qt::red;
+  mark[0] = TQt::blue;
+  mark[1] = TQt::red;
+  mark[2] = TQt::yellow;
+  mark[3] = TQt::magenta;
+  mark[4] = TQt::gray;
+  mark[5] = TQt::green;
+  mark[6] = TQt::red;
 
   for (int i = 1; i <= KTextEditor::MarkInterface::reservedMarkersCount(); i++) {
     TQColor col = config->readColorEntry(TQString("Color MarkType%1").arg(i), &mark[i - 1]);
@@ -1425,5 +1425,3 @@ void KateRendererConfig::setShowIndentationLines (bool on)
 }
 
 //END
-
-// kate: space-indent on; indent-width 2; replace-tabs on;
