@@ -27,7 +27,7 @@
 #include "kateschema.h"
 #include "katesearch.h"
 #include "kateconfig.h"
-#ifndef Q_WS_WIN //todo
+#ifndef TQ_WS_WIN //todo
 #include "katejscript.h"
 #endif
 #include "kateluaindentscript.h"
@@ -137,7 +137,7 @@ KateFactory::KateFactory ()
   // vm allocator
   m_vm = new KVMAllocator ();
 
-#ifndef Q_WS_WIN //todo
+#ifndef TQ_WS_WIN //todo
   // create script man (search scripts) + register commands
   m_jscriptManager = new KateJScriptManager ();
   KateCmd::self()->registerCommand (m_jscriptManager);
@@ -251,7 +251,7 @@ void KateFactory::deregisterRenderer ( KateRenderer  *renderer )
 
 KateJScript *KateFactory::jscript ()
 {
-#ifndef Q_WS_WIN //todo
+#ifndef TQ_WS_WIN //todo
   if (m_jscript)
     return m_jscript;
 
