@@ -41,7 +41,7 @@ class TDEActionCollection;
 
 class KateSearch : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   friend class KateDocument;
 
@@ -167,7 +167,7 @@ class KateSearch : public TQObject
  */
 class KateReplacePrompt : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     /**
