@@ -65,15 +65,15 @@ KateScrollBar::KateScrollBar (Orientation orientation, KateViewInternal* parent,
   , m_savVisibleLines(0)
   , m_showMarks(false)
 {
-  connect(this, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(sliderMaybeMoved(int)));
-  connect(m_doc, TQT_SIGNAL(marksChanged()), this, TQT_SLOT(marksChanged()));
+  connect(this, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(sliderMaybeMoved(int)));
+  connect(m_doc, TQ_SIGNAL(marksChanged()), this, TQ_SLOT(marksChanged()));
 
   m_lines.setAutoDelete(true);
 }
 
 void KateScrollBar::mousePressEvent(TQMouseEvent* e)
 {
-  if (e->button() == Qt::MidButton)
+  if (e->button() == TQt::MidButton)
     m_middleMouseDown = true;
 
   TQScrollBar::mousePressEvent(e);
@@ -94,7 +94,7 @@ void KateScrollBar::mouseMoveEvent(TQMouseEvent* e)
 {
   TQScrollBar::mouseMoveEvent(e);
 
-  if (e->state() | Qt::LeftButton)
+  if (e->state() | TQt::LeftButton)
     redrawMarks();
 }
 
@@ -295,8 +295,8 @@ KateCmdLine::KateCmdLine (KateView *view)
   , m_command( 0L )
   , m_oldCompletionObject( 0L )
 {
-  connect (this, TQT_SIGNAL(returnPressed(const TQString &)),
-           this, TQT_SLOT(slotReturnPressed(const TQString &)));
+  connect (this, TQ_SIGNAL(returnPressed(const TQString &)),
+           this, TQ_SLOT(slotReturnPressed(const TQString &)));
 
   completionObject()->insertItems (KateCmd::self()->cmds());
   setAutoDeleteCompletionObject( false );
@@ -375,7 +375,7 @@ void KateCmdLine::slotReturnPressed ( const TQString& text )
   m_cmdend = 0;
 
   m_view->setFocus ();
-  TQTimer::singleShot( 4000, this, TQT_SLOT(hideMe()) );
+  TQTimer::singleShot( 4000, this, TQ_SLOT(hideMe()) );
 }
 
 void KateCmdLine::hideMe () // unless i have focus ;)
@@ -716,7 +716,7 @@ void KateIconBorder::setIconBorderOn( bool enable )
 
   updateGeometry();
 
-  TQTimer::singleShot( 0, this, TQT_SLOT(update()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(update()) );
 }
 
 void KateIconBorder::setLineNumbersOn( bool enable )
@@ -729,7 +729,7 @@ void KateIconBorder::setLineNumbersOn( bool enable )
 
   updateGeometry();
 
-  TQTimer::singleShot( 0, this, TQT_SLOT(update()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(update()) );
 }
 
 void KateIconBorder::setDynWrapIndicators( int state )
@@ -742,7 +742,7 @@ void KateIconBorder::setDynWrapIndicators( int state )
 
   updateGeometry ();
 
-  TQTimer::singleShot( 0, this, TQT_SLOT(update()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(update()) );
 }
 
 void KateIconBorder::setFoldingMarkersOn( bool enable )
@@ -754,7 +754,7 @@ void KateIconBorder::setFoldingMarkersOn( bool enable )
 
   updateGeometry();
 
-  TQTimer::singleShot( 0, this, TQT_SLOT(update()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(update()) );
 }
 
 TQSize KateIconBorder::sizeHint() const
@@ -953,7 +953,7 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
       if (realLine > -1)
         if (m_viewInternal->lineRanges[z].startCol == 0) {
           if (m_lineNumbersOn)
-            p.drawText( lnX + 1, y, lnWidth-4, h, Qt::AlignRight|Qt::AlignVCenter, TQString("%1").arg( realLine + 1 ) );
+            p.drawText( lnX + 1, y, lnWidth-4, h, TQt::AlignRight|TQt::AlignVCenter, TQString("%1").arg( realLine + 1 ) );
         } else if (m_view->dynWordWrap() && m_dynWrapIndicatorsOn) {
           p.drawPixmap(lnX + lnWidth - m_arrow.width() - 4, y, m_arrow);
         }
@@ -1069,7 +1069,7 @@ void KateIconBorder::mouseReleaseEvent( TQMouseEvent* e )
   {
     BorderArea area = positionToArea( e->pos() );
     if( area == IconBorder) {
-      if (e->button() == Qt::LeftButton) {
+      if (e->button() == TQt::LeftButton) {
         if( m_doc->editableMarks() & KateViewConfig::global()->defaultMarkType() ) {
           if( m_doc->mark( cursorOnLine ) & KateViewConfig::global()->defaultMarkType() )
             m_doc->removeMark( cursorOnLine, KateViewConfig::global()->defaultMarkType() );
@@ -1080,7 +1080,7 @@ void KateIconBorder::mouseReleaseEvent( TQMouseEvent* e )
           }
         }
         else
-        if (e->button() == Qt::RightButton) {
+        if (e->button() == TQt::RightButton) {
           showMarkMenu( cursorOnLine, TQCursor::pos() );
         }
     }
@@ -1170,7 +1170,7 @@ void KateIconBorder::showMarkMenu( uint line, const TQPoint& pos )
 KateViewEncodingAction::KateViewEncodingAction(KateDocument *_doc, KateView *_view, const TQString& text, TQObject* parent, const char* name)
        : TDEActionMenu (text, parent, name), doc(_doc), view (_view)
 {
-  connect(popupMenu(),TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(slotAboutToShow()));
+  connect(popupMenu(),TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(slotAboutToShow()));
 }
 
 void KateViewEncodingAction::slotAboutToShow()
@@ -1180,7 +1180,7 @@ void KateViewEncodingAction::slotAboutToShow()
   popupMenu()->clear ();
   for (uint z=0; z<modes.size(); ++z)
   {
-    popupMenu()->insertItem ( modes[z], this, TQT_SLOT(setMode(int)), 0,  z);
+    popupMenu()->insertItem ( modes[z], this, TQ_SLOT(setMode(int)), 0,  z);
 
     bool found = false;
     TQTextCodec *codecForEnc = TDEGlobal::charsets()->codecForName(TDEGlobal::charsets()->encodingForName(modes[z]), found);
