@@ -76,7 +76,7 @@ KDataToolPluginView::KDataToolPluginView( KTextEditor::View *view )
 	setInstance( KGenericFactory<KDataToolPlugin>::instance() );
 
 	m_menu = new TDEActionMenu(i18n("Data Tools"), actionCollection(), "popup_dataTool");
-	connect(m_menu->popupMenu(), TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(aboutToShow()));
+	connect(m_menu->popupMenu(), TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(aboutToShow()));
 	setXMLFile("tdetexteditor_kdatatoolui.rc");
 
 	m_view = view;
@@ -151,7 +151,7 @@ void KDataToolPluginView::aboutToShow()
 			m_singleWord_line = line;
 		} else {
 			m_notAvailable = new TDEAction(i18n("(not available)"), TQString::null, 0, this, 
-					TQT_SLOT(slotNotAvailable()), actionCollection(),"dt_n_av");
+					TQ_SLOT(slotNotAvailable()), actionCollection(),"dt_n_av");
 			m_menu->insert(m_notAvailable);
 			return;
 		}
@@ -165,7 +165,7 @@ void KDataToolPluginView::aboutToShow()
 		tools += KDataToolInfo::query( "TQString", "application/x-singleword", inst );
 
 	m_actionList = KDataToolAction::dataToolActionList( tools, this,
-		TQT_SLOT( slotToolActivated( const KDataToolInfo &, const TQString & ) ) );
+		TQ_SLOT( slotToolActivated( const KDataToolInfo &, const TQString & ) ) );
 
 	for ( ac = m_actionList.first(); ac; ac = m_actionList.next() ) {
 		m_menu->insert(ac);
@@ -173,7 +173,7 @@ void KDataToolPluginView::aboutToShow()
 
 	if( m_actionList.isEmpty() ) {
 		m_notAvailable = new TDEAction(i18n("(not available)"), TQString::null, 0, this,
-			TQT_SLOT(slotNotAvailable()), actionCollection(),"dt_n_av");
+			TQ_SLOT(slotNotAvailable()), actionCollection(),"dt_n_av");
 		m_menu->insert(m_notAvailable);
 	}
 }
