@@ -180,7 +180,7 @@ void LdapConfigWidget::initWidget()
     //without host query doesn't make sense
     if ( mHost ) {
       TQPushButton *dnquery = new TQPushButton( i18n( "Query Server" ), this );
-      connect( dnquery, TQT_SIGNAL( clicked() ), TQT_SLOT( mQueryDNClicked() ) );
+      connect( dnquery, TQ_SIGNAL( clicked() ), TQ_SLOT( mQueryDNClicked() ) );
       mainLayout->addMultiCellWidget( dnquery, row, row, 2, 3 );
     }
     row++;
@@ -202,9 +202,9 @@ void LdapConfigWidget::initWidget()
     mSecSSL = new TQRadioButton( i18n( "SSL" ), btgroup, "kcfg_ldapssl" );
     mainLayout->addMultiCellWidget( btgroup, row, row, 0, 3 );
 
-    connect( mSecNO, TQT_SIGNAL( clicked() ), TQT_SLOT( setLDAPPort() ) );
-    connect( mSecTLS, TQT_SIGNAL( clicked() ), TQT_SLOT( setLDAPPort() ) );
-    connect( mSecSSL, TQT_SIGNAL( clicked() ), TQT_SLOT( setLDAPSPort( ) ) );
+    connect( mSecNO, TQ_SIGNAL( clicked() ), TQ_SLOT( setLDAPPort() ) );
+    connect( mSecTLS, TQ_SIGNAL( clicked() ), TQ_SLOT( setLDAPPort() ) );
+    connect( mSecSSL, TQ_SIGNAL( clicked() ), TQ_SLOT( setLDAPSPort( ) ) );
 
     mSecNO->setChecked( true );
     row++;
@@ -213,7 +213,7 @@ void LdapConfigWidget::initWidget()
   if ( mFlags & W_AUTHBOX ) {
 
     TQButtonGroup *authbox =
-      new TQButtonGroup( 3, Qt::Horizontal, i18n( "Authentication" ), this );
+      new TQButtonGroup( 3, TQt::Horizontal, i18n( "Authentication" ), this );
 
     mAnonymous = new TQRadioButton( i18n( "Anonymous" ), authbox, "kcfg_ldapanon" );
     mSimple = new TQRadioButton( i18n( "Simple" ), authbox, "kcfg_ldapsimple" );
@@ -229,14 +229,14 @@ void LdapConfigWidget::initWidget()
     //without host query doesn't make sense
     if ( mHost ) {
       mQueryMech = new TQPushButton( i18n( "Query Server" ), authbox );
-      connect( mQueryMech, TQT_SIGNAL( clicked() ), TQT_SLOT( mQueryMechClicked() ) );
+      connect( mQueryMech, TQ_SIGNAL( clicked() ), TQ_SLOT( mQueryMechClicked() ) );
     }
 
     mainLayout->addMultiCellWidget( authbox, row, row+1, 0, 3 );
 
-    connect( mAnonymous, TQT_SIGNAL( stateChanged(int) ), TQT_SLOT( setAnonymous(int) ) );
-    connect( mSimple, TQT_SIGNAL( stateChanged(int) ), TQT_SLOT( setSimple(int) ) );
-    connect( mSASL, TQT_SIGNAL( stateChanged(int) ), TQT_SLOT( setSASL(int) ) );
+    connect( mAnonymous, TQ_SIGNAL( stateChanged(int) ), TQ_SLOT( setAnonymous(int) ) );
+    connect( mSimple, TQ_SIGNAL( stateChanged(int) ), TQ_SLOT( setSimple(int) ) );
+    connect( mSASL, TQ_SIGNAL( stateChanged(int) ), TQ_SLOT( setSASL(int) ) );
 
     mAnonymous->setChecked( true );
   }
@@ -293,10 +293,10 @@ void LdapConfigWidget::sendQuery()
   mLdif.startParsing();
   TDEIO::Job *job = TDEIO::get( _url, true, false );
   job->addMetaData("no-auth-prompt","true");
-  connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-    this, TQT_SLOT( loadData( TDEIO::Job*, const TQByteArray& ) ) );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-    this, TQT_SLOT( loadResult( TDEIO::Job* ) ) );
+  connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+    this, TQ_SLOT( loadData( TDEIO::Job*, const TQByteArray& ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+    this, TQ_SLOT( loadResult( TDEIO::Job* ) ) );
 
   if ( mProg == NULL )
     mProg = new KProgressDialog( this, 0, i18n("LDAP Query"), _url.prettyURL(), true );
