@@ -173,10 +173,10 @@ TQString ResourceLDAPTDEIO::findUid( const TQString &uid )
   
   TDEIO::ListJob * listJob = TDEIO::listDir( url, false /* no GUI */ );
   connect( listJob, 
-    TQT_SIGNAL( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ),
-    TQT_SLOT( entries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ) );
-  connect( listJob, TQT_SIGNAL( result( TDEIO::Job* ) ), 
-    this, TQT_SLOT( listResult( TDEIO::Job* ) ) );
+    TQ_SIGNAL( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ),
+    TQ_SLOT( entries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ) );
+  connect( listJob, TQ_SIGNAL( result( TDEIO::Job* ) ), 
+    this, TQ_SLOT( listResult( TDEIO::Job* ) ) );
 
   enter_loop();
   return d->mResultDn;
@@ -511,8 +511,8 @@ TDEIO::Job *ResourceLDAPTDEIO::loadFromCache()
   
     KURL url( d->mCacheDst );
     job = TDEIO::get( url, true, false );
-    connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-      this, TQT_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
+    connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+      this, TQ_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
   }
   return job;
 }
@@ -535,17 +535,17 @@ bool ResourceLDAPTDEIO::load()
   createCache();
   if ( d->mCachePolicy != Cache_Always ) {
     job = TDEIO::get( d->mLDAPUrl, true, false );
-    connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-      this, TQT_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-      this, TQT_SLOT( syncLoadSaveResult( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+      this, TQ_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+      this, TQ_SLOT( syncLoadSaveResult( TDEIO::Job* ) ) );
     enter_loop();
   }
 
   job = loadFromCache();    
   if ( job ) {
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-      this, TQT_SLOT( syncLoadSaveResult( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+      this, TQ_SLOT( syncLoadSaveResult( TDEIO::Job* ) ) );
     enter_loop();
   }
   if ( mErrorMsg.isEmpty() ) {
@@ -572,10 +572,10 @@ bool ResourceLDAPTDEIO::asyncLoad()
   createCache();
   if ( d->mCachePolicy != Cache_Always ) {
     TDEIO::Job *job = TDEIO::get( d->mLDAPUrl, true, false );
-    connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-      this, TQT_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-      this, TQT_SLOT( result( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+      this, TQ_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+      this, TQ_SLOT( result( TDEIO::Job* ) ) );
   } else {
     result( NULL );
   }
@@ -714,8 +714,8 @@ void ResourceLDAPTDEIO::result( TDEIO::Job *job )
   TDEIO::Job *cjob;
   cjob = loadFromCache();
   if ( cjob ) {
-    connect( cjob, TQT_SIGNAL( result( TDEIO::Job* ) ),
-      this, TQT_SLOT( loadCacheResult( TDEIO::Job* ) ) );
+    connect( cjob, TQ_SIGNAL( result( TDEIO::Job* ) ),
+      this, TQ_SLOT( loadCacheResult( TDEIO::Job* ) ) );
   } else {
     if ( !mErrorMsg.isEmpty() )
       emit loadingError( this, mErrorMsg );
@@ -730,10 +730,10 @@ bool ResourceLDAPTDEIO::save( Ticket* )
   
   d->mSaveIt = begin();
   TDEIO::Job *job = TDEIO::put( d->mLDAPUrl, -1, true, false, false );
-  connect( job, TQT_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ),
-    this, TQT_SLOT( saveData( TDEIO::Job*, TQByteArray& ) ) );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-    this, TQT_SLOT( syncLoadSaveResult( TDEIO::Job* ) ) );
+  connect( job, TQ_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ),
+    this, TQ_SLOT( saveData( TDEIO::Job*, TQByteArray& ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+    this, TQ_SLOT( syncLoadSaveResult( TDEIO::Job* ) ) );
   enter_loop();
   if ( mErrorMsg.isEmpty() ) {
     kdDebug(7125) << "ResourceLDAPTDEIO save ok!" << endl; 
@@ -750,10 +750,10 @@ bool ResourceLDAPTDEIO::asyncSave( Ticket* )
   kdDebug(7125) << "ResourceLDAPTDEIO asyncSave" << endl;
   d->mSaveIt = begin();
   TDEIO::Job *job = TDEIO::put( d->mLDAPUrl, -1, true, false, false );
-  connect( job, TQT_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ),
-    this, TQT_SLOT( saveData( TDEIO::Job*, TQByteArray& ) ) );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-    this, TQT_SLOT( saveResult( TDEIO::Job* ) ) );
+  connect( job, TQ_SIGNAL( dataReq( TDEIO::Job*, TQByteArray& ) ),
+    this, TQ_SLOT( saveData( TDEIO::Job*, TQByteArray& ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+    this, TQ_SLOT( saveResult( TDEIO::Job* ) ) );
   return true;
 }
 
