@@ -25,7 +25,7 @@ using namespace TDEABC;
 
 extern "C"
 {
-  KDE_EXPORT void *init_tdeabc_net()
+  TDE_EXPORT void *init_tdeabc_net()
   {
     return new KRES::PluginFactory<ResourceNet, ResourceNetConfig>();
   }
