@@ -21,7 +21,7 @@
 
 #include "tdecertpart.h"
 #include <tdeparts/genericfactory.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaboutdata.h>
 #include <tqframe.h>
 #include <tdelocale.h>
@@ -169,7 +169,7 @@ _baseGrid->addMultiCellWidget(_sideList, 0, 13, 0, 1);
 
 _importAll = new TQPushButton(i18n("Import &All"), _frame);
 _baseGrid->addMultiCellWidget(_importAll, 14, 14, 0, 1);
-connect(_importAll, TQT_SIGNAL(clicked()), TQT_SLOT(slotImportAll()));
+connect(_importAll, TQ_SIGNAL(clicked()), TQ_SLOT(slotImportAll()));
 
 
 
@@ -184,7 +184,7 @@ grid->addMultiCellWidget(new TQLabel(i18n("TDE Secure Certificate Import"), _pkc
 grid->addWidget(new TQLabel(i18n("Chain:"), _pkcsFrame), 1, 0);
 _p12_chain = new KComboBox(_pkcsFrame);
 grid->addMultiCellWidget(_p12_chain, 1, 1, 1, 4);
-connect(_p12_chain, TQT_SIGNAL(activated(int)), TQT_SLOT(slotChain(int)));
+connect(_p12_chain, TQ_SIGNAL(activated(int)), TQ_SLOT(slotChain(int)));
 
 grid->addWidget(new TQLabel(i18n("Subject:"), _pkcsFrame), 2, 0);
 grid->addWidget(new TQLabel(i18n("Issued by:"), _pkcsFrame), 2, 3);
@@ -373,10 +373,10 @@ _baseGrid->addMultiCellWidget(_launch, 14, 14, 4, 5);
 _baseGrid->addWidget(_import, 14, 6);
 _baseGrid->addWidget(_save, 14, 7);
 _baseGrid->addWidget(_done, 14, 8);
-connect(_launch, TQT_SIGNAL(clicked()), TQT_SLOT(slotLaunch()));
-connect(_import, TQT_SIGNAL(clicked()), TQT_SLOT(slotImport()));
-connect(_save, TQT_SIGNAL(clicked()), TQT_SLOT(slotSave()));
-connect(_done, TQT_SIGNAL(clicked()), TQT_SLOT(slotDone()));
+connect(_launch, TQ_SIGNAL(clicked()), TQ_SLOT(slotLaunch()));
+connect(_import, TQ_SIGNAL(clicked()), TQ_SLOT(slotImport()));
+connect(_save, TQ_SIGNAL(clicked()), TQ_SLOT(slotSave()));
+connect(_done, TQ_SIGNAL(clicked()), TQ_SLOT(slotDone()));
 _import->setEnabled(false);
 _save->setEnabled(false);
 
@@ -386,8 +386,8 @@ _baseGrid->addMultiCellWidget(_pkcsFrame, 0, 12, 2, 8);
 _baseGrid->addMultiCellWidget(_x509Frame, 0, 12, 2, 8);
 _baseGrid->addMultiCellWidget(_blankFrame, 0, 12, 2, 8);
 
-connect(_sideList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-		this, TQT_SLOT(slotSelectionChanged(TQListViewItem*)));
+connect(_sideList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+		this, TQ_SLOT(slotSelectionChanged(TQListViewItem*)));
 setReadWrite(true);
 }
 
@@ -482,7 +482,7 @@ emit completed();
 //       x-pkcs12 loading
 /////////////////////////////////////////////////////////////////////////////
 if (whatType == "application/x-pkcs12") {
-	TQCString pass;
+	TQString pass;
 	_p12 = KSSLPKCS12::loadCertFile(m_file);
 
 	while (!_p12) {
@@ -490,7 +490,7 @@ if (whatType == "application/x-pkcs12") {
 		int rc = KPasswordDialog::getPassword(pass, i18n("Certificate Password"));
 		if (rc != KPasswordDialog::Accepted) break;
 
-		_p12 = KSSLPKCS12::loadCertFile(m_file, TQString(pass));
+		_p12 = KSSLPKCS12::loadCertFile(m_file, pass);
 
 		if (!_p12) {
 			rc = KMessageBox::warningContinueCancel(_frame, i18n("The certificate file could not be loaded. Try a different password?"), i18n("Certificate Import"),i18n("Try Different"));
@@ -629,7 +629,7 @@ void KCertPart::displayCACert(KSSLCertificate *c) {
 
 	// Set the valid period
 	TQPalette cspl = _ca_validFrom->palette();
-	if (TQDateTime::currentDateTime() < c->getQDTNotBefore()) {
+	if (TQDateTime::currentDateTime(TQt::UTC) < c->getQDTNotBefore()) {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
 	} else {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -638,7 +638,7 @@ void KCertPart::displayCACert(KSSLCertificate *c) {
 	_ca_validFrom->setText(c->getNotBefore());
 
 	cspl = _ca_validUntil->palette();
-	if (TQDateTime::currentDateTime() > c->getQDTNotAfter()) {
+	if (TQDateTime::currentDateTime(TQt::UTC) > c->getQDTNotAfter()) {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
 	} else {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -670,7 +670,7 @@ void KCertPart::displayPKCS12Cert(KSSLCertificate *c) {
 
 	// Set the valid period
 	TQPalette cspl = _p12_validFrom->palette();
-	if (TQDateTime::currentDateTime() < c->getQDTNotBefore()) {
+	if (TQDateTime::currentDateTime(TQt::UTC) < c->getQDTNotBefore()) {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
 	} else {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
@@ -679,7 +679,7 @@ void KCertPart::displayPKCS12Cert(KSSLCertificate *c) {
 	_p12_validFrom->setText(c->getNotBefore());
 
 	cspl = _p12_validUntil->palette();
-	if (TQDateTime::currentDateTime() > c->getQDTNotAfter()) {
+	if (TQDateTime::currentDateTime(TQt::UTC) > c->getQDTNotAfter()) {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(196,33,21));
 	} else {
 		cspl.setColor(TQColorGroup::Foreground, TQColor(42,153,59));
