@@ -18,7 +18,7 @@
 
 #ifdef MAKE_TDECORE_LIB //needed for proper linkage (win32)
 #undef TDEIO_EXPORT
-#define TDEIO_EXPORT KDE_EXPORT
+#define TDEIO_EXPORT TDE_EXPORT
 #endif
 
 #define KPROTOCOLINFO_TDECORE
