@@ -30,11 +30,6 @@
 #define __svr4__
 #endif
 
-#ifdef __osf__
-#define _OSF_SOURCE
-#include <float.h>
-#endif
-
 #ifdef _AIX
 #define _ALL_SOURCE
 #endif
@@ -91,11 +86,9 @@ extern "C" {
 }
 #endif
 
-#if !defined(__osf__)
-# ifdef HAVE_TERMIO_H
+#ifdef HAVE_TERMIO_H
 /* needed at least on AIX */
-#  include <termio.h>
-# endif
+# include <termio.h>
 #endif
 
 #if defined(HAVE_TCGETATTR)
