@@ -92,20 +92,20 @@ public:
      * Constructs a TDESocket with the provided file descriptor.
      * @param _sock	The file descriptor to use.
      */
-    TDESocket( int _sock ) KDE_DEPRECATED;
+    TDESocket( int _sock ) TDE_DEPRECATED;
     /**
      * Creates a socket and connects to a host.
      * @param _host	The remote host to which to connect.
      * @param _port	The port on the remote host.
      * @param timeOut	The number of seconds waiting for connect (default 30).
      */
-    TDESocket( const char *_host, unsigned short int _port, int timeOut = 30) KDE_DEPRECATED;
+    TDESocket( const char *_host, unsigned short int _port, int timeOut = 30) TDE_DEPRECATED;
 
     /**
      * Connects to a UNIX domain socket.
      * @param _path    The filename of the socket.
      */
-    TDESocket( const char * _path ) KDE_DEPRECATED;
+    TDESocket( const char * _path ) TDE_DEPRECATED;
 
     /**
      * Destructor. Closes the socket if it is still open.
@@ -150,7 +150,7 @@ public:
      * instead
      * @deprecated
      */
-    unsigned long ipv4_addr() KDE_DEPRECATED;
+    unsigned long ipv4_addr() TDE_DEPRECATED;
 
     // BCI: remove in libtdecore.so.4
     /**
@@ -158,7 +158,7 @@ public:
       *  Don't use this in new programs. Use KExtendedSocket::lookup
       *  @deprecated
       */
-    static bool initSockaddr(ksockaddr_in *server_name, const char *hostname, unsigned short int port, int domain = PF_INET) KDE_DEPRECATED;
+    static bool initSockaddr(ksockaddr_in *server_name, const char *hostname, unsigned short int port, int domain = PF_INET) TDE_DEPRECATED;
 #endif
 
 signals:
@@ -280,7 +280,7 @@ public:
      * On error the socket will be closed.
      * @param suppressFailureMessages suppress warning messages generated if the socket cannot be opened.
      * @return true on success. false on error.
-     * @warning If suppressFailureMessages is TRUE future debugging may be made more difficult.  Only set it
+     * @warning If suppressFailureMessages is true future debugging may be made more difficult.  Only set it
      * if your application expects to bind to unavailable ports, e.g. while scanning for open ports in a range.
      */
     bool bindAndListen(bool suppressFailureMessages = false);
@@ -340,7 +340,7 @@ protected:
 private:
     // HACK
 #ifdef TDESOCKET_BINARY_COMPAT_HACK
-    KDE_EXPORT bool bindAndListen();
+    TDE_EXPORT bool bindAndListen();
 #endif // TDESOCKET_BINARY_COMPAT_HACK
 
     TDEServerSocket(const TDEServerSocket&);
