@@ -52,11 +52,11 @@ KDatagramSocket::KDatagramSocket(TQObject* parent, const char *name)
 
   localResolver().setFlags(KResolver::Passive);
 
-  //  TQObject::connect(localResolver(), TQT_SIGNAL(finished(KResolverResults)),
-  //		   this, TQT_SLOT(lookupFinishedLocal()));
-  TQObject::connect(&peerResolver(), TQT_SIGNAL(finished(KResolverResults)),
-  		   this, TQT_SLOT(lookupFinishedPeer()));
-  TQObject::connect(this, TQT_SIGNAL(hostFound()), this, TQT_SLOT(lookupFinishedLocal()));
+  //  TQObject::connect(localResolver(), TQ_SIGNAL(finished(KResolverResults)),
+  //		   this, TQ_SLOT(lookupFinishedLocal()));
+  TQObject::connect(&peerResolver(), TQ_SIGNAL(finished(KResolverResults)),
+  		   this, TQ_SLOT(lookupFinishedPeer()));
+  TQObject::connect(this, TQ_SIGNAL(hostFound()), this, TQ_SLOT(lookupFinishedLocal()));
 }
 
 KDatagramSocket::~KDatagramSocket()
@@ -156,7 +156,7 @@ KDatagramPacket KDatagramSocket::receive()
   TDESocketAddress address;
   
   // now do the reading
-  size = tqreadBlock(data.data(), size, address);
+  size = readBlock(data.data(), size, address);
   if (size < 0)
     // error has been set
     return KDatagramPacket();
@@ -167,10 +167,10 @@ KDatagramPacket KDatagramSocket::receive()
 
 TQ_LONG KDatagramSocket::send(const KDatagramPacket& packet)
 {
-  return tqwriteBlock(packet.data(), packet.size(), packet.address());
+  return writeBlock(packet.data(), packet.size(), packet.address());
 }
 
-TQ_LONG KDatagramSocket::tqwriteBlock(const char *data, TQ_ULONG len, const TDESocketAddress& to)
+TQ_LONG KDatagramSocket::writeBlock(const char *data, TQ_ULONG len, const TDESocketAddress& to)
 {
   if (to.family() != AF_UNSPEC)
     {
@@ -179,7 +179,7 @@ TQ_LONG KDatagramSocket::tqwriteBlock(const char *data, TQ_ULONG len, const TDES
 	// error handling will happen below
 	socketDevice()->create(to.family(), SOCK_DGRAM, 0);
     }
-  return KClientSocketBase::tqwriteBlock(data, len, to);
+  return KClientSocketBase::writeBlock(data, len, to);
 }
 
 void KDatagramSocket::lookupFinishedLocal()
@@ -265,7 +265,7 @@ void KDatagramSocket::setupSignals()
   if (n)
     {
       n->setEnabled(emitsReadyRead());
-      TQObject::connect(n, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotReadActivity()));
+      TQObject::connect(n, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotReadActivity()));
     }
   else
     return;
@@ -274,7 +274,7 @@ void KDatagramSocket::setupSignals()
   if (n)
     {
       n->setEnabled(emitsReadyWrite());
-      TQObject::connect(n, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotWriteActivity()));
+      TQObject::connect(n, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotWriteActivity()));
     }
   else
     return;
