@@ -74,9 +74,9 @@ class TDEAccelPrivate;
  * // Insert an action "Scroll Up" which is associated with the "Up" key:
  * pAccel->insert( "Scroll Up", i18n("Scroll up"),
  *                       i18n("Scroll up the current document by one line."),
- *                       Qt::Key_Up, this, TQT_SLOT(slotScrollUp()) );
+ *                       TQt::Key_Up, this, TQ_SLOT(slotScrollUp()) );
  * // Insert an standard acclerator action.
- * pAccel->insert( TDEStdAccel::Print, this, TQT_SLOT(slotPrint()) );
+ * pAccel->insert( TDEStdAccel::Print, this, TQ_SLOT(slotPrint()) );
  *
  * // Update the shortcuts by read any user-defined settings from the
  * // application's config file.
@@ -159,7 +159,7 @@ class TDECORE_EXPORT TDEAccel : public TQAccel
 	 * insert( "Do Something", i18n("Do Something"),
 	 *   i18n("This action allows you to do something really great with this program to "
 	 *        "the currently open document."),
-	 *   ALT+Key_D, this, TQT_SLOT(slotDoSomething()) );
+	 *   ALT+Key_D, this, TQ_SLOT(slotDoSomething()) );
 	 *\endcode
 	 *
 	 * @param sAction The internal name of the action.
@@ -191,7 +191,7 @@ class TDECORE_EXPORT TDEAccel : public TQAccel
 	 *
 	 * Usage:
 	 * \code
-	 * insert( i18n("Do Something"), ALT+Key_D, this, TQT_SLOT(slotDoSomething()) );
+	 * insert( i18n("Do Something"), ALT+Key_D, this, TQ_SLOT(slotDoSomething()) );
 	 * \endcode
 	 *
 	 * @param psAction The name AND label of the action.
@@ -319,47 +319,47 @@ class TDECORE_EXPORT TDEAccel : public TQAccel
 	 */
 	bool insertItem( const TQString& sLabel, const TQString& sAction,
 	                 const char* psKey,
-	                 int nIDMenu = 0, TQPopupMenu* pMenu = 0, bool bConfigurable = true ) KDE_DEPRECATED;
+	                 int nIDMenu = 0, TQPopupMenu* pMenu = 0, bool bConfigurable = true ) TDE_DEPRECATED;
 	/**
 	 * @deprecated use insert
 	 */
 	bool insertItem( const TQString& sLabel, const TQString& sAction,
 	                 int key,
-	                 int nIDMenu = 0, TQPopupMenu* pMenu = 0, bool bConfigurable = true ) KDE_DEPRECATED;
+	                 int nIDMenu = 0, TQPopupMenu* pMenu = 0, bool bConfigurable = true ) TDE_DEPRECATED;
 	/**
 	 * @deprecated use insert
 	 */
-	bool insertStdItem( TDEStdAccel::StdAccel id, const TQString& descr = TQString::null ) KDE_DEPRECATED;
+	bool insertStdItem( TDEStdAccel::StdAccel id, const TQString& descr = TQString::null ) TDE_DEPRECATED;
 	/**
 	 * @deprecated use insert
 	 */
-	bool connectItem( const TQString& sAction, const TQObject* pObjSlot, const char* psMethodSlot, bool bActivate = true ) KDE_DEPRECATED;
+	bool connectItem( const TQString& sAction, const TQObject* pObjSlot, const char* psMethodSlot, bool bActivate = true ) TDE_DEPRECATED;
 	/**
 	 * @deprecated use insert( accel, pObjSlot, psMethodSlot );
 	 *
 	 */
-	KDE_DEPRECATED bool connectItem( TDEStdAccel::StdAccel accel, const TQObject* pObjSlot, const char* psMethodSlot )
+	TDE_DEPRECATED bool connectItem( TDEStdAccel::StdAccel accel, const TQObject* pObjSlot, const char* psMethodSlot )
 		{ return insert( accel, pObjSlot, psMethodSlot ); }
 	/**
 	 * @deprecated use remove
 	 */
-	bool removeItem( const TQString& sAction ) KDE_DEPRECATED;
+	bool removeItem( const TQString& sAction ) TDE_DEPRECATED;
 	/**
 	 * @deprecated
 	 */
-	bool setItemEnabled( const TQString& sAction, bool bEnable ) KDE_DEPRECATED;
+	bool setItemEnabled( const TQString& sAction, bool bEnable ) TDE_DEPRECATED;
 	/**
 	 * @deprecated see KDE3PORTING.html
 	 */
-	void changeMenuAccel( TQPopupMenu *menu, int id, const TQString& action ) KDE_DEPRECATED;
+	void changeMenuAccel( TQPopupMenu *menu, int id, const TQString& action ) TDE_DEPRECATED;
 	/**
 	 * @deprecated see KDE3PORTING.html
 	 */
-	void changeMenuAccel( TQPopupMenu *menu, int id, TDEStdAccel::StdAccel accel ) KDE_DEPRECATED;
+	void changeMenuAccel( TQPopupMenu *menu, int id, TDEStdAccel::StdAccel accel ) TDE_DEPRECATED;
 	/**
 	 * @deprecated
 	 */
-	static int stringToKey( const TQString& ) KDE_DEPRECATED;
+	static int stringToKey( const TQString& ) TDE_DEPRECATED;
 
 	/**
 	 * @deprecated  Use shortcut().
@@ -368,7 +368,7 @@ class TDECORE_EXPORT TDEAccel : public TQAccel
 	 * @p action, or zero if either the action name cannot be
 	 * found or the current key is set to no key.
 	 */
-	int currentKey( const TQString& action ) const KDE_DEPRECATED;
+	int currentKey( const TQString& action ) const TDE_DEPRECATED;
 
 	/**
 	 * @deprecated  Use actions().actionPtr().
@@ -376,7 +376,7 @@ class TDECORE_EXPORT TDEAccel : public TQAccel
 	 * Return the name of the accelerator item with the keycode @p key,
 	 * or TQString::null if the item cannot be found.
 	 */
-	TQString findKey( int key ) const KDE_DEPRECATED;
+	TQString findKey( int key ) const TDE_DEPRECATED;
 #endif // !KDE_NO_COMPAT
 
  protected:
