@@ -38,7 +38,7 @@ class TDECORE_EXPORT TDEAccelPrivate : public TQObject, public TDEAccelBase
 	void menuItemActivated(TDEAccelAction*);
 
  private:
-#ifndef Q_WS_WIN /** @todo TEMP: new implementation (commit #424926) didn't work */
+#ifndef TQ_WS_WIN /** @todo TEMP: new implementation (commit #424926) didn't work */
 	void emitActivatedSignal(TDEAccelAction*);
 #endif
 
