@@ -20,7 +20,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
 #include "test4.h"
-#include "kinstance.h"
+#include "tdeinstance.h"
 
 int main( int, char*[] )
 {
