@@ -21,7 +21,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "test8a.h"
 #include "test8b.h"
-#include "kinstance.h"
+#include "tdeinstance.h"
 
 int main( int, char*[] )
 {
