@@ -25,9 +25,9 @@
 
 #include <tqpixmap.h>
 #include <tqtimer.h>
-#include <ntqthread.h>
-#include <ntqeventloop.h>
-#include <ntqapplication.h>
+#include <tqthread.h>
+#include <tqeventloop.h>
+#include <tqapplication.h>
 
 #include "tdeglobal.h"
 #include "tdelocale.h"
