@@ -45,7 +45,7 @@
 #include <tdelocale.h>
 #include <dcopclient.h>
 #include <dcopref.h>
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <tdestartupinfo.h>
 #include <kxerrorhandler.h>
 
@@ -103,7 +103,7 @@ static void twin_net_create_atoms() {
 /*
   Sends a client message to the ROOT window.
  */
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 static void sendClientMessageToRoot(Window w, Atom a, long x, long y = 0, long z = 0 ){
   XEvent ev;
   long mask;
@@ -124,7 +124,7 @@ static void sendClientMessageToRoot(Window w, Atom a, long x, long y = 0, long z
 /*
   Send a client message to window w
  */
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 static void sendClientMessage(Window w, Atom a, long x){
   XEvent ev;
   long mask;
@@ -145,7 +145,7 @@ static void sendClientMessage(Window w, Atom a, long x){
 
 bool KWin::compositingActive()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     twin_net_create_atoms();
     return XGetSelectionOwner( tqt_xdisplay(), net_wm_cm ) != None;
 #else
@@ -153,7 +153,7 @@ bool KWin::compositingActive()
 #endif
 }
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 namespace
 {
 class ContextWidget : public TQWidget
@@ -213,14 +213,14 @@ bool ContextWidget::x11Event( XEvent * ev)
 
 void KWin::invokeContextHelp()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     ContextWidget w;
 #endif
 }
 
 void KWin::setSystemTrayWindowFor( WId trayWin, WId forWin )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), trayWin, tqt_xrootwin(), 0 );
     if ( !forWin )
 	forWin = tqt_xrootwin();
@@ -236,30 +236,30 @@ void KWin::setSystemTrayWindowFor( WId trayWin, WId forWin )
 
 void KWin::activateWindow( WId win, long time )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), 0 );
     if( time == 0 )
-        time = GET_QT_X_USER_TIME();
+        time = get_tqt_x_user_time();
     info.setActiveWindow( win, NET::FromApplication, time,
         kapp->activeWindow() ? kapp->activeWindow()->winId() : 0 );
-#endif // Q_WS_X11 ...
+#endif // TQ_WS_X11 ...
     KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWin::forceActiveWindow( WId win, long time )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), 0 );
     if( time == 0 )
-        time = GET_QT_X_TIME();
+        time = get_tqt_x_time();
     info.setActiveWindow( win, NET::FromTool, time, 0 );
-#endif // Q_WS_X11
+#endif // TQ_WS_X11
     KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWin::setActiveWindow( WId win )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), 0 );
     info.setActiveWindow( win, NET::FromUnknown, 0, 0 );
 #endif
@@ -268,7 +268,7 @@ void KWin::setActiveWindow( WId win )
 
 void KWin::demandAttention( WId win, bool set )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), 0 );
     info.setState( set ? NET::DemandsAttention : 0, NET::DemandsAttention );
 #endif
@@ -276,7 +276,7 @@ void KWin::demandAttention( WId win, bool set )
 
 void KWin::setUserTime( WId win, long time )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), 0 );
     info.setUserTime( time );
 #endif
@@ -290,7 +290,7 @@ KWin::WindowInfo KWin::windowInfo( WId win, unsigned long properties, unsigned l
 
 WId KWin::transientFor( WId win )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     KXErrorHandler handler; // ignore badwindow
     Window transient_for = None;
     if( XGetTransientForHint( tqt_xdisplay(), win, &transient_for ))
@@ -304,13 +304,13 @@ WId KWin::transientFor( WId win )
 
 void KWin::setMainWindow( TQWidget* subwindow, WId mainwindow )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if( mainwindow != 0 )
     {
         /*
          Grmbl. See TQDialog::show(). That should get fixed in Qt somehow.
         */
-        if( tqqt_cast< TQDialog* >( subwindow ) != NULL
+        if( tqt_cast< TQDialog* >( subwindow ) != NULL
             && subwindow->parentWidget() == NULL
             && kapp->mainWidget() != NULL )
         {
@@ -326,7 +326,7 @@ void KWin::setMainWindow( TQWidget* subwindow, WId mainwindow )
 
 WId KWin::groupLeader( WId win )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     KXErrorHandler handler; // ignore badwindow
     XWMHints *hints = XGetWMHints( tqt_xdisplay(), win );
     Window window_group = None;
@@ -347,7 +347,7 @@ WId KWin::groupLeader( WId win )
 KWin::Info KWin::info( WId win )
 {
     Info w;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo inf( tqt_xdisplay(), win, tqt_xrootwin(),
 		    NET::WMState |
 		    NET::WMStrut |
@@ -398,11 +398,11 @@ TQPixmap KWin::icon( WId win, int width, int height, bool scale )
 
 TQPixmap KWin::icon( WId win, int width, int height, bool scale, int flags )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     KXErrorHandler handler; // ignore badwindow
 #endif
     TQPixmap result;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if( flags & NETWM ) {
         NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), NET::WMIcon );
         NETIcon ni = info.icon( width, height );
@@ -514,7 +514,7 @@ TQPixmap KWin::icon( WId win, int width, int height, bool scale, int flags )
 
 void KWin::setIcons( WId win, const TQPixmap& icon, const TQPixmap& miniIcon )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if ( icon.isNull() )
 	return;
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), 0 );
@@ -536,7 +536,7 @@ void KWin::setIcons( WId win, const TQPixmap& icon, const TQPixmap& miniIcon )
 
 void KWin::setType( WId win, NET::WindowType windowType )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), 0 );
     info.setWindowType( windowType );
 #endif
@@ -544,7 +544,7 @@ void KWin::setType( WId win, NET::WindowType windowType )
 
 void KWin::setState( WId win, unsigned long state )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), NET::WMState );
     info.setState( state, state );
 #endif
@@ -552,7 +552,7 @@ void KWin::setState( WId win, unsigned long state )
 
 void KWin::clearState( WId win, unsigned long state )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), NET::WMState );
     info.setState( 0, state );
 #endif
@@ -560,7 +560,7 @@ void KWin::clearState( WId win, unsigned long state )
 
 void KWin::setOpacity( WId win, uint percent )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     twin_net_create_atoms();
     if (percent > 99)
         XDeleteProperty (tqt_xdisplay(), win, kde_wm_window_opacity);
@@ -574,7 +574,7 @@ void KWin::setOpacity( WId win, uint percent )
 
 void KWin::setShadowSize( WId win, uint percent )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     twin_net_create_atoms();
     long shadowSize = long(0xFFFFFFFF/100.0*percent);
     XChangeProperty(tqt_xdisplay(), win, kde_wm_window_shadow, XA_CARDINAL, 32, PropModeReplace, (unsigned char *) &shadowSize, 1L);
@@ -583,7 +583,7 @@ void KWin::setShadowSize( WId win, uint percent )
 
 void KWin::setOnAllDesktops( WId win, bool b )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), NET::WMDesktop );
     if ( b )
 	info.setDesktop( NETWinInfo::OnAllDesktops );
@@ -596,7 +596,7 @@ void KWin::setOnAllDesktops( WId win, bool b )
 
 void KWin::setOnDesktop( WId win, int desktop )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), NET::WMDesktop );
     info.setDesktop( desktop );
 #endif
@@ -606,7 +606,7 @@ void KWin::setExtendedStrut( WId win, int left_width, int left_start, int left_e
     int right_width, int right_start, int right_end, int top_width, int top_start, int top_end,
     int bottom_width, int bottom_start, int bottom_end )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), 0 );
     NETExtendedStrut strut;
     strut.left_width = left_width;
@@ -627,7 +627,7 @@ void KWin::setExtendedStrut( WId win, int left_width, int left_start, int left_e
 
 void KWin::setStrut( WId win, int left, int right, int top, int bottom )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), win, tqt_xrootwin(), 0 );
     NETStrut strut;
     strut.left = left;
@@ -640,11 +640,11 @@ void KWin::setStrut( WId win, int left, int right, int top, int bottom )
 
 int KWin::currentDesktop()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if (!tqt_xdisplay())
 #endif
       return 1;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), NET::CurrentDesktop );
     return info.currentDesktop();
 #endif
@@ -652,11 +652,11 @@ int KWin::currentDesktop()
 
 int KWin::numberOfDesktops()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if (!tqt_xdisplay())
 #endif
       return 0;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), NET::NumberOfDesktops );
     return info.numberOfDesktops();
 #endif
@@ -664,7 +664,7 @@ int KWin::numberOfDesktops()
 
 void KWin::setCurrentDesktop( int desktop )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), NET::CurrentDesktop );
     info.setCurrentDesktop( desktop );
 #endif
@@ -672,7 +672,7 @@ void KWin::setCurrentDesktop( int desktop )
 
 void KWin::setCurrentDesktopViewport( int desktop, TQPoint viewport )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), NET::CurrentDesktop );
     NETPoint netview;
     netview.x = viewport.x();
@@ -683,7 +683,7 @@ void KWin::setCurrentDesktopViewport( int desktop, TQPoint viewport )
 
 void KWin::iconifyWindow( WId win, bool animation)
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if ( !animation )
     {
         twin_net_create_atoms();
@@ -696,7 +696,7 @@ void KWin::iconifyWindow( WId win, bool animation)
 
 void KWin::deIconifyWindow( WId win, bool animation )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if ( !animation )
     {
         twin_net_create_atoms();
@@ -708,7 +708,7 @@ void KWin::deIconifyWindow( WId win, bool animation )
 
 void KWin::raiseWindow( WId win )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), NET::Supported );
     if( info.isSupported( NET::WM2RestackWindow ))
         info.restackRequest( win, None, Above );
@@ -719,7 +719,7 @@ void KWin::raiseWindow( WId win )
 
 void KWin::lowerWindow( WId win )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     NETRootInfo info( tqt_xdisplay(), NET::Supported );
     if( info.isSupported( NET::WM2RestackWindow ))
         info.restackRequest( win, None, Below );
@@ -730,7 +730,7 @@ void KWin::lowerWindow( WId win )
 
 void KWin::appStarted()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     TDEStartupInfo::appStarted();
 #endif
 }
@@ -739,11 +739,11 @@ class KWin::WindowInfoPrivate
 {
     public:
 	WindowInfoPrivate()
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	: info( NULL )
 #endif
 	{}
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	~WindowInfoPrivate() { delete info; }
 	NETWinInfo* info;
 #endif
@@ -762,7 +762,7 @@ class KWin::WindowInfoPrivate
 // KWin::info() should be updated too if something has to be changed here
 KWin::WindowInfo::WindowInfo( WId win, unsigned long properties, unsigned long properties2 )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     KXErrorHandler handler;
     d = new WindowInfoPrivate;
     d->ref = 1;
@@ -862,7 +862,7 @@ WId KWin::WindowInfo::win() const
 
 unsigned long KWin::WindowInfo::state() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMState ) == 0, 176 )
         << "Pass NET::WMState to KWin::windowInfo()" << endl;
     return d->info->state();
@@ -873,7 +873,7 @@ unsigned long KWin::WindowInfo::state() const
 
 NET::MappingState KWin::WindowInfo::mappingState() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::XAWMState ) == 0, 176 )
         << "Pass NET::XAWMState to KWin::windowInfo()" << endl;
     return d->info->mappingState();
@@ -884,7 +884,7 @@ NET::MappingState KWin::WindowInfo::mappingState() const
 
 NETExtendedStrut KWin::WindowInfo::extendedStrut() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2ExtendedStrut ) == 0, 176 )
         << "Pass NET::WM2ExtendedStrut to second argument of KWin::windowInfo()" << endl;
     NETExtendedStrut ext = d->info->extendedStrut();
@@ -922,7 +922,7 @@ NETExtendedStrut KWin::WindowInfo::extendedStrut() const
 
 NETStrut KWin::WindowInfo::strut() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMStrut ) == 0, 176 )
         << "Pass NET::WMStrut to KWin::windowInfo()" << endl;
     return d->info->strut();
@@ -934,7 +934,7 @@ NETStrut KWin::WindowInfo::strut() const
 
 NET::WindowType KWin::WindowInfo::windowType( int supported_types ) const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMWindowType ) == 0, 176 )
         << "Pass NET::WMWindowType to KWin::windowInfo()" << endl;
     return d->info->windowType( supported_types );
@@ -965,7 +965,7 @@ TQString KWin::Info::visibleNameWithState() const
 
 TQString KWin::WindowInfo::visibleName() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMVisibleName ) == 0, 176 )
         << "Pass NET::WMVisibleName to KWin::windowInfo()" << endl;
     return d->info->visibleName() && d->info->visibleName()[ 0 ] != '\0'
@@ -977,7 +977,7 @@ TQString KWin::WindowInfo::visibleName() const
 
 TQString KWin::WindowInfo::name() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMName ) == 0, 176 )
         << "Pass NET::WMName to KWin::windowInfo()" << endl;
     return d->name_;
@@ -998,7 +998,7 @@ TQString KWin::WindowInfo::visibleIconNameWithState() const
 
 TQString KWin::WindowInfo::visibleIconName() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMVisibleIconName ) == 0, 176 )
         << "Pass NET::WMVisibleIconName to KWin::windowInfo()" << endl;
     if( d->info->visibleIconName() && d->info->visibleIconName()[ 0 ] != '\0' )
@@ -1013,7 +1013,7 @@ TQString KWin::WindowInfo::visibleIconName() const
 
 TQString KWin::WindowInfo::iconName() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMIconName ) == 0, 176 )
         << "Pass NET::WMIconName to KWin::windowInfo()" << endl;
     if( d->info->iconName() && d->info->iconName()[ 0 ] != '\0' )
@@ -1026,7 +1026,7 @@ TQString KWin::WindowInfo::iconName() const
 
 bool KWin::WindowInfo::isOnCurrentDesktop() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     return isOnDesktop( KWin::currentDesktop());
 #else
     return false;
@@ -1035,7 +1035,7 @@ bool KWin::WindowInfo::isOnCurrentDesktop() const
 
 bool KWin::WindowInfo::isOnDesktop( int desktop ) const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMDesktop ) == 0, 176 )
         << "Pass NET::WMDesktop to KWin::windowInfo()" << endl;
     return d->info->desktop() == desktop || d->info->desktop() == NET::OnAllDesktops;
@@ -1046,7 +1046,7 @@ bool KWin::WindowInfo::isOnDesktop( int desktop ) const
 
 bool KWin::WindowInfo::onAllDesktops() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMDesktop ) == 0, 176 )
         << "Pass NET::WMDesktop to KWin::windowInfo()" << endl;
     return d->info->desktop() == NET::OnAllDesktops;
@@ -1057,7 +1057,7 @@ bool KWin::WindowInfo::onAllDesktops() const
 
 int KWin::WindowInfo::desktop() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMDesktop ) == 0, 176 )
         << "Pass NET::WMDesktop to KWin::windowInfo()" << endl;
     return d->info->desktop();
@@ -1068,7 +1068,7 @@ int KWin::WindowInfo::desktop() const
 
 TQRect KWin::WindowInfo::geometry() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMGeometry ) == 0, 176 )
         << "Pass NET::WMGeometry to KWin::windowInfo()" << endl;
     return d->geometry_;
@@ -1079,7 +1079,7 @@ TQRect KWin::WindowInfo::geometry() const
 
 TQRect KWin::WindowInfo::frameGeometry() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS ] & NET::WMKDEFrameStrut ) == 0, 176 )
         << "Pass NET::WMKDEFrameStrut to KWin::windowInfo()" << endl;
     return d->frame_geometry_;
@@ -1090,7 +1090,7 @@ TQRect KWin::WindowInfo::frameGeometry() const
 
 WId KWin::WindowInfo::transientFor() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2TransientFor ) == 0, 176 )
         << "Pass NET::WM2TransientFor to KWin::windowInfo()" << endl;
     return d->info->transientFor();
@@ -1101,7 +1101,7 @@ WId KWin::WindowInfo::transientFor() const
 
 WId KWin::WindowInfo::groupLeader() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2GroupLeader ) == 0, 176 )
         << "Pass NET::WM2GroupLeader to KWin::windowInfo()" << endl;
     return d->info->groupLeader();
@@ -1112,7 +1112,7 @@ WId KWin::WindowInfo::groupLeader() const
 
 TQCString KWin::WindowInfo::windowClassClass() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
         << "Pass NET::WM2WindowClass to KWin::windowInfo()" << endl;
     return d->info->windowClassClass();
@@ -1123,7 +1123,7 @@ TQCString KWin::WindowInfo::windowClassClass() const
 
 TQCString KWin::WindowInfo::windowClassName() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
         << "Pass NET::WM2WindowClass to KWin::windowInfo()" << endl;
     return d->info->windowClassName();
@@ -1134,7 +1134,7 @@ TQCString KWin::WindowInfo::windowClassName() const
 
 TQCString KWin::WindowInfo::windowRole() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowRole ) == 0, 176 )
         << "Pass NET::WM2WindowRole to KWin::windowInfo()" << endl;
     return d->info->windowRole();
@@ -1145,7 +1145,7 @@ TQCString KWin::WindowInfo::windowRole() const
 
 TQCString KWin::WindowInfo::clientMachine() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2ClientMachine ) == 0, 176 )
         << "Pass NET::WM2ClientMachine to KWin::windowInfo()" << endl;
     return d->info->clientMachine();
@@ -1156,7 +1156,7 @@ TQCString KWin::WindowInfo::clientMachine() const
 
 bool KWin::WindowInfo::actionSupported( NET::Action action ) const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2AllowedActions ) == 0, 176 )
         << "Pass NET::WM2AllowedActions to KWin::windowInfo()" << endl;
     if( allowedActionsSupported())
@@ -1169,7 +1169,7 @@ bool KWin::WindowInfo::actionSupported( NET::Action action ) const
 // see NETWM spec section 7.6
 bool KWin::WindowInfo::isMinimized() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if( mappingState() != NET::Iconic )
         return false;
     // NETWM 1.2 compliant WM - uses NET::Hidden for minimized windows
@@ -1186,7 +1186,7 @@ bool KWin::WindowInfo::isMinimized() const
 
 bool KWin::Info::isMinimized() const
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if( mappingState != NET::Iconic )
         return false;
     // NETWM 1.2 compliant WM - uses NET::Hidden for minimized windows
@@ -1208,7 +1208,7 @@ bool KWin::Info::isIconified() const
 
 bool KWin::icccmCompliantMappingState()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     static enum { noidea, yes, no } wm_is_1_2_compliant = noidea;
     if( wm_is_1_2_compliant == noidea ) {
         NETRootInfo info( tqt_xdisplay(), NET::Supported );
@@ -1222,7 +1222,7 @@ bool KWin::icccmCompliantMappingState()
 
 bool KWin::allowedActionsSupported()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     static enum { noidea, yes, no } wm_supports_allowed_actions = noidea;
     if( wm_supports_allowed_actions == noidea ) {
         NETRootInfo info( tqt_xdisplay(), NET::Supported );
@@ -1236,13 +1236,13 @@ bool KWin::allowedActionsSupported()
 
 TQString KWin::readNameProperty( WId win, unsigned long atom )
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     XTextProperty tp;
     char **text = NULL;
     int count;
 #endif
     TQString result;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if ( XGetTextProperty( tqt_xdisplay(), win, &tp, atom ) != 0 && tp.value != NULL ) 
     {
         if (!twin_UTF8_STRING)
