@@ -2383,7 +2383,7 @@ void TDEStyle::virtual_hook( int, void* )
 
 // HACK for gtk-qt-engine
 
-extern "C" KDE_EXPORT
+extern "C" TDE_EXPORT
 void kde_tdestyle_set_scrollbar_type_windows( void* style )
 {
     ((TDEStyle*)style)->setScrollBarType( TDEStyle::WindowsStyleScrollBar );
