@@ -149,11 +149,6 @@
 
 /* Compiler */
 
-/* COMPILER(CWP) */
-#if defined(__MWERKS__)
-#define WTF_COMPILER_CWP 1
-#endif
-
 /* COMPILER(MSVC) */
 #if defined(_MSC_VER)
 #define WTF_COMPILER_MSVC 1
@@ -169,12 +164,6 @@
 #define WTF_COMPILER_SUNPRO 1
 #endif
 
-/* COMPILER(BORLAND) */
-/* not really fully supported - is this relevant any more? */
-#if defined(__BORLANDC__)
-#define WTF_COMPILER_BORLAND 1
-#endif
-
 /* COMPILER(CYGWIN) */
 /* not really fully supported - is this relevant any more? */
 #if defined(__CYGWIN__)
