@@ -786,10 +786,10 @@ void CachedImage::setShowAnimations( TDEHTMLSettings::KAnimationAdvice showAnima
         imgSource->cleanBuffer();
         delete p;
         p = new TQPixmap(m->framePixmap());
-        m->disconnectUpdate( this, TQT_SLOT( movieUpdated( const TQRect &) ));
-        m->disconnectStatus( this, TQT_SLOT( movieStatus( int ) ));
-        m->disconnectResize( this, TQT_SLOT( movieResize( const TQSize& ) ) );
-        TQTimer::singleShot(0, this, TQT_SLOT( deleteMovie()));
+        m->disconnectUpdate( this, TQ_SLOT( movieUpdated( const TQRect &) ));
+        m->disconnectStatus( this, TQ_SLOT( movieStatus( int ) ));
+        m->disconnectResize( this, TQ_SLOT( movieResize( const TQSize& ) ) );
+        TQTimer::singleShot(0, this, TQ_SLOT( deleteMovie()));
         imgSource = 0;
     }
 }
@@ -849,9 +849,9 @@ void CachedImage::data ( TQBuffer &_buffer, bool eof )
         {
             imgSource = new ImageSource( _buffer.buffer());
             m = new TQMovie( imgSource, 8192 );
-            m->connectUpdate( this, TQT_SLOT( movieUpdated( const TQRect &) ));
-            m->connectStatus( this, TQT_SLOT( movieStatus(int)));
-            m->connectResize( this, TQT_SLOT( movieResize( const TQSize& ) ) );
+            m->connectUpdate( this, TQ_SLOT( movieUpdated( const TQRect &) ));
+            m->connectStatus( this, TQ_SLOT( movieStatus(int)));
+            m->connectResize( this, TQ_SLOT( movieResize( const TQSize& ) ) );
         }
     }
 
@@ -1128,7 +1128,7 @@ Loader::Loader() : TQObject()
 {
     m_requestsPending.setAutoDelete( true );
     m_requestsLoading.setAutoDelete( true );
-    connect(&m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT( servePendingRequests() ) );
+    connect(&m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT( servePendingRequests() ) );
 }
 
 void Loader::load(DocLoader* dl, CachedObject *object, bool incremental)
@@ -1171,9 +1171,9 @@ void Loader::servePendingRequests()
             }
         }
 
-        connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotFinished( TDEIO::Job * ) ) );
-        connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray &)),
-                 TQT_SLOT( slotData( TDEIO::Job*, const TQByteArray &)));
+        connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotFinished( TDEIO::Job * ) ) );
+        connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray &)),
+                 TQ_SLOT( slotData( TDEIO::Job*, const TQByteArray &)));
 
         if ( req->object->schedule() )
             TDEIO::Scheduler::scheduleJob( job );
