@@ -30,7 +30,7 @@
 
 #include <tdeparts/part.h>
 #include <tdeparts/browserextension.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <kfinddialog.h>
 
 #include <tqregexp.h>
@@ -182,7 +182,7 @@ namespace TDEWallet
  */
 class TDEHTML_EXPORT TDEHTMLPart : public KParts::ReadOnlyPart
 {
-  Q_OBJECT
+  TQ_OBJECT
   friend class TDEHTMLView;
   friend class DOM::HTMLTitleElementImpl;
   friend class DOM::HTMLFrameElementImpl;
