@@ -28,7 +28,7 @@ DEALINGS IN THE SOFTWARE.
 
 #include <tqfile.h>
 #include <tqtextstream.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstandarddirs.h>
 #include <tdeconfig.h>
 #include <kdebug.h>
