@@ -89,7 +89,7 @@ public:
    KService::DCOPServiceType_t dcop_service_type;
    bool autoStart;
    TQString errorMsg;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
    TQCString startup_id; // "" is the default, "0" for none
    TQCString startup_dpy; // Display to send startup notification to.
 #endif
@@ -193,7 +193,7 @@ protected:
    TQCString mSlaveValgrindSkin;
    bool dontBlockReading;
    bool newStartup;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
    Display *mCached_dpy;
 #endif
 };
