@@ -24,7 +24,7 @@
 #include <tqstringlist.h>
 #include <tqmap.h>
 #include <ksimpleconfig.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include "kbookmarkimporter.h"
 
