@@ -23,7 +23,7 @@
 #include <tqcstring.h>
 #include <tqstringlist.h>
 #include <ksimpleconfig.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include "kbookmarkimporter.h"
 #include "kbookmarkexporter.h"
