@@ -44,9 +44,9 @@ namespace KPAC
         m_scriptURL = url;
 
         TDEIO::TransferJob* job = TDEIO::get( url, false, false );
-        connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-                 TQT_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
-        connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), TQT_SLOT( result( TDEIO::Job* ) ) );
+        connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+                 TQ_SLOT( data( TDEIO::Job*, const TQByteArray& ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ), TQ_SLOT( result( TDEIO::Job* ) ) );
     }
 
     void Downloader::failed()
