@@ -53,11 +53,11 @@
 // See design notes at end
 
 extern "C" {
-	KDE_EXPORT KDEDModule *create_kssld(const TQCString &name) {
+	TDE_EXPORT KDEDModule *create_kssld(const TQCString &name) {
 		return new KSSLD(name);
 	}
 
-	KDE_EXPORT void *__kde_do_unload;
+	TDE_EXPORT void *__kde_do_unload;
 }
 
 
@@ -287,7 +287,7 @@ KSSLCNode *node;
 			if ( !node->permanent ) {
 				node->expires = TQDateTime::currentDateTime();
 				// FIXME: make this configurable
-					node->expires = TQT_TQDATETIME_OBJECT(node->expires.addSecs(5));
+					node->expires = node->expires.addSecs(5);
 			} else {
 					node->expires = node->cert->getQDTNotAfter(); // set to certs expiry date
 			}
@@ -310,7 +310,7 @@ KSSLCNode *node;
 
 	if (!permanent) {
 		n->expires = TQDateTime::currentDateTime();
-		n->expires = TQT_TQDATETIME_OBJECT(n->expires.addSecs(5));
+		n->expires = n->expires.addSecs(5);
 	} else {
 		if ( !n->expires.isValid() )
 			n->expires = n->cert->getQDTNotAfter(); // set to certs expiry date
