@@ -36,7 +36,7 @@
 #include <tdeglobal.h>
 #include <kicondialog.h>
 #include <kiconloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <klineedit.h>
 #include <tdelocale.h>
 #include <kmimetype.h>
