@@ -124,16 +124,16 @@ KDirOperator::KDirOperator(const KURL& _url,
 
     setDirLister( new KDirLister( true ) );
 
-    connect(&myCompletion, TQT_SIGNAL(match(const TQString&)),
-            TQT_SLOT(slotCompletionMatch(const TQString&)));
+    connect(&myCompletion, TQ_SIGNAL(match(const TQString&)),
+            TQ_SLOT(slotCompletionMatch(const TQString&)));
 
     progress = new KProgress(this, "progress");
     progress->adjustSize();
     progress->move(2, height() - progress->height() -2);
 
     d->progressDelayTimer = new TQTimer( this, "progress delay timer" );
-    connect( d->progressDelayTimer, TQT_SIGNAL( timeout() ),
-	     TQT_SLOT( slotShowProgress() ));
+    connect( d->progressDelayTimer, TQ_SIGNAL( timeout() ),
+	     TQ_SLOT( slotShowProgress() ));
 
     myCompleteListDirty = false;
 
@@ -145,6 +145,8 @@ KDirOperator::KDirOperator(const KURL& _url,
     setupMenu();
 
     setFocusPolicy(TQWidget::WheelFocus);
+
+    installEventFilter(this);
 }
 
 KDirOperator::~KDirOperator()
@@ -192,10 +194,10 @@ void KDirOperator::insertViewDependentActions()
    {
       if (viewActionCollection)
       {
-         disconnect( viewActionCollection, TQT_SIGNAL( inserted( TDEAction * )),
-               this, TQT_SLOT( slotViewActionAdded( TDEAction * )));
-         disconnect( viewActionCollection, TQT_SIGNAL( removed( TDEAction * )),
-               this, TQT_SLOT( slotViewActionRemoved( TDEAction * )));
+         disconnect( viewActionCollection, TQ_SIGNAL( inserted( TDEAction * )),
+               this, TQ_SLOT( slotViewActionAdded( TDEAction * )));
+         disconnect( viewActionCollection, TQ_SIGNAL( removed( TDEAction * )),
+               this, TQ_SLOT( slotViewActionRemoved( TDEAction * )));
       }
 
       viewActionMenu->popupMenu()->clear();
@@ -237,10 +239,10 @@ void KDirOperator::insertViewDependentActions()
          }
       }
 
-      connect( viewActionCollection, TQT_SIGNAL( inserted( TDEAction * )),
-               TQT_SLOT( slotViewActionAdded( TDEAction * )));
-      connect( viewActionCollection, TQT_SIGNAL( removed( TDEAction * )),
-               TQT_SLOT( slotViewActionRemoved( TDEAction * )));
+      connect( viewActionCollection, TQ_SIGNAL( inserted( TDEAction * )),
+               TQ_SLOT( slotViewActionAdded( TDEAction * )));
+      connect( viewActionCollection, TQ_SIGNAL( removed( TDEAction * )),
+               TQ_SLOT( slotViewActionRemoved( TDEAction * )));
    }
 }
 
@@ -719,7 +721,7 @@ void KDirOperator::pathChanged()
     TQApplication::restoreOverrideCursor();
 
     // when TDEIO::Job emits finished, the slot will restore the cursor
-    TQApplication::setOverrideCursor( tqwaitCursor );
+    TQApplication::setOverrideCursor( TQt::waitCursor );
 
     if ( !isReadable( currUrl )) {
         KMessageBox::error(viewWidget(),
@@ -1046,22 +1048,27 @@ void KDirOperator::connectView(KFileView *view)
     }
 
     m_fileView = view;
+    m_fileView->widget()->installEventFilter(this);
+    if (m_fileView->widget()->inherits("TQScrollView"))
+    {
+        (static_cast<TQScrollView *>(m_fileView->widget()))->viewport()->installEventFilter(this);
+    }
     m_fileView->setDropOptions(d->dropOptions);
     viewActionCollection = 0L;
     KFileViewSignaler *sig = view->signaler();
 
-    connect(sig, TQT_SIGNAL( activatedMenu(const KFileItem *, const TQPoint& ) ),
-            this, TQT_SLOT( activatedMenu(const KFileItem *, const TQPoint& )));
-    connect(sig, TQT_SIGNAL( dirActivated(const KFileItem *) ),
-            this, TQT_SLOT( selectDir(const KFileItem*) ) );
-    connect(sig, TQT_SIGNAL( fileSelected(const KFileItem *) ),
-            this, TQT_SLOT( selectFile(const KFileItem*) ) );
-    connect(sig, TQT_SIGNAL( fileHighlighted(const KFileItem *) ),
-            this, TQT_SLOT( highlightFile(const KFileItem*) ));
-    connect(sig, TQT_SIGNAL( sortingChanged( TQDir::SortSpec ) ),
-            this, TQT_SLOT( slotViewSortingChanged( TQDir::SortSpec )));
-    connect(sig, TQT_SIGNAL( dropped(const KFileItem *, TQDropEvent*, const KURL::List&) ),
-            this, TQT_SIGNAL( dropped(const KFileItem *, TQDropEvent*, const KURL::List&)) );
+    connect(sig, TQ_SIGNAL( activatedMenu(const KFileItem *, const TQPoint& ) ),
+            this, TQ_SLOT( activatedMenu(const KFileItem *, const TQPoint& )));
+    connect(sig, TQ_SIGNAL( dirActivated(const KFileItem *) ),
+            this, TQ_SLOT( selectDir(const KFileItem*) ) );
+    connect(sig, TQ_SIGNAL( fileSelected(const KFileItem *) ),
+            this, TQ_SLOT( selectFile(const KFileItem*) ) );
+    connect(sig, TQ_SIGNAL( fileHighlighted(const KFileItem *) ),
+            this, TQ_SLOT( highlightFile(const KFileItem*) ));
+    connect(sig, TQ_SIGNAL( sortingChanged( TQDir::SortSpec ) ),
+            this, TQ_SLOT( slotViewSortingChanged( TQDir::SortSpec )));
+    connect(sig, TQ_SIGNAL( dropped(const KFileItem *, TQDropEvent*, const KURL::List&) ),
+            this, TQ_SIGNAL( dropped(const KFileItem *, TQDropEvent*, const KURL::List&)) );
 
     if ( reverseAction->isChecked() != m_fileView->isReversed() )
         slotSortReversed();
@@ -1071,7 +1078,7 @@ void KDirOperator::connectView(KFileView *view)
     m_fileView->widget()->show();
 
     if ( listDir ) {
-        TQApplication::setOverrideCursor( tqwaitCursor );
+        TQApplication::setOverrideCursor( TQt::waitCursor );
         openURL( currUrl );
     }
     else
@@ -1124,20 +1131,20 @@ void KDirOperator::setDirLister( KDirLister *lister )
     dir->setMainWindow (mainWidget);
     kdDebug (tdefile_area) << "mainWidget=" << mainWidget << endl;
 
-    connect( dir, TQT_SIGNAL( percent( int )),
-             TQT_SLOT( slotProgress( int ) ));
-    connect( dir, TQT_SIGNAL(started( const KURL& )), TQT_SLOT(slotStarted()));
-    connect( dir, TQT_SIGNAL(newItems(const KFileItemList &)),
-             TQT_SLOT(insertNewFiles(const KFileItemList &)));
-    connect( dir, TQT_SIGNAL(completed()), TQT_SLOT(slotIOFinished()));
-    connect( dir, TQT_SIGNAL(canceled()), TQT_SLOT(slotCanceled()));
-    connect( dir, TQT_SIGNAL(deleteItem(KFileItem *)),
-             TQT_SLOT(itemDeleted(KFileItem *)));
-    connect( dir, TQT_SIGNAL(redirection( const KURL& )),
-	     TQT_SLOT( slotRedirected( const KURL& )));
-    connect( dir, TQT_SIGNAL( clear() ), TQT_SLOT( slotClearView() ));
-    connect( dir, TQT_SIGNAL( refreshItems( const KFileItemList& ) ),
-             TQT_SLOT( slotRefreshItems( const KFileItemList& ) ) );
+    connect( dir, TQ_SIGNAL( percent( int )),
+             TQ_SLOT( slotProgress( int ) ));
+    connect( dir, TQ_SIGNAL(started( const KURL& )), TQ_SLOT(slotStarted()));
+    connect( dir, TQ_SIGNAL(newItems(const KFileItemList &)),
+             TQ_SLOT(insertNewFiles(const KFileItemList &)));
+    connect( dir, TQ_SIGNAL(completed()), TQ_SLOT(slotIOFinished()));
+    connect( dir, TQ_SIGNAL(canceled()), TQ_SLOT(slotCanceled()));
+    connect( dir, TQ_SIGNAL(deleteItem(KFileItem *)),
+             TQ_SLOT(itemDeleted(KFileItem *)));
+    connect( dir, TQ_SIGNAL(redirection( const KURL& )),
+	     TQ_SLOT( slotRedirected( const KURL& )));
+    connect( dir, TQ_SIGNAL( clear() ), TQ_SLOT( slotClearView() ));
+    connect( dir, TQ_SIGNAL( refreshItems( const KFileItemList& ) ),
+             TQ_SLOT( slotRefreshItems( const KFileItemList& ) ) );
 }
 
 void KDirOperator::insertNewFiles(const KFileItemList &newone)
@@ -1163,7 +1170,7 @@ void KDirOperator::insertNewFiles(const KFileItemList &newone)
 	++it;
     }
 
-    TQTimer::singleShot(200, this, TQT_SLOT(resetCursor()));
+    TQTimer::singleShot(200, this, TQ_SLOT(resetCursor()));
 }
 
 void KDirOperator::selectDir(const KFileItem *item)
@@ -1253,26 +1260,26 @@ void KDirOperator::slotCompletionMatch(const TQString& match)
 
 void KDirOperator::setupActions()
 {
-    myActionCollection = new TDEActionCollection( topLevelWidget(), TQT_TQOBJECT(this), "KDirOperator::myActionCollection" );
+    myActionCollection = new TDEActionCollection( topLevelWidget(), this, "KDirOperator::myActionCollection" );
 
     actionMenu = new TDEActionMenu( i18n("Menu"), myActionCollection, "popupMenu" );
-    upAction = KStdAction::up( TQT_TQOBJECT(this), TQT_SLOT( cdUp() ), myActionCollection, "up" );
+    upAction = KStdAction::up( this, TQ_SLOT( cdUp() ), myActionCollection, "up" );
     upAction->setText( i18n("Parent Folder") );
-    backAction = KStdAction::back( TQT_TQOBJECT(this), TQT_SLOT( back() ), myActionCollection, "back" );
-    forwardAction = KStdAction::forward( TQT_TQOBJECT(this), TQT_SLOT(forward()), myActionCollection, "forward" );
-    homeAction = KStdAction::home( TQT_TQOBJECT(this), TQT_SLOT( home() ), myActionCollection, "home" );
+    backAction = KStdAction::back( this, TQ_SLOT( back() ), myActionCollection, "back" );
+    forwardAction = KStdAction::forward( this, TQ_SLOT(forward()), myActionCollection, "forward" );
+    homeAction = KStdAction::home( this, TQ_SLOT( home() ), myActionCollection, "home" );
     homeAction->setText(i18n("Home Folder"));
-    reloadAction = KStdAction::redisplay( TQT_TQOBJECT(this), TQT_SLOT(rereadDir()), myActionCollection, "reload" );
+    reloadAction = KStdAction::redisplay( this, TQ_SLOT(rereadDir()), myActionCollection, "reload" );
     actionSeparator = new TDEActionSeparator( myActionCollection, "separator" );
     d->viewActionSeparator = new TDEActionSeparator( myActionCollection,
                                                    "viewActionSeparator" );
     mkdirAction = new TDEAction( i18n("New Folder..."), 0,
-                                 TQT_TQOBJECT(this), TQT_SLOT( mkdir() ), myActionCollection, "mkdir" );
+                                 this, TQ_SLOT( mkdir() ), myActionCollection, "mkdir" );
     TDEAction* trash = new TDEAction( i18n( "Move to Trash" ), "edittrash", Key_Delete, myActionCollection, "trash" );
-    connect( trash, TQT_SIGNAL( activated( TDEAction::ActivationReason, TQt::ButtonState ) ),
-	     this, TQT_SLOT( trashSelected( TDEAction::ActivationReason, TQt::ButtonState ) ) );
-    new TDEAction( i18n( "Delete" ), "edit-delete", SHIFT+Key_Delete, TQT_TQOBJECT(this),
-                  TQT_SLOT( deleteSelected() ), myActionCollection, "delete" );
+    connect( trash, TQ_SIGNAL( activated( TDEAction::ActivationReason, TQt::ButtonState ) ),
+	     this, TQ_SLOT( trashSelected( TDEAction::ActivationReason, TQt::ButtonState ) ) );
+    new TDEAction( i18n( "Delete" ), "edit-delete", SHIFT+Key_Delete, this,
+                  TQ_SLOT( deleteSelected() ), myActionCollection, "delete" );
     mkdirAction->setIcon( TQString::fromLatin1("folder-new") );
     reloadAction->setText( i18n("Reload") );
     reloadAction->setShortcut( TDEStdAccel::shortcut( TDEStdAccel::Reload ));
@@ -1281,16 +1288,16 @@ void KDirOperator::setupActions()
     // the sort menu actions
     sortActionMenu = new TDEActionMenu( i18n("Sorting"), myActionCollection, "sorting menu");
     byNameAction = new TDERadioAction( i18n("By Name"), 0,
-                                     TQT_TQOBJECT(this), TQT_SLOT( slotSortByName() ),
+                                     this, TQ_SLOT( slotSortByName() ),
                                      myActionCollection, "by name" );
     byDateAction = new TDERadioAction( i18n("By Date"), 0,
-                                     TQT_TQOBJECT(this), TQT_SLOT( slotSortByDate() ),
+                                     this, TQ_SLOT( slotSortByDate() ),
                                      myActionCollection, "by date" );
     bySizeAction = new TDERadioAction( i18n("By Size"), 0,
-                                     TQT_TQOBJECT(this), TQT_SLOT( slotSortBySize() ),
+                                     this, TQ_SLOT( slotSortBySize() ),
                                      myActionCollection, "by size" );
     reverseAction = new TDEToggleAction( i18n("Reverse"), 0,
-                                       TQT_TQOBJECT(this), TQT_SLOT( slotSortReversed() ),
+                                       this, TQ_SLOT( slotSortReversed() ),
                                        myActionCollection, "reversed" );
 
     TQString sortGroup = TQString::fromLatin1("sort");
@@ -1304,17 +1311,17 @@ void KDirOperator::setupActions()
     caseInsensitiveAction = new TDEToggleAction(i18n("Case Insensitive"), 0,
                                               myActionCollection, "case insensitive" );
 
-    connect( dirsFirstAction, TQT_SIGNAL( toggled( bool ) ),
-             TQT_SLOT( slotToggleDirsFirst() ));
-    connect( caseInsensitiveAction, TQT_SIGNAL( toggled( bool ) ),
-             TQT_SLOT( slotToggleIgnoreCase() ));
+    connect( dirsFirstAction, TQ_SIGNAL( toggled( bool ) ),
+             TQ_SLOT( slotToggleDirsFirst() ));
+    connect( caseInsensitiveAction, TQ_SIGNAL( toggled( bool ) ),
+             TQ_SLOT( slotToggleIgnoreCase() ));
 
 
 
     // the view menu actions
     viewActionMenu = new TDEActionMenu( i18n("&View"), myActionCollection, "view menu" );
-    connect( viewActionMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ),
-             TQT_SLOT( insertViewDependentActions() ));
+    connect( viewActionMenu->popupMenu(), TQ_SIGNAL( aboutToShow() ),
+             TQ_SLOT( insertViewDependentActions() ));
 
     shortAction = new TDERadioAction( i18n("Short View"), "view_multicolumn",
                                     TDEShortcut(), myActionCollection, "short view" );
@@ -1325,31 +1332,31 @@ void KDirOperator::setupActions()
                                           myActionCollection, "show hidden" );
 //    showHiddenAction->setCheckedState( i18n("Hide Hidden Files") );
     separateDirsAction = new TDEToggleAction( i18n("Separate Folders"), TDEShortcut(),
-                                            TQT_TQOBJECT(this),
-                                            TQT_SLOT(slotSeparateDirs()),
+                                            this,
+                                            TQ_SLOT(slotSeparateDirs()),
                                             myActionCollection, "separate dirs" );
     TDEToggleAction *previewAction = new TDEToggleAction(i18n("Show Preview"),
                                                      "thumbnail", TDEShortcut(),
                                                      myActionCollection,
                                                      "preview" );
     previewAction->setCheckedState(i18n("Hide Preview"));
-    connect( previewAction, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( togglePreview( bool )));
+    connect( previewAction, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( togglePreview( bool )));
 
 
     TQString viewGroup = TQString::fromLatin1("view");
     shortAction->setExclusiveGroup( viewGroup );
     detailedAction->setExclusiveGroup( viewGroup );
 
-    connect( shortAction, TQT_SIGNAL( activated() ),
-             TQT_SLOT( slotSimpleView() ));
-    connect( detailedAction, TQT_SIGNAL( activated() ),
-             TQT_SLOT( slotDetailedView() ));
-    connect( showHiddenAction, TQT_SIGNAL( toggled( bool ) ),
-             TQT_SLOT( slotToggleHidden( bool ) ));
+    connect( shortAction, TQ_SIGNAL( activated() ),
+             TQ_SLOT( slotSimpleView() ));
+    connect( detailedAction, TQ_SIGNAL( activated() ),
+             TQ_SLOT( slotDetailedView() ));
+    connect( showHiddenAction, TQ_SIGNAL( toggled( bool ) ),
+             TQ_SLOT( slotToggleHidden( bool ) ));
 
-    new TDEAction( i18n("Properties"), TDEShortcut(ALT+Key_Return), TQT_TQOBJECT(this),
-                 TQT_SLOT(slotProperties()), myActionCollection, "properties" );
+    new TDEAction( i18n("Properties"), TDEShortcut(ALT+Key_Return), this,
+                 TQ_SLOT(slotProperties()), myActionCollection, "properties" );
 }
 
 void KDirOperator::setupMenu()
@@ -1734,6 +1741,24 @@ TQString KDirOperator::viewConfigGroup() const
     return d->configGroup;
 }
 
+bool KDirOperator::eventFilter(TQObject *obj, TQEvent *ev)
+{
+    if (ev->type() == TQEvent::MouseButtonRelease)
+    {
+        TQMouseEvent *mouseEv = static_cast<TQMouseEvent *>(ev);
+        switch (mouseEv->button())
+        {
+            case TQMouseEvent::HistoryBackButton:
+                back();
+                return true;
+            case TQMouseEvent::HistoryForwardButton:
+                forward();
+                return true;
+        }
+    }
+    return false;
+}
+
 void KDirOperator::virtual_hook( int, void* )
 { /*BASE::virtual_hook( id, data );*/ }
 
