@@ -72,21 +72,21 @@ KFileDetailView::KFileDetailView(TQWidget *parent, const char *name)
     setAllColumnsShowFocus( true );
     setDragEnabled(true);
 
-    connect( header(), TQT_SIGNAL( clicked(int)),
-             TQT_SLOT(slotSortingChanged(int) ));
+    connect( header(), TQ_SIGNAL( clicked(int)),
+             TQ_SLOT(slotSortingChanged(int) ));
 
 
-    connect( this, TQT_SIGNAL( returnPressed(TQListViewItem *) ),
-	     TQT_SLOT( slotActivate( TQListViewItem *) ) );
+    connect( this, TQ_SIGNAL( returnPressed(TQListViewItem *) ),
+	     TQ_SLOT( slotActivate( TQListViewItem *) ) );
 
-    connect( this, TQT_SIGNAL( clicked(TQListViewItem *, const TQPoint&, int)),
-	     TQT_SLOT( selected( TQListViewItem *) ) );
-    connect( this, TQT_SIGNAL( doubleClicked(TQListViewItem *, const TQPoint&, int)),
-	     TQT_SLOT( slotActivate( TQListViewItem *) ) );
+    connect( this, TQ_SIGNAL( clicked(TQListViewItem *, const TQPoint&, int)),
+	     TQ_SLOT( selected( TQListViewItem *) ) );
+    connect( this, TQ_SIGNAL( doubleClicked(TQListViewItem *, const TQPoint&, int)),
+	     TQ_SLOT( slotActivate( TQListViewItem *) ) );
 
-    connect( this, TQT_SIGNAL(contextMenuRequested( TQListViewItem *,
+    connect( this, TQ_SIGNAL(contextMenuRequested( TQListViewItem *,
                                                 const TQPoint &, int )),
-	     this, TQT_SLOT( slotActivateMenu( TQListViewItem *, const TQPoint& )));
+	     this, TQ_SLOT( slotActivateMenu( TQListViewItem *, const TQPoint& )));
 
     KFile::SelectionMode sm = KFileView::selectionMode();
     switch ( sm ) {
@@ -107,15 +107,15 @@ KFileDetailView::KFileDetailView(TQWidget *parent, const char *name)
 
     // for highlighting
     if ( sm == KFile::Multi || sm == KFile::Extended )
-	connect( this, TQT_SIGNAL( selectionChanged() ),
-		 TQT_SLOT( slotSelectionChanged() ));
+	connect( this, TQ_SIGNAL( selectionChanged() ),
+		 TQ_SLOT( slotSelectionChanged() ));
     else
-	connect( this, TQT_SIGNAL( selectionChanged( TQListViewItem * ) ),
-		 TQT_SLOT( highlighted( TQListViewItem * ) ));
+	connect( this, TQ_SIGNAL( selectionChanged( TQListViewItem * ) ),
+		 TQ_SLOT( highlighted( TQListViewItem * ) ));
 		
     // DND
-    connect( &(d->autoOpenTimer), TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( slotAutoOpen() ));
+    connect( &(d->autoOpenTimer), TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( slotAutoOpen() ));
 
     setSorting( sorting() );
 
@@ -253,8 +253,8 @@ void KFileDetailView::highlighted( TQListViewItem *item )
 
 void KFileDetailView::setSelectionMode( KFile::SelectionMode sm )
 {
-    disconnect( this, TQT_SIGNAL( selectionChanged() ));
-    disconnect( this, TQT_SIGNAL( selectionChanged( TQListViewItem * ) ));
+    disconnect( this, TQ_SIGNAL( selectionChanged() ));
+    disconnect( this, TQ_SIGNAL( selectionChanged( TQListViewItem * ) ));
 
     KFileView::setSelectionMode( sm );
 
@@ -275,11 +275,11 @@ void KFileDetailView::setSelectionMode( KFile::SelectionMode sm )
     }
 
     if ( sm == KFile::Multi || sm == KFile::Extended )
-        connect( this, TQT_SIGNAL( selectionChanged() ),
-                 TQT_SLOT( slotSelectionChanged() ));
+        connect( this, TQ_SIGNAL( selectionChanged() ),
+                 TQ_SLOT( slotSelectionChanged() ));
     else
-        connect( this, TQT_SIGNAL( selectionChanged( TQListViewItem * )),
-                 TQT_SLOT( highlighted( TQListViewItem * )));
+        connect( this, TQ_SIGNAL( selectionChanged( TQListViewItem * )),
+                 TQ_SLOT( highlighted( TQListViewItem * )));
 }
 
 bool KFileDetailView::isSelected( const KFileItem *i ) const
