@@ -309,7 +309,7 @@ public:
      * Do not use in conjunction with setFilter()
      * @deprecated
      */
-    void setFilterMimeType(const TQString &label, const KMimeType::List &types, const KMimeType::Ptr &defaultType) KDE_DEPRECATED;
+    void setFilterMimeType(const TQString &label, const KMimeType::List &types, const KMimeType::Ptr &defaultType) TDE_DEPRECATED;
 
     /**
      * Returns the mimetype for the desired output format.
@@ -364,7 +364,7 @@ public:
      * Ownership is transferred to KFileDialog. You need to create the
      * preview-widget with "new", i.e. on the heap.
      */
-    void setPreviewWidget(const TQWidget *w) KDE_DEPRECATED;
+    void setPreviewWidget(const TQWidget *w) TDE_DEPRECATED;
 
     /**
      * Adds a preview widget and enters the preview mode.
@@ -713,7 +713,7 @@ public:
      * items into it, e.g.:
      * \code
      *      yourAction = new TDEAction( i18n("Your Action"), 0,
-     *                                this, TQT_SLOT( yourSlot() ),
+     *                                this, TQ_SLOT( yourSlot() ),
      *                                this, "action name" );
      *      yourAction->plug( tdefileDialog->toolBar() );
      * \endcode
