@@ -25,7 +25,7 @@ class TDEConfig;
 
 class TDEIO_EXPORT KFileSpeedBar : public KURLBar
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     KFileSpeedBar( TQWidget *parent = 0, const char *name = 0 );
     ~KFileSpeedBar();
