@@ -22,7 +22,7 @@
 
 class testFrame: public TDEMainWindow
 {
-   Q_OBJECT
+   TQ_OBJECT
 public:
    testFrame();
    void showPath( const KURL & );
