@@ -1307,7 +1307,7 @@ TDEIO_EXPORT TQByteArray TDEIO::rawErrorDetail(int errorCode, const TQString &er
 #endif
 #ifdef HAVE_SYS_UCRED_H
 #include <sys/ucred.h>
-#elifdef HAVE_UCRED_H
+#elif defined(HAVE_UCRED_H)
 #include <ucred.h>
 #endif
 #ifdef HAVE_SYS_MOUNT_H
@@ -1760,11 +1760,7 @@ static TQString get_mount_info(const TQString& filename,
         if (realpath(device_name, realpath_buffer) != 0)
             // succes, use result from realpath
             device_name = realpath_buffer;
-#ifdef __osf__
-        char * mounttype = mnt_names[mounted[i].f_type];
-#else
         char * mounttype = mounted[i].f_fstypename;
-#endif
         if ( is_my_mountpoint( mounted[i].f_mntonname, realname, max ) )
         {
             mountPoint = TQFile::decodeName(mounted[i].f_mntonname);
