@@ -226,7 +226,7 @@ KDirWatchPrivate::KDirWatchPrivate()
   : rescan_timer(0, "KDirWatchPrivate::rescan_timer")
 {
   timer = new TQTimer(this, "KDirWatchPrivate::timer");
-  connect (timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotRescan()));
+  connect (timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotRescan()));
   freq = 3600000; // 1 hour as upper bound
   statEntries = 0;
   delayRemove = false;
@@ -240,7 +240,7 @@ KDirWatchPrivate::KDirWatchPrivate()
 
   // used for FAM and DNOTIFY
   rescan_all = false;
-  connect(&rescan_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotRescan()));
+  connect(&rescan_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotRescan()));
 
 #ifdef HAVE_FAM
   // It's possible that FAM server can't be started
@@ -249,8 +249,8 @@ KDirWatchPrivate::KDirWatchPrivate()
     use_fam=true;
     sn = new TQSocketNotifier( FAMCONNECTION_GETFD(&fc),
 			      TQSocketNotifier::Read, this);
-    connect( sn, TQT_SIGNAL(activated(int)),
- 	     this, TQT_SLOT(famEventReceived()) );
+    connect( sn, TQ_SIGNAL(activated(int)),
+ 	     this, TQ_SLOT(famEventReceived()) );
   }
   else {
     kdDebug(7001) << "Can't use FAM (fam daemon not running?)" << endl;
@@ -286,7 +286,7 @@ KDirWatchPrivate::KDirWatchPrivate()
     fcntl(m_inotify_fd, F_SETFD, FD_CLOEXEC);
 
     mSn = new TQSocketNotifier( m_inotify_fd, TQSocketNotifier::Read, this );
-    connect( mSn, TQT_SIGNAL(activated( int )), this, TQT_SLOT( slotActivated() ) );
+    connect( mSn, TQ_SIGNAL(activated( int )), this, TQ_SLOT( slotActivated() ) );
   }
 #endif
 
@@ -320,7 +320,7 @@ KDirWatchPrivate::KDirWatchPrivate()
     fcntl(mPipe[0], F_SETFL, O_NONBLOCK | fcntl(mPipe[0], F_GETFL));
     fcntl(mPipe[1], F_SETFL, O_NONBLOCK | fcntl(mPipe[1], F_GETFL));
     mSn = new TQSocketNotifier( mPipe[0], TQSocketNotifier::Read, this);
-    connect(mSn, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotActivated()));
+    connect(mSn, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotActivated()));
     // Install the signal handler only once
     if ( dnotify_signal == 0 )
     {
@@ -1249,7 +1249,7 @@ void KDirWatchPrivate::emitEvent(Entry* e, int event, const KURL &fileName)
     else
 #ifdef Q_OS_UNIX
       path += "/" + fileName.path();
-#elif defined(Q_WS_WIN)
+#elif defined(TQ_WS_WIN)
       //current drive is passed instead of /
       path += TQDir::currentDirPath().left(2) + "/" + fileName.path();
 #endif
@@ -1420,7 +1420,7 @@ void KDirWatchPrivate::slotRescan()
     timer->start(freq);
   }
 
-  TQTimer::singleShot(0, this, TQT_SLOT(slotRemoveDelayed()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotRemoveDelayed()));
 }
 
 bool KDirWatchPrivate::isNoisyFile( const char * filename )
@@ -1469,7 +1469,7 @@ void KDirWatchPrivate::famEventReceived()
       checkFAMEvent(&fe);
   }
 
-  TQTimer::singleShot(0, this, TQT_SLOT(slotRemoveDelayed()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotRemoveDelayed()));
 }
 
 void KDirWatchPrivate::checkFAMEvent(FAMEvent* fe)
