@@ -61,7 +61,7 @@
 #include <kde_file.h>
 #include <kstringhandler.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <twin.h>
 #endif
 
@@ -562,7 +562,7 @@ static pid_t runCommandInternal( TDEProcess* proc, const KService* service, cons
      return 0;
   }
   TQString bin = KRun::binaryName( binName, true );
-#ifdef Q_WS_X11 // Startup notification doesn't work with QT/E, service isn't needed without Startup notification
+#ifdef TQ_WS_X11 // Startup notification doesn't work with QT/E, service isn't needed without Startup notification
   bool silent;
   TQCString wmclass;
   TDEStartupInfoId id;
@@ -918,7 +918,7 @@ void KRun::init ( const KURL& url, TQWidget* window, const TQCString& asn, mode_
   // loop and do initialization afterwards.
   // Reason: We must complete the constructor before we do anything else.
   m_bInit = true;
-  connect( &m_timer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotTimeout() ) );
+  connect( &m_timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotTimeout() ) );
   m_timer.start( 0, true );
   kdDebug(7010) << " new KRun " << this << " " << url.prettyURL() << " timer=" << &m_timer << endl;
 
@@ -1109,8 +1109,8 @@ void KRun::init()
   // It may be a directory or a file, let's stat
   TDEIO::StatJob *job = TDEIO::stat( m_strURL, true, 0 /* no details */, m_bProgressInfo );
   job->setWindow (d->m_window);
-  connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           this, TQT_SLOT( slotStatResult( TDEIO::Job * ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           this, TQ_SLOT( slotStatResult( TDEIO::Job * ) ) );
   m_job = job;
   kdDebug(7010) << " Job " << job << " is about stating " << m_strURL.url() << endl;
 }
@@ -1158,10 +1158,10 @@ void KRun::scanFile()
 
   TDEIO::TransferJob *job = TDEIO::get( m_strURL, false /*reload*/, m_bProgressInfo );
   job->setWindow (d->m_window);
-  connect(job, TQT_SIGNAL( result(TDEIO::Job *)),
-          this, TQT_SLOT( slotScanFinished(TDEIO::Job *)));
-  connect(job, TQT_SIGNAL( mimetype(TDEIO::Job *, const TQString &)),
-          this, TQT_SLOT( slotScanMimeType(TDEIO::Job *, const TQString &)));
+  connect(job, TQ_SIGNAL( result(TDEIO::Job *)),
+          this, TQ_SLOT( slotScanFinished(TDEIO::Job *)));
+  connect(job, TQ_SIGNAL( mimetype(TDEIO::Job *, const TQString &)),
+          this, TQ_SLOT( slotScanMimeType(TDEIO::Job *, const TQString &)));
   m_job = job;
   kdDebug(7010) << " Job " << job << " is about getting from " << m_strURL.url() << endl;
 }
@@ -1341,14 +1341,14 @@ void KRun::foundMimeType( const TQString& type )
     // (For instance a tar.gz is a directory contained inside a file)
     // It may be a directory or a file, let's stat
     TDEIO::StatJob *job = TDEIO::stat( m_strURL, m_bProgressInfo );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-             this, TQT_SLOT( slotStatResult( TDEIO::Job * ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+             this, TQ_SLOT( slotStatResult( TDEIO::Job * ) ) );
     m_job = job;
 
     return;
   }
 */
-  TDEIO::TransferJob *job = ::tqqt_cast<TDEIO::TransferJob *>( m_job );
+  TDEIO::TransferJob *job = ::tqt_cast<TDEIO::TransferJob *>( m_job );
   if ( job )
   {
      job->putOnHold();
@@ -1471,7 +1471,7 @@ TDEProcessRunner::run(TDEProcess * p, const TQString & binName)
   return (new TDEProcessRunner(p, binName))->pid();
 }
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 pid_t
 TDEProcessRunner::run(TDEProcess * p, const TQString & binName, const TDEStartupInfoId& id )
 {
@@ -1485,15 +1485,15 @@ TDEProcessRunner::TDEProcessRunner(TDEProcess * p, const TQString & _binName )
     binName( _binName )
 {
   TQObject::connect(
-      process_, TQT_SIGNAL(processExited(TDEProcess *)),
-      this,     TQT_SLOT(slotProcessExited(TDEProcess *)));
+      process_, TQ_SIGNAL(processExited(TDEProcess *)),
+      this,     TQ_SLOT(slotProcessExited(TDEProcess *)));
 
   process_->start();
   if ( !process_->pid() )
       slotProcessExited( process_ );
 }
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 TDEProcessRunner::TDEProcessRunner(TDEProcess * p, const TQString & _binName, const TDEStartupInfoId& id )
   : TQObject(),
     process_(p),
@@ -1501,8 +1501,8 @@ TDEProcessRunner::TDEProcessRunner(TDEProcess * p, const TQString & _binName, co
     id_( id )
 {
   TQObject::connect(
-      process_, TQT_SIGNAL(processExited(TDEProcess *)),
-      this,     TQT_SLOT(slotProcessExited(TDEProcess *)));
+      process_, TQ_SIGNAL(processExited(TDEProcess *)),
+      this,     TQ_SLOT(slotProcessExited(TDEProcess *)));
 
   process_->start();
   if ( !process_->pid() )
@@ -1545,7 +1545,7 @@ TDEProcessRunner::slotProcessExited(TDEProcess * p)
       kapp->deref();
     }
   }
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
   if( !id_.none())
   {
       TDEStartupInfoData data;
