@@ -927,7 +927,7 @@ void KService::rebuildKSycoca(TQWidget *parent)
   DCOPClient *client = kapp->dcopClient();
 
   int result = client->callAsync("kded", "tdebuildsycoca", "recreate()",
-               data, TQT_TQOBJECT(&dlg), TQT_SLOT(slotFinished()));
+               data, &dlg, TQ_SLOT(slotFinished()));
 
   if (result)
   {
@@ -939,7 +939,7 @@ KServiceProgressDialog::KServiceProgressDialog(TQWidget *parent, const char *nam
                           const TQString &caption, const TQString &text)
  : KProgressDialog(parent, name, caption, text, true)
 {
-  connect(&m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotProgress()));
+  connect(&m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotProgress()));
   progressBar()->setTotalSteps(20);
   m_timeStep = 700;
   m_timer.start(m_timeStep);
@@ -968,7 +968,7 @@ KServiceProgressDialog::slotFinished()
 {
   progressBar()->setProgress(20);
   m_timer.stop();
-  TQTimer::singleShot(1000, this, TQT_SLOT(close()));
+  TQTimer::singleShot(1000, this, TQ_SLOT(close()));
 }
 
 #include "kservice_p.moc"
