@@ -113,7 +113,7 @@ public:
     /**
      * @deprecated. Use setUserReadOnly(bool).
      */
-    KDE_DEPRECATED void setEnableUserField( bool enable, bool=false ) {
+    TDE_DEPRECATED void setEnableUserField( bool enable, bool=false ) {
 	setUserReadOnly( !enable );
     };
 
