@@ -48,7 +48,7 @@
 #include <kguiitem.h>
 #include <ksqueezedtextlabel.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <twin.h>
 #endif
 
@@ -99,7 +99,7 @@ RenameDlg::RenameDlg(TQWidget *parent, const TQString & _caption,
     // Set "StaysOnTop", because this dialog is typically used in tdeio_uiserver,
     // i.e. in a separate process.
     // ####### This isn't the case anymore - remove?
-#if !defined(Q_WS_QWS) && !defined(Q_WS_WIN) //FIXME(E): Implement for QT Embedded & win32
+#if !defined(TQ_WS_QWS) && !defined(TQ_WS_WIN) //FIXME(E): Implement for QT Embedded & win32
     if (d->modal)
         KWin::setState( winId(), NET::StaysOnTop );
 #endif
@@ -113,42 +113,42 @@ RenameDlg::RenameDlg(TQWidget *parent, const TQString & _caption,
     setCaption( _caption );
 
     d->bCancel = new KPushButton( KStdGuiItem::cancel(), this );
-    connect(d->bCancel, TQT_SIGNAL(clicked()), this, TQT_SLOT(b0Pressed()));
+    connect(d->bCancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(b0Pressed()));
 
     if ( ! (_mode & M_NORENAME ) ) {
         d->bRename = new TQPushButton( i18n( "&Rename" ), this );
         d->bRename->setEnabled(false);
         d->bSuggestNewName = new TQPushButton( i18n( "Suggest New &Name" ), this );
-        connect(d->bSuggestNewName, TQT_SIGNAL(clicked()), this, TQT_SLOT(b8Pressed()));
-        connect(d->bRename, TQT_SIGNAL(clicked()), this, TQT_SLOT(b1Pressed()));
+        connect(d->bSuggestNewName, TQ_SIGNAL(clicked()), this, TQ_SLOT(b8Pressed()));
+        connect(d->bRename, TQ_SIGNAL(clicked()), this, TQ_SLOT(b1Pressed()));
     }
 
     if ( ( _mode & M_MULTI ) && ( _mode & M_SKIP ) ) {
         d->bSkip = new TQPushButton( i18n( "&Skip" ), this );
-        connect(d->bSkip, TQT_SIGNAL(clicked()), this, TQT_SLOT(b2Pressed()));
+        connect(d->bSkip, TQ_SIGNAL(clicked()), this, TQ_SLOT(b2Pressed()));
 
         d->bAutoSkip = new TQPushButton( i18n( "&Auto Skip" ), this );
-        connect(d->bAutoSkip, TQT_SIGNAL(clicked()), this, TQT_SLOT(b3Pressed()));
+        connect(d->bAutoSkip, TQ_SIGNAL(clicked()), this, TQ_SLOT(b3Pressed()));
     }
 
     if ( _mode & M_OVERWRITE ) {
         d->bOverwrite = new TQPushButton( i18n( "&Overwrite" ), this );
-        connect(d->bOverwrite, TQT_SIGNAL(clicked()), this, TQT_SLOT(b4Pressed()));
+        connect(d->bOverwrite, TQ_SIGNAL(clicked()), this, TQ_SLOT(b4Pressed()));
 
         if ( _mode & M_MULTI ) {
             d->bOverwriteAll = new TQPushButton( i18n( "O&verwrite All" ), this );
-            connect(d->bOverwriteAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(b5Pressed()));
+            connect(d->bOverwriteAll, TQ_SIGNAL(clicked()), this, TQ_SLOT(b5Pressed()));
         }
     }
 
     if ( _mode & M_RESUME ) {
         d->bResume = new TQPushButton( i18n( "&Resume" ), this );
-        connect(d->bResume, TQT_SIGNAL(clicked()), this, TQT_SLOT(b6Pressed()));
+        connect(d->bResume, TQ_SIGNAL(clicked()), this, TQ_SLOT(b6Pressed()));
 
         if ( _mode & M_MULTI )
         {
             d->bResumeAll = new TQPushButton( i18n( "R&esume All" ), this );
-            connect(d->bResumeAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(b7Pressed()));
+            connect(d->bResumeAll, TQ_SIGNAL(clicked()), this, TQ_SLOT(b7Pressed()));
         }
     }
 
@@ -194,12 +194,12 @@ RenameDlg::RenameDlg(TQWidget *parent, const TQString & _caption,
                     lib->unload();
                     continue;
                 }
-                TQObject *obj = factory->create( TQT_TQOBJECT(this), (*it)->name().latin1() );
+                TQObject *obj = factory->create( this, (*it)->name().latin1() );
                 if(!obj) {
                     lib->unload();
                     continue;
                 }
-                RenameDlgPlugin *plugin = static_cast<RenameDlgPlugin *>(TQT_TQWIDGET(obj));
+                RenameDlgPlugin *plugin = static_cast<RenameDlgPlugin *>(static_cast<TQWidget*>(obj));
                 if(!plugin ){
                     delete obj;
                     continue;
@@ -223,7 +223,7 @@ RenameDlg::RenameDlg(TQWidget *parent, const TQString & _caption,
             // No plugin found, build default dialog
             TQGridLayout * gridLayout = new TQGridLayout( 0L, 9, 2, KDialog::marginHint(),
                                                         KDialog::spacingHint() );
-            pLayout->addLayout(TQT_TQLAYOUT(gridLayout));
+            pLayout->addLayout(gridLayout);
             gridLayout->setColStretch(0,0);
             gridLayout->setColStretch(1,10);
 
@@ -325,8 +325,8 @@ RenameDlg::RenameDlg(TQWidget *parent, const TQString & _caption,
     TQString fileName = d->dest.fileName();
     d->m_pLineEdit->setText( TDEIO::decodeFileName( fileName ) );
     if ( d->bRename || d->bOverwrite )
-        connect(d->m_pLineEdit, TQT_SIGNAL(textChanged(const TQString &)),
-                TQT_SLOT(enableRenameButton(const TQString &)));
+        connect(d->m_pLineEdit, TQ_SIGNAL(textChanged(const TQString &)),
+                TQ_SLOT(enableRenameButton(const TQString &)));
     if ( d->bSuggestNewName )
     {
         layout2->addWidget( d->bSuggestNewName );
