@@ -951,7 +951,7 @@ KFilePlugin* KFileMetaInfoProvider::loadPlugin( const TQString& mimeType, const
         return 0;
 
     KFilePlugin* plugin = KParts::ComponentFactory::createInstanceFromService<KFilePlugin>
-                          ( service, TQT_TQOBJECT(this), mimeType.local8Bit() );
+                          ( service, this, mimeType.local8Bit() );
     if (!plugin)
         kdWarning(7033) << "error loading the plugin from " << service->desktopEntryPath() << endl;
 
