@@ -160,7 +160,7 @@ static void createTestFile( const TQString& path )
     TQFile f( path );
     if ( !f.open( IO_WriteOnly ) )
         kdFatal() << "Can't create " << path << endl;
-    f.tqwriteBlock( "Hello world", 11 );
+    f.writeBlock( "Hello world", 11 );
     f.close();
     setTimeStamp( path );
 }
@@ -195,8 +195,8 @@ void JobTest::get()
     KURL u; u.setPath( filePath );
     m_result = -1;
     TDEIO::StoredTransferJob* job = TDEIO::storedGet( u );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
-            this, TQT_SLOT( slotGetResult( TDEIO::Job* ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ),
+            this, TQ_SLOT( slotGetResult( TDEIO::Job* ) ) );
     kapp->eventLoop()->enterLoop();
     assert( m_result == 0 ); // no error
     assert( m_data.size() == 11 );
@@ -498,8 +498,8 @@ void JobTest::listRecursive()
     KURL u;
     u.setPath( src );
     TDEIO::ListJob* job = TDEIO::listRecursive( u );
-    connect( job, TQT_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ),
-             TQT_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ) );
+    connect( job, TQ_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ),
+             TQ_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ) );
     bool ok = TDEIO::NetAccess::synchronousRun( job, 0 );
     assert( ok );
     m_names.sort();
@@ -565,8 +565,8 @@ void JobTest::copyFileToSystem( bool resolve_local_urls )
 
     // copy the file with file_copy
     TDEIO::FileCopyJob* job = TDEIO::file_copy( u, d );
-    connect( job, TQT_SIGNAL(mimetype(TDEIO::Job*,const TQString&)),
-             this, TQT_SLOT(slotMimetype(TDEIO::Job*,const TQString&)) );
+    connect( job, TQ_SIGNAL(mimetype(TDEIO::Job*,const TQString&)),
+             this, TQ_SLOT(slotMimetype(TDEIO::Job*,const TQString&)) );
     bool ok = TDEIO::NetAccess::synchronousRun( job, 0 );
     assert( ok );
 
