@@ -270,7 +270,7 @@ int main(int argc, char **argv)
     // a search using the default search engine
     // 'ls' is a bit of a special case though, due to the toplevel domain called 'ls'
     filter( "cp", "http://www.google.com/search?q=cp&ie=UTF-8&oe=UTF-8", KURIFilterData::NET_PROTOCOL,
-            TQStringList(), 0, false /* don't check for executables, see konq_misc.cc */ );
+            TQStringList(), 0, false /* don't check for executables, see konq_misc.cpp */ );
 
     // Executable tests - No IKWS in minicli
     filter( "cp", "cp", KURIFilterData::EXECUTABLE, minicliFilters );
@@ -288,14 +288,14 @@ int main(int argc, char **argv)
     setenv( "SOMEVAR", "/somevar", 0 );
     setenv( "ETC", "/etc", 0 );
 
-    TQCString qtdir=getenv("QTDIR");
+    TQCString qtdir=getenv("TQTDIR");
     TQCString home = getenv("HOME");
     TQCString tdehome = getenv("TDEHOME");
 
     filter( "$SOMEVAR/tdelibs/tdeio", 0, KURIFilterData::ERROR ); // note: this dir doesn't exist...
     filter( "$ETC/passwd", "/etc/passwd", KURIFilterData::LOCAL_FILE );
     if( !qtdir.isEmpty() ) {
-        filter( "$QTDIR/doc/html/functions.html#s", TQCString("file://")+qtdir+"/doc/html/functions.html#s", KURIFilterData::LOCAL_FILE );
+        filter( "$TQTDIR/doc/html/functions.html#s", TQCString("file://")+qtdir+"/doc/html/functions.html#s", KURIFilterData::LOCAL_FILE );
     }
     filter( "http://www.kde.org/$USER", "http://www.kde.org/$USER", KURIFilterData::NET_PROTOCOL ); // no expansion
 
@@ -336,7 +336,7 @@ int main(int argc, char **argv)
     // itself if the requested environment variable
     // is not already set.
     if( !qtdir.isEmpty() ) {
-        filter( "$QTDIR", 0, KURIFilterData::LOCAL_DIR, "tdeshorturifilter" ); //use specific filter.
+        filter( "$TQTDIR", 0, KURIFilterData::LOCAL_DIR, "tdeshorturifilter" ); //use specific filter.
     }
     filter( "$HOME", home, KURIFilterData::LOCAL_DIR, "tdeshorturifilter" ); //use specific filter.
 
