@@ -140,7 +140,7 @@ KMdiDockContainer::~KMdiDockContainer()
 		KDockWidget *w = it.key();
 		if ( m_overlapButtons.contains( w ) )
 		{
-			( ::tqqt_cast<KDockWidgetHeader*>( w->getHeader() ) )->removeButton( m_overlapButtons[w] );
+			( ::tqt_cast<KDockWidgetHeader*>( w->getHeader() ) )->removeButton( m_overlapButtons[w] );
 			m_overlapButtons.remove( w );
 		}
 		m_map.remove( w );
@@ -172,7 +172,7 @@ void KMdiDockContainer::init()
 	// try to restore splitter size
 	if ( parentDockWidget() && parentDockWidget()->parent() )
 	{
-		KDockSplitter * sp = ::tqqt_cast<KDockSplitter*>( parentDockWidget()->parent() );
+		KDockSplitter * sp = ::tqt_cast<KDockSplitter*>( parentDockWidget()->parent() );
 		if ( sp )
 			sp->setSeparatorPosX( m_separatorPos );
 	}
@@ -207,12 +207,12 @@ void KMdiDockContainer::insertWidget ( KDockWidget *dwdg, TQPixmap pixmap, const
 		if ( ( ( KDockWidget* ) parentWidget() ) ->mayBeShow() )
 			( ( KDockWidget* ) parentWidget() ) ->dockBack();
 
-		if ( ::tqqt_cast<KDockWidgetHeader*>(w->getHeader()) )
+		if ( ::tqt_cast<KDockWidgetHeader*>(w->getHeader()) )
 		{
 			kdDebug( 760 ) << k_funcinfo << "The dockwidget we're adding has a header" << endl;
 			kdDebug( 760 ) << k_funcinfo << "Adding our overlap mode button to it" << endl;
 
-			KDockWidgetHeader *hdr = ::tqqt_cast<KDockWidgetHeader*>( w->getHeader() );
+			KDockWidgetHeader *hdr = ::tqt_cast<KDockWidgetHeader*>( w->getHeader() );
 			KDockButton_Private *btn = new KDockButton_Private( hdr, "OverlapButton" );
 
 			TQToolTip::add( btn, i18n( "Switch between overlap and side by side mode", "Overlap" ) );
@@ -223,7 +223,7 @@ void KMdiDockContainer::insertWidget ( KDockWidget *dwdg, TQPixmap pixmap, const
 			m_overlapButtons.insert( w, btn );
 			btn->setOn( !isOverlapMode() );
 
-			connect( btn, TQT_SIGNAL( clicked() ), this, TQT_SLOT( changeOverlapMode() ) );
+			connect( btn, TQ_SIGNAL( clicked() ), this, TQ_SLOT( changeOverlapMode() ) );
 		}
 
 		m_tb->appendTab( pixmap.isNull() ? SmallIcon( "misc" ) : pixmap, tab, w->tabPageLabel() );
@@ -231,7 +231,7 @@ void KMdiDockContainer::insertWidget ( KDockWidget *dwdg, TQPixmap pixmap, const
 		kdDebug( 760 ) << k_funcinfo << "Added tab with label " << w->tabPageLabel() <<
 			" to the tabbar" << endl;
 
-		connect( m_tb->tab( tab ), TQT_SIGNAL( clicked( int ) ), this, TQT_SLOT( tabClicked( int ) ) );
+		connect( m_tb->tab( tab ), TQ_SIGNAL( clicked( int ) ), this, TQ_SLOT( tabClicked( int ) ) );
 
 		mTabCnt++;
 		m_inserted = tab;
@@ -252,7 +252,7 @@ bool KMdiDockContainer::eventFilter( TQObject *obj, TQEvent *event )
 	{
 	case TQEvent::MouseButtonPress:
 	{
-		KMultiTabBarTab* kmtbTab = tqt_dynamic_cast<KMultiTabBarTab*>( obj );
+		KMultiTabBarTab* kmtbTab = dynamic_cast<KMultiTabBarTab*>( obj );
 		if ( !kmtbTab )
 		{
 			kdDebug(760) << k_funcinfo << "Got a mouse button press but we have no tab" << endl;
@@ -272,7 +272,7 @@ bool KMdiDockContainer::eventFilter( TQObject *obj, TQEvent *event )
 			break;
 		}
 
-		KDockWidgetHeader *hdr = ::tqqt_cast<KDockWidgetHeader*>( w->getHeader() );
+		KDockWidgetHeader *hdr = ::tqt_cast<KDockWidgetHeader*>( w->getHeader() );
 		if ( !hdr )
 		{
 			kdDebug(760) << "Wrong header type in KMdiDockContainer::eventFilter" << endl;
@@ -280,7 +280,7 @@ bool KMdiDockContainer::eventFilter( TQObject *obj, TQEvent *event )
 		}
 
 		m_dockManager = w->dockManager();
-		m_dragPanel = TQT_TQOBJECT(hdr->dragPanel());
+		m_dragPanel = hdr->dragPanel();
 
 		if ( m_dragPanel )
 			m_movingState = WaitingForMoveStart;
@@ -303,7 +303,7 @@ bool KMdiDockContainer::eventFilter( TQObject *obj, TQEvent *event )
 			TQPoint p( ( ( TQMouseEvent* ) event )->pos() - m_startEvent->pos() );
 			if ( p.manhattanLength() > TDEGlobalSettings::dndEventDelay() )
 			{
-				m_dockManager->eventFilter( m_dragPanel, TQT_TQEVENT(m_startEvent) );
+				m_dockManager->eventFilter( m_dragPanel, static_cast<TQEvent*>(m_startEvent) );
 				m_dockManager->eventFilter( m_dragPanel, event );
 				m_movingState = Moving;
 			}
@@ -332,7 +332,7 @@ void KMdiDockContainer::showWidget( KDockWidget *w )
 
 void KMdiDockContainer::changeOverlapMode()
 {
-	const KDockButton_Private * btn = tqt_dynamic_cast<const KDockButton_Private*>( sender() );
+	const KDockButton_Private * btn = dynamic_cast<const KDockButton_Private*>( sender() );
 
 	if ( !btn )
 		return ;
@@ -387,7 +387,7 @@ void KMdiDockContainer::removeWidget( KDockWidget* dwdg )
 	m_revMap.remove( id );
 	if ( m_overlapButtons.contains( w ) )
 	{
-		( ::tqqt_cast<KDockWidgetHeader*>( w->getHeader() ) )->removeButton( m_overlapButtons[ w ] );
+		( ::tqt_cast<KDockWidgetHeader*>( w->getHeader() ) )->removeButton( m_overlapButtons[ w ] );
 		m_overlapButtons.remove( w );
 	}
 	KDockContainer::removeWidget( w );
@@ -442,7 +442,7 @@ void KMdiDockContainer::tabClicked( int t )
 		if ( m_ws->widget( t ) )
 		{
 			m_ws->raiseWidget( t );
-			KDockWidget * tmpDw = ::tqqt_cast<KDockWidget*>( m_ws->widget( t ) );
+			KDockWidget * tmpDw = ::tqt_cast<KDockWidget*>( m_ws->widget( t ) );
 			if ( tmpDw )
 			{
 				if ( tmpDw->getWidget() )
@@ -467,7 +467,7 @@ void KMdiDockContainer::tabClicked( int t )
 		// try save splitter position
 		if ( parentDockWidget() && parentDockWidget()->parent() )
 		{
-			KDockSplitter * sp = ::tqqt_cast<KDockSplitter*>( parentDockWidget()->parent() );
+			KDockSplitter * sp = ::tqt_cast<KDockSplitter*>( parentDockWidget()->parent() );
 			if ( sp )
 				m_separatorPos = sp->separatorPos();
 		}
@@ -613,7 +613,7 @@ void KMdiDockContainer::load( TQDomElement& dockEl )
 			if ( it.key() ->name() == raise )
 			{
 				m_delayedRaise = it.data();
-				TQTimer::singleShot( 0, this, TQT_SLOT( delayedRaise() ) );
+				TQTimer::singleShot( 0, this, TQ_SLOT( delayedRaise() ) );
 				kdDebug( 760 ) << k_funcinfo << "raising " << it.key()->name() << endl;
 				break;
 			}
@@ -621,7 +621,7 @@ void KMdiDockContainer::load( TQDomElement& dockEl )
 
 	}
 	if ( m_delayedRaise == -1 )
-		TQTimer::singleShot( 0, this, TQT_SLOT( init() ) );
+		TQTimer::singleShot( 0, this, TQ_SLOT( init() ) );
 }
 
 void KMdiDockContainer::save( TDEConfig* cfg, const TQString& group_or_prefix )
@@ -638,7 +638,7 @@ void KMdiDockContainer::save( TDEConfig* cfg, const TQString& group_or_prefix )
 	// try to save the splitter position
 	if ( parentDockWidget() && parentDockWidget() ->parent() )
 	{
-		KDockSplitter * sp = ::tqqt_cast<KDockSplitter*>( parentDockWidget() -> parent() );
+		KDockSplitter * sp = ::tqt_cast<KDockSplitter*>( parentDockWidget() -> parent() );
 		if ( sp )
 			cfg->writeEntry( "separatorPosition", m_separatorPos );
 	}
@@ -744,7 +744,7 @@ void KMdiDockContainer::load( TDEConfig* cfg, const TQString& group_or_prefix )
 				        kapp->syncX();*/
 
 				m_delayedRaise = it.data();
-				TQTimer::singleShot( 0, this, TQT_SLOT( delayedRaise() ) );
+				TQTimer::singleShot( 0, this, TQ_SLOT( delayedRaise() ) );
 				kdDebug( 760 ) << k_funcinfo << "raising" << it.key() ->name() << endl;
 				break;
 			}
@@ -752,7 +752,7 @@ void KMdiDockContainer::load( TDEConfig* cfg, const TQString& group_or_prefix )
 
 	}
 	if ( m_delayedRaise == -1 )
-		TQTimer::singleShot( 0, this, TQT_SLOT( init() ) );
+		TQTimer::singleShot( 0, this, TQ_SLOT( init() ) );
 	cfg->setGroup( grp );
 
 }
@@ -794,7 +794,7 @@ void KMdiDockContainer::toggle()
 		kdDebug( 760 ) << k_funcinfo << "lowering tab" << endl;
 		m_tb->setTab( oldtab, false );
 		tabClicked( oldtab );
-		KMdiMainFrm *mainFrm = tqt_dynamic_cast<KMdiMainFrm*>( m_mainWin );
+		KMdiMainFrm *mainFrm = dynamic_cast<KMdiMainFrm*>( m_mainWin );
 		if ( mainFrm && mainFrm->activeWindow() )
 			mainFrm->activeWindow()->setFocus();
 	}
