@@ -36,7 +36,7 @@ class KDockButton_Private;
 
 class KMDI_EXPORT KMdiDockContainer: public TQWidget, public KDockContainer
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	KMdiDockContainer( TQWidget *parent, TQWidget *win, int position, int flags );
