@@ -10,7 +10,7 @@ class TQWidget;
 
 class Shell : public TDEMainWindow
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   Shell();
   virtual ~Shell();
