@@ -11,7 +11,7 @@ class GUIActivateEvent;
 
 class Part1 : public KParts::ReadOnlyPart
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   Part1( TQObject *parent, TQWidget * parentWidget );
   virtual ~Part1();
@@ -26,7 +26,7 @@ protected:
 
 class Part2 : public KParts::Part
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   Part2( TQObject *parent, TQWidget * parentWidget );
   virtual ~Part2();
