@@ -227,19 +227,19 @@ static const short yycheck[] = {     4,
 /* We think this test detects Watcom and Microsoft C.  */
 /* This used to test MSDOS, but that is a bad idea
    since that symbol is in the user namespace.  */
-#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if defined (_MSDOS) || defined (_MSDOS_)
 #if 0 /* No need for malloc.h, which pollutes the namespace;
 	 instead, just don't use alloca.  */
 #include <malloc.h>
 #endif
-#else /* not MSDOS, or __TURBOC__ */
+#else /* not MSDOS */
 #if defined(_AIX)
 /* I don't know what this was needed for, but it pollutes the namespace.
    So I turned it off.   rms, 2 May 1997.  */
 /* #include <malloc.h>  */
  #pragma alloca
 #define YYSTACK_USE_ALLOCA
-#else /* not MSDOS, or __TURBOC__, or _AIX */
+#else /* not MSDOS or _AIX */
 #if 0
 #ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
 		 and on HPUX 10.  Eventually we can turn this on.  */
@@ -248,7 +248,7 @@ static const short yycheck[] = {     4,
 #endif /* __hpux */
 #endif
 #endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not MSDOS */
 #endif /* not sparc */
 #endif /* not GNU C */
 #endif /* alloca not defined */
