@@ -43,7 +43,7 @@ KMSpecialManager::KMSpecialManager(KMManager *parent, const char *name)
 bool KMSpecialManager::savePrinters()
 {
 	// for root, use a global location.
-	QString	confname;
+	TQString	confname;
 	if (getuid() == 0)
 	{
 		confname = locate("data", "tdeprint/specials.desktop");
@@ -139,7 +139,7 @@ bool KMSpecialManager::loadDesktopFile(const TQString& filename)
 	int	n = conf.readNumEntry("Number",0);
 	for (int i=0;i<n;i++)
 	{
-		QString	grpname = TQString::fromLatin1("Printer %1").arg(i);
+		TQString	grpname = TQString::fromLatin1("Printer %1").arg(i);
 		if (!conf.hasGroup(grpname)) continue;
 		conf.setGroup(grpname);
 		KMPrinter	*printer = new KMPrinter;
@@ -213,7 +213,7 @@ DrMain* KMSpecialManager::loadDriver(KMPrinter *pr)
 
 TQString KMSpecialManager::setupCommand(const TQString& cmd, const TQMap<TQString,TQString>& opts)
 {
-	QString	s(cmd);
+	TQString	s(cmd);
 	if (!s.isEmpty())
 	{
 		KXmlCommand	*xmlCmd = loadCommand(cmd);
