@@ -94,7 +94,7 @@ int TDEIconSelectAction::plug(TQWidget* widget, int index)
 		bar->getButton(id)->setPopup(d->m_menu, true);
 		bar->setItemEnabled(id, isEnabled());
 		addContainer(bar, id);
-		connect(bar, TQT_SIGNAL(destroyed()), TQT_SLOT(slotDestroyed()));
+		connect(bar, TQ_SIGNAL(destroyed()), TQ_SLOT(slotDestroyed()));
 
 		value = containerCount()-1;
 	}
