@@ -27,7 +27,7 @@ class DrMain;
 
 class KMDriverDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KMDriverDialog(TQWidget *parent = 0, const char *name = 0);
 	~KMDriverDialog();
