@@ -105,7 +105,7 @@ KMJobViewer::KMJobViewer(TQWidget *parent, const char *name)
 		resize( conf->readSizeEntry( "Size", &defSize ) );
 	}
 
-	connect(KMFactory::self()->manager(), TQT_SIGNAL(printerListUpdated()),TQT_SLOT(slotPrinterListUpdated()));
+	connect(KMFactory::self()->manager(), TQ_SIGNAL(printerListUpdated()),TQ_SLOT(slotPrinterListUpdated()));
 }
 
 KMJobViewer::~KMJobViewer()
@@ -240,18 +240,18 @@ void KMJobViewer::init()
 		m_view->addColumn(i18n("Status", "State"));
 		m_view->addColumn(i18n("Size (KB)"));
 		m_view->addColumn(i18n("Page(s)"));
-		m_view->setColumnAlignment(5,Qt::AlignRight|Qt::AlignVCenter);
-		connect( m_view, TQT_SIGNAL( dropped( TQDropEvent*, TQListViewItem* ) ), TQT_SLOT( slotDropped( TQDropEvent*, TQListViewItem* ) ) );
+		m_view->setColumnAlignment(5,TQt::AlignRight|TQt::AlignVCenter);
+		connect( m_view, TQ_SIGNAL( dropped( TQDropEvent*, TQListViewItem* ) ), TQ_SLOT( slotDropped( TQDropEvent*, TQListViewItem* ) ) );
 		//m_view->addColumn(i18n("Printer"));
-		//m_view->setColumnAlignment(6,Qt::AlignRight|Qt::AlignVCenter);
+		//m_view->setColumnAlignment(6,TQt::AlignRight|TQt::AlignVCenter);
 		KMFactory::self()->uiManager()->setupJobViewer(m_view);
 		m_view->setFrameStyle(TQFrame::WinPanel|TQFrame::Sunken);
 		m_view->setLineWidth(1);
 		m_view->setSorting(0);
 		m_view->setAllColumnsShowFocus(true);
 		m_view->setSelectionMode(TQListView::Extended);
-		connect(m_view,TQT_SIGNAL(selectionChanged()),TQT_SLOT(slotSelectionChanged()));
-		connect(m_view,TQT_SIGNAL(rightButtonPressed(TQListViewItem*,const TQPoint&,int)),TQT_SLOT(slotRightClicked(TQListViewItem*,const TQPoint&,int)));
+		connect(m_view,TQ_SIGNAL(selectionChanged()),TQ_SLOT(slotSelectionChanged()));
+		connect(m_view,TQ_SIGNAL(rightButtonPressed(TQListViewItem*,const TQPoint&,int)),TQ_SLOT(slotRightClicked(TQListViewItem*,const TQPoint&,int)));
 		setCentralWidget(m_view);
 	}
 
@@ -261,26 +261,26 @@ void KMJobViewer::init()
 void KMJobViewer::initActions()
 {
 	// job actions
-	TDEAction	*hact = new TDEAction(i18n("&Hold"),"process-stop",0,TQT_TQOBJECT(this),TQT_SLOT(slotHold()),actionCollection(),"job_hold");
-	TDEAction	*ract = new TDEAction(i18n("&Resume"),"system-run",0,TQT_TQOBJECT(this),TQT_SLOT(slotResume()),actionCollection(),"job_resume");
-	TDEAction	*dact = new TDEAction(i18n("Remo&ve"),"edittrash",Qt::Key_Delete,TQT_TQOBJECT(this),TQT_SLOT(slotRemove()),actionCollection(),"job_remove");
-	TDEAction *sact = new TDEAction(i18n("Res&tart"),"edit-redo",0,TQT_TQOBJECT(this),TQT_SLOT(slotRestart()),actionCollection(),"job_restart");
+	TDEAction	*hact = new TDEAction(i18n("&Hold"),"process-stop",0,this,TQ_SLOT(slotHold()),actionCollection(),"job_hold");
+	TDEAction	*ract = new TDEAction(i18n("&Resume"),"system-run",0,this,TQ_SLOT(slotResume()),actionCollection(),"job_resume");
+	TDEAction	*dact = new TDEAction(i18n("Remo&ve"),"edittrash",TQt::Key_Delete,this,TQ_SLOT(slotRemove()),actionCollection(),"job_remove");
+	TDEAction *sact = new TDEAction(i18n("Res&tart"),"edit-redo",0,this,TQ_SLOT(slotRestart()),actionCollection(),"job_restart");
 	TDEActionMenu *mact = new TDEActionMenu(i18n("&Move to Printer"),"document-print",actionCollection(),"job_move");
 	mact->setDelayed(false);
-	connect(mact->popupMenu(),TQT_SIGNAL(activated(int)),TQT_SLOT(slotMove(int)));
-	connect(mact->popupMenu(),TQT_SIGNAL(aboutToShow()),KMTimer::self(),TQT_SLOT(hold()));
-	connect(mact->popupMenu(),TQT_SIGNAL(aboutToHide()),KMTimer::self(),TQT_SLOT(release()));
-	connect(mact->popupMenu(),TQT_SIGNAL(aboutToShow()),TQT_SLOT(slotShowMoveMenu()));
+	connect(mact->popupMenu(),TQ_SIGNAL(activated(int)),TQ_SLOT(slotMove(int)));
+	connect(mact->popupMenu(),TQ_SIGNAL(aboutToShow()),KMTimer::self(),TQ_SLOT(hold()));
+	connect(mact->popupMenu(),TQ_SIGNAL(aboutToHide()),KMTimer::self(),TQ_SLOT(release()));
+	connect(mact->popupMenu(),TQ_SIGNAL(aboutToShow()),TQ_SLOT(slotShowMoveMenu()));
 	TDEToggleAction	*tact = new TDEToggleAction(i18n("&Toggle Completed Jobs"),"history",0,actionCollection(),"view_completed");
 	tact->setEnabled(m_manager->actions() & KMJob::ShowCompleted);
-	connect(tact,TQT_SIGNAL(toggled(bool)),TQT_SLOT(slotShowCompleted(bool)));
+	connect(tact,TQ_SIGNAL(toggled(bool)),TQ_SLOT(slotShowCompleted(bool)));
 	TDEToggleAction	*uact = new TDEToggleAction(i18n("Show Only User Jobs"), "preferences-desktop-personal", 0, actionCollection(), "view_user_jobs");
 	uact->setCheckedState(KGuiItem(i18n("Hide Only User Jobs"),"preferences-desktop-personal"));
-	connect(uact, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotUserOnly(bool)));
+	connect(uact, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotUserOnly(bool)));
 	m_userfield = new TQLineEdit(0);
 	m_userfield->setText(getenv("USER"));
-	connect(m_userfield, TQT_SIGNAL(returnPressed()), TQT_SLOT(slotUserChanged()));
-	connect(uact, TQT_SIGNAL(toggled(bool)), m_userfield, TQT_SLOT(setEnabled(bool)));
+	connect(m_userfield, TQ_SIGNAL(returnPressed()), TQ_SLOT(slotUserChanged()));
+	connect(uact, TQ_SIGNAL(toggled(bool)), m_userfield, TQ_SLOT(setEnabled(bool)));
 	m_userfield->setEnabled(false);
 	m_userfield->setSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
 	KWidgetAction	*ufact = new KWidgetAction(m_userfield, i18n("User Name"), 0, 0, 0, actionCollection(), "view_username");
@@ -288,8 +288,8 @@ void KMJobViewer::initActions()
 	if (!m_pop)
 	{
 		m_pop = new TQPopupMenu(this);
-		connect(m_pop,TQT_SIGNAL(aboutToShow()),KMTimer::self(),TQT_SLOT(hold()));
-		connect(m_pop,TQT_SIGNAL(aboutToHide()),KMTimer::self(),TQT_SLOT(release()));
+		connect(m_pop,TQ_SIGNAL(aboutToShow()),KMTimer::self(),TQ_SLOT(hold()));
+		connect(m_pop,TQ_SIGNAL(aboutToHide()),KMTimer::self(),TQ_SLOT(release()));
 		hact->plug(m_pop);
 		ract->plug(m_pop);
 		m_pop->insertSeparator();
@@ -302,10 +302,10 @@ void KMJobViewer::initActions()
 	// Filter actions
 	TDEActionMenu	*fact = new TDEActionMenu(i18n("&Select Printer"), "tdeprint_printer", actionCollection(), "filter_modify");
 	fact->setDelayed(false);
-	connect(fact->popupMenu(),TQT_SIGNAL(activated(int)),TQT_SLOT(slotPrinterSelected(int)));
-	connect(fact->popupMenu(),TQT_SIGNAL(aboutToShow()),KMTimer::self(),TQT_SLOT(hold()));
-	connect(fact->popupMenu(),TQT_SIGNAL(aboutToHide()),KMTimer::self(),TQT_SLOT(release()));
-	connect(fact->popupMenu(),TQT_SIGNAL(aboutToShow()),TQT_SLOT(slotShowPrinterMenu()));
+	connect(fact->popupMenu(),TQ_SIGNAL(activated(int)),TQ_SLOT(slotPrinterSelected(int)));
+	connect(fact->popupMenu(),TQ_SIGNAL(aboutToShow()),KMTimer::self(),TQ_SLOT(hold()));
+	connect(fact->popupMenu(),TQ_SIGNAL(aboutToHide()),KMTimer::self(),TQ_SLOT(release()));
+	connect(fact->popupMenu(),TQ_SIGNAL(aboutToShow()),TQ_SLOT(slotShowPrinterMenu()));
 
 	if (!m_standalone)
 	{
@@ -324,12 +324,12 @@ void KMJobViewer::initActions()
 	}
 	else
 	{// stand-alone application
-		KStdAction::quit(TQT_TQOBJECT(kapp),TQT_SLOT(quit()),actionCollection());
-		KStdAction::close(TQT_TQOBJECT(this),TQT_SLOT(slotClose()),actionCollection());
-		KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), actionCollection());
+		KStdAction::quit(kapp,TQ_SLOT(quit()),actionCollection());
+		KStdAction::close(this,TQ_SLOT(slotClose()),actionCollection());
+		KStdAction::preferences(this, TQ_SLOT(slotConfigure()), actionCollection());
 
 		// refresh action
-		new TDEAction(i18n("Refresh"),"reload",0,TQT_TQOBJECT(this),TQT_SLOT(slotRefresh()),actionCollection(),"refresh");
+		new TDEAction(i18n("Refresh"),"reload",0,this,TQ_SLOT(slotRefresh()),actionCollection(),"refresh");
 
 		// create status bar
 		KStatusBar	*statusbar = statusBar();
@@ -338,7 +338,7 @@ void KMJobViewer::initActions()
 		TDEConfig *conf = KMFactory::self()->printConfig();
 		conf->setGroup("Jobs");
 		m_stickybox->setChecked(conf->readBoolEntry("KeepWindow",false));
-		connect(m_stickybox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotKeepWindowChange(bool)));
+		connect(m_stickybox, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotKeepWindowChange(bool)));
 		statusbar->addWidget( m_stickybox, 1, false );
 		statusbar->insertItem(" " + i18n("Max.: %1").arg(i18n("Unlimited"))+ " ", 0, 0, true);
 		statusbar->setItemFixed(0);
@@ -617,7 +617,7 @@ void KMJobViewer::loadPluginActions()
 	for (TQValueListIterator<TDEAction*> it=acts.begin(); it!=acts.end(); ++it)
 	{
 		// connect the action to this
-		connect((*it), TQT_SIGNAL(activated(int)), TQT_SLOT(pluginActionActivated(int)));
+		connect((*it), TQ_SIGNAL(activated(int)), TQ_SLOT(pluginActionActivated(int)));
 
 		// should add it to the toolbar and menubar
 		(*it)->plug(toolBar(), toolbarindex++);
