@@ -22,7 +22,7 @@ class TQPopupMenu;
 
 class HelpWindow : public TDEMainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     HelpWindow( const TQString& home_,  const TQString& path, TQWidget* parent = 0, const char *name=0 );
     ~HelpWindow();
