@@ -148,7 +148,7 @@ AsteroidStyle::applicationPolish(const TQStyleControlElementData&, ControlElemen
 	TQPalette wp = TQApplication::palette();
 	wp.setColor(TQColorGroup::Dark, TQColor(128, 128, 128));
 	wp.setColor(TQColorGroup::Mid, wp.active().color(TQColorGroup::Button).dark(150));	// Which GUI element(s) does this correspond to?
-	TQApplication::setPalette( wp, TRUE );
+	TQApplication::setPalette( wp, true );
 }
 
 /*! \reimp
@@ -1015,8 +1015,7 @@ void AsteroidStyle::drawControl(ControlElement ce,
 	
 		const TQTab * t = o.tab();
 		bool selected = sf & Style_Selected;
-		bool lastTab = (ceData.tabBarData.identIndexMap[t->identifier()] == ceData.tabBarData.tabCount-1) ?
-				TRUE : FALSE;
+		bool lastTab = (ceData.tabBarData.identIndexMap[t->identifier()] == ceData.tabBarData.tabCount-1);
 		TQRect r2( r );
 		if ( ceData.tabBarData.shape == TQTabBar::RoundedAbove ) {
 			p->setPen( cg.light() );
@@ -1875,8 +1874,8 @@ void AsteroidStyle::drawComplexControl(ComplexControl cc,
 				if ( !verticalLine ) {
 				// make 128*1 and 1*128 bitmaps that can be used for
 				// drawing the right sort of lines.
-				verticalLine = new TQBitmap( 1, 129, TRUE );
-				horizontalLine = new TQBitmap( 128, 1, TRUE );
+				verticalLine = new TQBitmap( 1, 129, true );
+				horizontalLine = new TQBitmap( 128, 1, true );
 				TQPointArray a( 64 );
 				TQPainter p;
 				p.begin( verticalLine );
