@@ -33,7 +33,7 @@ DEALINGS IN THE SOFTWARE.
 
 #include "highcontrastconfig.h"
 
-extern "C" KDE_EXPORT TQWidget* 
+extern "C" TDE_EXPORT TQWidget* 
 allocate_tdestyle_config(TQWidget* parent)
 {
     return new HighContrastStyleConfig(parent);
