@@ -73,7 +73,7 @@ class HighContrastStylePlugin : public TQStylePlugin
 		}
 };
 
-KDE_Q_EXPORT_PLUGIN (HighContrastStylePlugin)
+TDE_EXPORT_PLUGIN (HighContrastStylePlugin)
 // ---------------------------------------------------
 
 
