@@ -173,7 +173,7 @@ void KCharSelectTable::paintCell( class TQPainter* p, int row, int col )
     }
 
     if ( c == focusItem.unicode() && hasFocus() ) {
-	style().tqdrawPrimitive( TQStyle::PE_FocusRect, p, TQRect( 2, 2, w - 4, h - 4 ), 
+	style().drawPrimitive( TQStyle::PE_FocusRect, p, TQRect( 2, 2, w - 4, h - 4 ), 
 			       colorGroup() );
 	focusPos = TQPoint( col, row );
     }
@@ -382,32 +382,32 @@ KCharSelect::KCharSelect( TQWidget *parent, const char *name, const TQString &_f
 
     TQLabel* const lFont = new TQLabel( i18n( "Font:" ), bar );
     lFont->resize( lFont->sizeHint() );
-    lFont->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+    lFont->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
     lFont->setMaximumWidth( lFont->sizeHint().width() );
 
     fontCombo = new TQComboBox( true, bar );
     fillFontCombo();
     fontCombo->resize( fontCombo->sizeHint() );
 
-    connect( fontCombo, TQT_SIGNAL( activated( const TQString & ) ), this, TQT_SLOT( fontSelected( const TQString & ) ) );
+    connect( fontCombo, TQ_SIGNAL( activated( const TQString & ) ), this, TQ_SLOT( fontSelected( const TQString & ) ) );
 
     TQLabel* const lTable = new TQLabel( i18n( "Table:" ), bar );
     lTable->resize( lTable->sizeHint() );
-    lTable->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+    lTable->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
     lTable->setMaximumWidth( lTable->sizeHint().width() );
 
     tableSpinBox = new TQSpinBox( 0, 255, 1, bar );
     tableSpinBox->resize( tableSpinBox->sizeHint() );
 
-    connect( tableSpinBox, TQT_SIGNAL( valueChanged( int ) ), this, TQT_SLOT( tableChanged( int ) ) );
+    connect( tableSpinBox, TQ_SIGNAL( valueChanged( int ) ), this, TQ_SLOT( tableChanged( int ) ) );
 
     TQLabel* const lUnicode = new TQLabel( i18n( "&Unicode code point:" ), bar );
     lUnicode->resize( lUnicode->sizeHint() );
-    lUnicode->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+    lUnicode->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
     lUnicode->setMaximumWidth( lUnicode->sizeHint().width() );
 
     const TQRegExp rx( "[a-fA-F0-9]{1,4}" );
-    TQValidator* const validator = new TQRegExpValidator( rx, TQT_TQOBJECT(this) );
+    TQValidator* const validator = new TQRegExpValidator( rx, this );
 
     d->unicodeLine = new KLineEdit( bar );
     d->unicodeLine->setValidator(validator);
@@ -415,7 +415,7 @@ KCharSelect::KCharSelect( TQWidget *parent, const char *name, const TQString &_f
     d->unicodeLine->resize( d->unicodeLine->sizeHint() );
     slotUpdateUnicode(_chr);
 
-    connect( d->unicodeLine, TQT_SIGNAL( returnPressed() ), this, TQT_SLOT( slotUnicodeEntered() ) );
+    connect( d->unicodeLine, TQ_SIGNAL( returnPressed() ), this, TQ_SLOT( slotUnicodeEntered() ) );
 
     charTable = new KCharSelectTable( this, name, _font.isEmpty() ? TQString(TQVBox::font().family()) : _font, _chr, _tableNum );
     const TQSize sz( charTable->contentsWidth()  +  4 ,
@@ -429,18 +429,18 @@ KCharSelect::KCharSelect( TQWidget *parent, const char *name, const TQString &_f
     setFont( _font.isEmpty() ? TQString(TQVBox::font().family()) : _font );
     setTableNum( _tableNum );
 
-    connect( charTable, TQT_SIGNAL( highlighted( const TQChar & ) ), this, TQT_SLOT( slotUpdateUnicode( const TQChar & ) ) );
-    connect( charTable, TQT_SIGNAL( highlighted( const TQChar & ) ), this, TQT_SLOT( charHighlighted( const TQChar & ) ) );
-    connect( charTable, TQT_SIGNAL( highlighted() ), this, TQT_SLOT( charHighlighted() ) );
-    connect( charTable, TQT_SIGNAL( activated( const TQChar & ) ), this, TQT_SLOT( charActivated( const TQChar & ) ) );
-    connect( charTable, TQT_SIGNAL( activated() ), this, TQT_SLOT( charActivated() ) );
-    connect( charTable, TQT_SIGNAL( focusItemChanged( const TQChar & ) ),
-	     this, TQT_SLOT( charFocusItemChanged( const TQChar & ) ) );
-    connect( charTable, TQT_SIGNAL( focusItemChanged() ), this, TQT_SLOT( charFocusItemChanged() ) );
-    connect( charTable, TQT_SIGNAL( tableUp() ), this, TQT_SLOT( charTableUp() ) );
-    connect( charTable, TQT_SIGNAL( tableDown() ), this, TQT_SLOT( charTableDown() ) );
+    connect( charTable, TQ_SIGNAL( highlighted( const TQChar & ) ), this, TQ_SLOT( slotUpdateUnicode( const TQChar & ) ) );
+    connect( charTable, TQ_SIGNAL( highlighted( const TQChar & ) ), this, TQ_SLOT( charHighlighted( const TQChar & ) ) );
+    connect( charTable, TQ_SIGNAL( highlighted() ), this, TQ_SLOT( charHighlighted() ) );
+    connect( charTable, TQ_SIGNAL( activated( const TQChar & ) ), this, TQ_SLOT( charActivated( const TQChar & ) ) );
+    connect( charTable, TQ_SIGNAL( activated() ), this, TQ_SLOT( charActivated() ) );
+    connect( charTable, TQ_SIGNAL( focusItemChanged( const TQChar & ) ),
+	     this, TQ_SLOT( charFocusItemChanged( const TQChar & ) ) );
+    connect( charTable, TQ_SIGNAL( focusItemChanged() ), this, TQ_SLOT( charFocusItemChanged() ) );
+    connect( charTable, TQ_SIGNAL( tableUp() ), this, TQ_SLOT( charTableUp() ) );
+    connect( charTable, TQ_SIGNAL( tableDown() ), this, TQ_SLOT( charTableDown() ) );
 
-    connect( charTable, TQT_SIGNAL(doubleClicked()),this,TQT_SLOT(slotDoubleClicked()));
+    connect( charTable, TQ_SIGNAL(doubleClicked()),this,TQ_SLOT(slotDoubleClicked()));
 
     setFocusPolicy( TQWidget::StrongFocus );
     setFocusProxy( charTable );
