@@ -187,17 +187,17 @@ void KDatePicker::init( const TQDate &dt )
       monthForward->setIconSet(BarIconSet(TQString::fromLatin1("1rightarrow")));
       monthBackward->setIconSet(BarIconSet(TQString::fromLatin1("1leftarrow")));
   }
-  connect(table, TQT_SIGNAL(dateChanged(TQDate)), TQT_SLOT(dateChangedSlot(TQDate)));
-  connect(table, TQT_SIGNAL(tableClicked()), TQT_SLOT(tableClickedSlot()));
-  connect(monthForward, TQT_SIGNAL(clicked()), TQT_SLOT(monthForwardClicked()));
-  connect(monthBackward, TQT_SIGNAL(clicked()), TQT_SLOT(monthBackwardClicked()));
-  connect(yearForward, TQT_SIGNAL(clicked()), TQT_SLOT(yearForwardClicked()));
-  connect(yearBackward, TQT_SIGNAL(clicked()), TQT_SLOT(yearBackwardClicked()));
-  connect(d->selectWeek, TQT_SIGNAL(activated(int)), TQT_SLOT(weekSelected(int)));
-  connect(d->todayButton, TQT_SIGNAL(clicked()), TQT_SLOT(todayButtonClicked()));
-  connect(selectMonth, TQT_SIGNAL(clicked()), TQT_SLOT(selectMonthClicked()));
-  connect(selectYear, TQT_SIGNAL(toggled(bool)), TQT_SLOT(selectYearClicked()));
-  connect(line, TQT_SIGNAL(returnPressed()), TQT_SLOT(lineEnterPressed()));
+  connect(table, TQ_SIGNAL(dateChanged(TQDate)), TQ_SLOT(dateChangedSlot(TQDate)));
+  connect(table, TQ_SIGNAL(tableClicked()), TQ_SLOT(tableClickedSlot()));
+  connect(monthForward, TQ_SIGNAL(clicked()), TQ_SLOT(monthForwardClicked()));
+  connect(monthBackward, TQ_SIGNAL(clicked()), TQ_SLOT(monthBackwardClicked()));
+  connect(yearForward, TQ_SIGNAL(clicked()), TQ_SLOT(yearForwardClicked()));
+  connect(yearBackward, TQ_SIGNAL(clicked()), TQ_SLOT(yearBackwardClicked()));
+  connect(d->selectWeek, TQ_SIGNAL(activated(int)), TQ_SLOT(weekSelected(int)));
+  connect(d->todayButton, TQ_SIGNAL(clicked()), TQ_SLOT(todayButtonClicked()));
+  connect(selectMonth, TQ_SIGNAL(clicked()), TQ_SLOT(selectMonthClicked()));
+  connect(selectYear, TQ_SIGNAL(toggled(bool)), TQ_SLOT(selectYearClicked()));
+  connect(line, TQ_SIGNAL(returnPressed()), TQ_SLOT(lineEnterPressed()));
   table->setFocus();
 
 
@@ -225,8 +225,8 @@ KDatePicker::eventFilter(TQObject *o, TQEvent *e )
 
       if ( (k->key() == TQt::Key_Prior) ||
            (k->key() == TQt::Key_Next)  ||
-           (k->key() == Qt::Key_Up)    ||
-           (k->key() == Qt::Key_Down) )
+           (k->key() == TQt::Key_Up)    ||
+           (k->key() == TQt::Key_Down) )
        {
           TQApplication::sendEvent( table, e );
           table->setFocus();
@@ -394,7 +394,7 @@ KDatePicker::selectYearClicked()
   picker->setYear( table->getDate().year() );
   picker->selectAll();
   popup->setMainWidget(picker);
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   picker->setFocus();
   if(popup->exec(selectYear->mapToGlobal(TQPoint(0, selectMonth->height()))))
     {
@@ -416,7 +416,7 @@ KDatePicker::selectYearClicked()
     }
 
   delete popup;
-  TQTimer::singleShot(0, this, TQT_SLOT(ensureSelectYearIsUp()));
+  TQTimer::singleShot(0, this, TQ_SLOT(ensureSelectYearIsUp()));
 }
 
 void
@@ -507,7 +507,7 @@ KDatePicker::setFontSize(int s)
       maxMonthRect.setHeight(TQMAX(r.height(),  maxMonthRect.height()));
     }
 
-  TQSize metricBound = style().tqsizeFromContents(TQStyle::CT_ToolButton,
+  TQSize metricBound = style().sizeFromContents(TQStyle::CT_ToolButton,
                                                selectMonth,
                                                maxMonthRect);
   selectMonth->setMinimumSize(metricBound);
@@ -528,8 +528,8 @@ KDatePicker::setCloseButton( bool enable )
         d->navigationLayout->addWidget(d->closeButton);
         TQToolTip::add(d->closeButton, i18n("Close"));
         d->closeButton->setPixmap( SmallIcon("remove") );
-        connect( d->closeButton, TQT_SIGNAL( clicked() ),
-                 topLevelWidget(), TQT_SLOT( close() ) );
+        connect( d->closeButton, TQ_SIGNAL( clicked() ),
+                 topLevelWidget(), TQ_SLOT( close() ) );
     }
     else {
         delete d->closeButton;
