@@ -56,7 +56,7 @@ public:
    * @param orient orientation. Either @p Vertical or @p Horizontal
    * @param pos procentual position of the splitter. Must be int [0...100].
    */
-  KDockSplitter(TQWidget *parent= 0, const char *name= 0, Orientation orient= Qt::Vertical, int pos= 50);
+  KDockSplitter(TQWidget *parent= 0, const char *name= 0, Orientation orient= TQt::Vertical, int pos= 50);
   virtual ~KDockSplitter(){}
 
   /**
