@@ -67,8 +67,8 @@ KEdit::KEdit(TQWidget *_parent, const char *name)
     setAcceptDrops(true);
     KCursor::setAutoHideCursor( this, true );
 
-    connect(this, TQT_SIGNAL(cursorPositionChanged(int,int)),
-            this, TQT_SLOT(slotCursorPositionChanged()));
+    connect(this, TQ_SIGNAL(cursorPositionChanged(int,int)),
+            this, TQ_SLOT(slotCursorPositionChanged()));
 }
 
 
