@@ -105,10 +105,10 @@ void KEditListBox::init( bool checkAtEntering, int buttons,
     d->buttons = 0;
     setButtons( buttons );
 
-    connect(m_lineEdit,TQT_SIGNAL(textChanged(const TQString&)),this,TQT_SLOT(typedSomething(const TQString&)));
+    connect(m_lineEdit,TQ_SIGNAL(textChanged(const TQString&)),this,TQ_SLOT(typedSomething(const TQString&)));
     m_lineEdit->setTrapReturnKey(true);
-    connect(m_lineEdit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(addItem()));
-    connect(m_listBox, TQT_SIGNAL(highlighted(int)), TQT_SLOT(enableMoveButtons(int)));
+    connect(m_lineEdit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(addItem()));
+    connect(m_listBox, TQ_SIGNAL(highlighted(int)), TQ_SLOT(enableMoveButtons(int)));
 
     // maybe supplied lineedit has some text already
     typedSomething( m_lineEdit->text() );
@@ -124,7 +124,7 @@ void KEditListBox::setButtons( uint buttons )
         servNewButton = new TQPushButton(i18n("&Add"), this);
         servNewButton->setEnabled(false);
         servNewButton->show();
-        connect(servNewButton, TQT_SIGNAL(clicked()), TQT_SLOT(addItem()));
+        connect(servNewButton, TQ_SIGNAL(clicked()), TQ_SLOT(addItem()));
 
         grid->addWidget(servNewButton, 2, 1);
     } else if ( ( buttons & Add ) == 0 && servNewButton ) {
@@ -136,7 +136,7 @@ void KEditListBox::setButtons( uint buttons )
         servRemoveButton = new TQPushButton(i18n("&Remove"), this);
         servRemoveButton->setEnabled(false);
         servRemoveButton->show();
-        connect(servRemoveButton, TQT_SIGNAL(clicked()), TQT_SLOT(removeItem()));
+        connect(servRemoveButton, TQ_SIGNAL(clicked()), TQ_SLOT(removeItem()));
 
         grid->addWidget(servRemoveButton, 3, 1);
     } else if ( ( buttons & Remove ) == 0 && servRemoveButton ) {
@@ -148,12 +148,12 @@ void KEditListBox::setButtons( uint buttons )
         servUpButton = new TQPushButton(i18n("Move &Up"), this);
         servUpButton->setEnabled(false);
         servUpButton->show();
-        connect(servUpButton, TQT_SIGNAL(clicked()), TQT_SLOT(moveItemUp()));
+        connect(servUpButton, TQ_SIGNAL(clicked()), TQ_SLOT(moveItemUp()));
 
         servDownButton = new TQPushButton(i18n("Move &Down"), this);
         servDownButton->setEnabled(false);
         servDownButton->show();
-        connect(servDownButton, TQT_SIGNAL(clicked()), TQT_SLOT(moveItemDown()));
+        connect(servDownButton, TQ_SIGNAL(clicked()), TQ_SLOT(moveItemDown()));
 
         grid->addWidget(servUpButton, 4, 1);
         grid->addWidget(servDownButton, 5, 1);
@@ -418,7 +418,7 @@ void KEditListBox::virtual_hook( int, void* )
 KEditListBox::CustomEditor::CustomEditor( KComboBox *combo )
 {
     m_representationWidget = combo;
-    m_lineEdit = tqt_dynamic_cast<KLineEdit*>( combo->lineEdit() );
+    m_lineEdit = dynamic_cast<KLineEdit*>( combo->lineEdit() );
     assert( m_lineEdit );
 }
 
