@@ -230,12 +230,12 @@ void KPasswordDialog::init()
 	lbl->setPixmap(pix);
 	lbl->setAlignment(AlignHCenter|AlignVCenter);
 	lbl->setFixedSize(lbl->sizeHint());
-	m_pGrid->addWidget(lbl, 0, 0, (Qt::AlignmentFlags)AlignCenter);
+	m_pGrid->addWidget(lbl, 0, 0, TQt::AlignCenter);
     }
 
     m_pHelpLbl = new TQLabel(m_pMain);
     m_pHelpLbl->setAlignment(AlignLeft|AlignVCenter|WordBreak);
-    m_pGrid->addWidget(m_pHelpLbl, 0, 2, (Qt::AlignmentFlags)AlignLeft);
+    m_pGrid->addWidget(m_pHelpLbl, 0, 2, TQt::AlignLeft);
     m_pGrid->addRowSpacing(1, 10);
     m_pGrid->setRowStretch(1, 12);
 
@@ -248,7 +248,7 @@ void KPasswordDialog::init()
     lbl->setAlignment(AlignLeft|AlignVCenter);
     lbl->setText(i18n("&Password:"));
     lbl->setFixedSize(lbl->sizeHint());
-    m_pGrid->addWidget(lbl, 7, 0, (Qt::AlignmentFlags)AlignLeft);
+    m_pGrid->addWidget(lbl, 7, 0, TQt::AlignLeft);
 
     TQHBoxLayout *h_lay = new TQHBoxLayout();
     m_pGrid->addLayout(h_lay, 7, 2);
@@ -277,9 +277,9 @@ void KPasswordDialog::init()
 	    m_Keep = 0;
 	    m_keepWarnLbl->hide();
 	}
-	connect(cb, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotKeep(bool)));
-	m_pGrid->addWidget(cb, 9, 2, (Qt::AlignmentFlags)(AlignLeft|AlignVCenter));
-//	m_pGrid->addWidget(m_keepWarnLbl, 13, 2, (Qt::AlignmentFlags)(AlignLeft|AlignVCenter));
+	connect(cb, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotKeep(bool)));
+	m_pGrid->addWidget(cb, 9, 2, TQt::AlignLeft|TQt::AlignVCenter);
+//	m_pGrid->addWidget(m_keepWarnLbl, 13, 2, TQt::AlignLeft|TQt::AlignVCenter);
 	m_pGrid->addMultiCellWidget(m_keepWarnLbl, 13, 13, 0, 3);
     } else if (m_Type == NewPassword) {
 	m_pGrid->addRowSpacing(8, 10);
@@ -287,7 +287,7 @@ void KPasswordDialog::init()
 	lbl->setAlignment(AlignLeft|AlignVCenter);
 	lbl->setText(i18n("&Verify:"));
 	lbl->setFixedSize(lbl->sizeHint());
-	m_pGrid->addWidget(lbl, 9, 0, (Qt::AlignmentFlags)AlignLeft);
+	m_pGrid->addWidget(lbl, 9, 0, TQt::AlignLeft);
 
 	h_lay = new TQHBoxLayout();
 	m_pGrid->addLayout(h_lay, 9, 2);
@@ -330,8 +330,8 @@ void KPasswordDialog::init()
         d->m_MatchLabel->setText(i18n("Passwords do not match"));
 
 
-        connect( m_pEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(enableOkBtn()) );
-        connect( m_pEdit2, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(enableOkBtn()) );
+        connect( m_pEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(enableOkBtn()) );
+        connect( m_pEdit2, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(enableOkBtn()) );
         enableOkBtn();
     }
 
@@ -381,12 +381,12 @@ void KPasswordDialog::addLine(TQString key, TQString value)
     TQLabel *lbl = new TQLabel(key, m_pMain);
     lbl->setAlignment(AlignLeft|AlignTop);
     lbl->setFixedSize(lbl->sizeHint());
-    m_pGrid->addWidget(lbl, m_Row+2, 0, (Qt::AlignmentFlags)AlignLeft);
+    m_pGrid->addWidget(lbl, m_Row+2, 0, TQt::AlignLeft);
 
     lbl = new TQLabel(value, m_pMain);
     lbl->setAlignment(AlignTop|WordBreak);
     lbl->setFixedSize(275, lbl->heightForWidth(275));
-    m_pGrid->addWidget(lbl, m_Row+2, 2, (Qt::AlignmentFlags)AlignLeft);
+    m_pGrid->addWidget(lbl, m_Row+2, 2, TQt::AlignLeft);
     ++m_Row;
 }
 
@@ -446,7 +446,7 @@ void KPasswordDialog::slotKeep(bool keep)
         else {
             m_keepWarnLbl->hide();
         }
-        TQTimer::singleShot(0, this, SLOT(slotLayout()));
+        TQTimer::singleShot(0, this, TQ_SLOT(slotLayout()));
     }
 
     m_Keep = keep;
