@@ -20,7 +20,7 @@
 #include <tqwindowdefs.h>
 #include <tqwidget.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 
 #include <tdeapplication.h>
 #include <krootprop.h>
