@@ -117,7 +117,7 @@ TQWidget *KXMLGUIBuilder::createContainer( TQWidget *parent, int index, const TQ
   if ( element.tagName().lower() == d->tagMainWindow )
   {
     TDEMainWindow *mainwindow = 0;
-    if ( ::tqqt_cast<TDEMainWindow *>( d->m_widget ) )
+    if ( ::tqt_cast<TDEMainWindow *>( d->m_widget ) )
       mainwindow = static_cast<TDEMainWindow *>(d->m_widget);
 
     return mainwindow;
@@ -127,7 +127,7 @@ TQWidget *KXMLGUIBuilder::createContainer( TQWidget *parent, int index, const TQ
   {
     KMenuBar *bar;
 
-    if ( ::tqqt_cast<TDEMainWindow *>( d->m_widget ) )
+    if ( ::tqt_cast<TDEMainWindow *>( d->m_widget ) )
       bar = static_cast<TDEMainWindow *>(d->m_widget)->menuBar();
     else
       bar = new KMenuBar( d->m_widget );
@@ -145,7 +145,7 @@ TQWidget *KXMLGUIBuilder::createContainer( TQWidget *parent, int index, const TQ
     // And we don't want to set the parent for a standalone popupmenu,
     // otherwise its shortcuts appear.
     TQWidget* p = parent;
-    while ( p && !::tqqt_cast<TDEMainWindow *>( p ) )
+    while ( p && !::tqt_cast<TDEMainWindow *>( p ) )
         p = p->parentWidget();
 
     TQCString name = element.attribute( d->attrName ).utf8();
@@ -181,14 +181,14 @@ TQWidget *KXMLGUIBuilder::createContainer( TQWidget *parent, int index, const TQ
       pix = SmallIconSet( icon, 16, instance );
     }
 
-    if ( parent && ::tqqt_cast<KMenuBar *>( parent ) )
+    if ( parent && ::tqt_cast<KMenuBar *>( parent ) )
     {
       if ( !icon.isEmpty() )
         id = static_cast<KMenuBar *>(parent)->insertItem( pix, i18nText, popup, -1, index );
       else
         id = static_cast<KMenuBar *>(parent)->insertItem( i18nText, popup, -1, index );
     }
-    else if ( parent && ::tqqt_cast<TQPopupMenu *>( parent ) )
+    else if ( parent && ::tqt_cast<TQPopupMenu *>( parent ) )
     {
       if ( !icon.isEmpty() )
         id = static_cast<TQPopupMenu *>(parent)->insertItem( pix, i18nText, popup, -1, index );
@@ -205,13 +205,13 @@ TQWidget *KXMLGUIBuilder::createContainer( TQWidget *parent, int index, const TQ
 
     TQCString name = element.attribute( d->attrName ).utf8();
 
-    TDEToolBar *bar = static_cast<TDEToolBar*>(TQT_TQWIDGET(d->m_widget->child( name, "TDEToolBar" )));
+    TDEToolBar *bar = static_cast<TDEToolBar*>(d->m_widget->child( name, "TDEToolBar" ));
     if( !bar )
     {
        bar = new TDEToolBar( d->m_widget, name, honor, false );
     }
 
-    if ( ::tqqt_cast<TDEMainWindow *>( d->m_widget ) )
+    if ( ::tqt_cast<TDEMainWindow *>( d->m_widget ) )
     {
         if ( d->m_client && !d->m_client->xmlFile().isEmpty() )
             bar->setXMLGUIClient( d->m_client );
@@ -224,7 +224,7 @@ TQWidget *KXMLGUIBuilder::createContainer( TQWidget *parent, int index, const TQ
 
   if ( element.tagName().lower() == d->tagStatusBar )
   {
-      if ( ::tqqt_cast<TDEMainWindow *>( d->m_widget ) )
+      if ( ::tqt_cast<TDEMainWindow *>( d->m_widget ) )
     {
       TDEMainWindow *mainWin = static_cast<TDEMainWindow *>(d->m_widget);
       mainWin->statusBar()->show();
@@ -241,26 +241,26 @@ void KXMLGUIBuilder::removeContainer( TQWidget *container, TQWidget *parent, TQD
 {
   // Warning parent can be 0L
 
-  if ( ::tqqt_cast<TQPopupMenu *>( container ) )
+  if ( ::tqt_cast<TQPopupMenu *>( container ) )
   {
     if ( parent )
     {
-        if ( ::tqqt_cast<KMenuBar *>( parent ) )
+        if ( ::tqt_cast<KMenuBar *>( parent ) )
             static_cast<KMenuBar *>(parent)->removeItem( id );
-        else if ( ::tqqt_cast<TQPopupMenu *>( parent ) )
+        else if ( ::tqt_cast<TQPopupMenu *>( parent ) )
             static_cast<TQPopupMenu *>(parent)->removeItem( id );
     }
 
     delete container;
   }
-  else if ( ::tqqt_cast<TDEToolBar *>( container ) )
+  else if ( ::tqt_cast<TDEToolBar *>( container ) )
   {
     TDEToolBar *tb = static_cast<TDEToolBar *>( container );
 
     tb->saveState( element );
     delete tb;
   }
-  else if ( ::tqqt_cast<KMenuBar *>( container ) )
+  else if ( ::tqt_cast<KMenuBar *>( container ) )
   {
     KMenuBar *mb = static_cast<KMenuBar *>( container );
     mb->hide();
@@ -269,9 +269,9 @@ void KXMLGUIBuilder::removeContainer( TQWidget *container, TQWidget *parent, TQD
     // sure that TQMainWindow::d->mb does not point to a deleted
     // menubar object.
   }
-  else if ( ::tqqt_cast<KStatusBar *>( container ) )
+  else if ( ::tqt_cast<KStatusBar *>( container ) )
   {
-    if ( ::tqqt_cast<TDEMainWindow *>( d->m_widget ) )
+    if ( ::tqt_cast<TDEMainWindow *>( d->m_widget ) )
         container->hide();
     else
       delete static_cast<KStatusBar *>(container);
@@ -291,7 +291,7 @@ int KXMLGUIBuilder::createCustomElement( TQWidget *parent, int index, const TQDo
 {
   if ( element.tagName().lower() == d->tagSeparator )
   {
-    if ( ::tqqt_cast<TQPopupMenu *>( parent ) )
+    if ( ::tqt_cast<TQPopupMenu *>( parent ) )
     {
       // Don't insert multiple separators in a row
       TQPopupMenu *menu = static_cast<TQPopupMenu *>(parent);
@@ -317,9 +317,9 @@ int KXMLGUIBuilder::createCustomElement( TQWidget *parent, int index, const TQDo
       else
         return menu->insertSeparator( index );
     }
-    else if ( ::tqqt_cast<TQMenuBar *>( parent ) )
+    else if ( ::tqt_cast<TQMenuBar *>( parent ) )
        return static_cast<TQMenuBar *>(parent)->insertSeparator( index );
-    else if ( ::tqqt_cast<TDEToolBar *>( parent ) )
+    else if ( ::tqt_cast<TDEToolBar *>( parent ) )
     {
       TDEToolBar *bar = static_cast<TDEToolBar *>( parent );
 
@@ -351,12 +351,12 @@ int KXMLGUIBuilder::createCustomElement( TQWidget *parent, int index, const TQDo
   }
   else if ( element.tagName().lower() == d->tagTearOffHandle )
   {
-    if ( ::tqqt_cast<TQPopupMenu *>( parent )  && TDEGlobalSettings::insertTearOffHandle())
+    if ( ::tqt_cast<TQPopupMenu *>( parent )  && TDEGlobalSettings::insertTearOffHandle())
       return static_cast<TQPopupMenu *>(parent)->insertTearOffHandle( -1, index );
   }
   else if ( element.tagName().lower() == d->tagMenuTitle )
   {
-    if ( ::tqqt_cast<TDEPopupMenu *>( parent ) )
+    if ( ::tqt_cast<TDEPopupMenu *>( parent ) )
     {
       TQString i18nText;
       TQCString text = element.text().utf8();
@@ -389,11 +389,11 @@ int KXMLGUIBuilder::createCustomElement( TQWidget *parent, int index, const TQDo
 
 void KXMLGUIBuilder::removeCustomElement( TQWidget *parent, int id )
 {
-  if ( ::tqqt_cast<TQPopupMenu *>( parent ) )
+  if ( ::tqt_cast<TQPopupMenu *>( parent ) )
     static_cast<TQPopupMenu *>(parent)->removeItem( id );
-  else if ( ::tqqt_cast<TQMenuBar *>( parent ) )
+  else if ( ::tqt_cast<TQMenuBar *>( parent ) )
     static_cast<TQMenuBar *>(parent)->removeItem( id );
-  else if ( ::tqqt_cast<TDEToolBar *>( parent ) )
+  else if ( ::tqt_cast<TDEToolBar *>( parent ) )
     static_cast<TDEToolBar *>(parent)->removeItemDelayed( id );
 }
 
@@ -421,7 +421,7 @@ void KXMLGUIBuilder::setBuilderInstance( TDEInstance *instance )
 
 void KXMLGUIBuilder::finalizeGUI( KXMLGUIClient * )
 {
-    if ( !d->m_widget || !::tqqt_cast<TDEMainWindow *>( d->m_widget ) )
+    if ( !d->m_widget || !::tqt_cast<TDEMainWindow *>( d->m_widget ) )
         return;
 #if 0
     TDEToolBar *toolbar = 0;
