@@ -34,7 +34,7 @@
 
 #include <tdeaction.h>
 #include <kdebug.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeglobal.h>
 #include <tdeshortcut.h>
 #include <kstandarddirs.h>
@@ -552,7 +552,7 @@ void KXMLGUIFactory::configureAction( TDEAction *action, const TQDomAttr &attrib
 
 int KXMLGUIFactory::configureShortcuts(bool bAllowLetterShortcuts , bool bSaveSettings )
 {
-	KKeyDialog dlg( bAllowLetterShortcuts, tqt_dynamic_cast<TQWidget*>(parent()) );
+	KKeyDialog dlg( bAllowLetterShortcuts, dynamic_cast<TQWidget*>(parent()) );
 	TQPtrListIterator<KXMLGUIClient> it( d->m_clients );
 	KXMLGUIClient *client;
 	while( (client=it.current()) !=0 )
