@@ -96,15 +96,15 @@ TDEAboutContributor::TDEAboutContributor( TQWidget *_parent, const char *wname,
   kurl->setFloat(true);
   kurl->setUnderline(true);
   kurl->setMargin(0);
-  connect(kurl, TQT_SIGNAL(leftClickedURL(const TQString &)),
-	  TQT_SLOT(emailClickedSlot(const TQString &)));
+  connect(kurl, TQ_SIGNAL(leftClickedURL(const TQString &)),
+	  TQ_SLOT(emailClickedSlot(const TQString &)));
 
   kurl = static_cast<KURLLabel *>(mText[2]);
   kurl->setFloat(true);
   kurl->setUnderline(true);
   kurl->setMargin(0);
-  connect(kurl, TQT_SIGNAL(leftClickedURL(const TQString &)),
-	  TQT_SLOT(urlClickedSlot(const TQString &)));
+  connect(kurl, TQ_SIGNAL(leftClickedURL(const TQString &)),
+	  TQ_SLOT(urlClickedSlot(const TQString &)));
 
   mLabel[3]->setAlignment( AlignTop );
 
@@ -227,8 +227,8 @@ void TDEAboutContributor::updateLayout( void )
       {
 	if( mShowHeader )
 	{
-	  gbox->addWidget( TQT_TQWIDGET(mLabel[i]), r, 0, (TQ_Alignment)AlignLeft );
-	  gbox->addWidget( TQT_TQWIDGET(mText[i]), r, 1, (TQ_Alignment)AlignLeft  );
+	  gbox->addWidget( mLabel[i], r, 0, (TQt::AlignmentFlags)AlignLeft );
+	  gbox->addWidget( mText[i], r, 1, (TQt::AlignmentFlags)AlignLeft  );
 	  mLabel[i]->show();
 	  mText[i]->show();
 	}
@@ -237,11 +237,11 @@ void TDEAboutContributor::updateLayout( void )
 	  mLabel[i]->hide();
 	  if( !i )
 	  {
-	    gbox->addMultiCellWidget( TQT_TQWIDGET(mText[i]), r, r, 0, 1, (TQ_Alignment)AlignLeft );
+	    gbox->addMultiCellWidget( mText[i], r, r, 0, 1, (TQt::AlignmentFlags)AlignLeft );
 	  }
 	  else
 	  {
-	    gbox->addWidget( TQT_TQWIDGET(mText[i]), r, 1, (TQ_Alignment)AlignLeft  );
+	    gbox->addWidget( mText[i], r, 1, (TQt::AlignmentFlags)AlignLeft  );
 	  }
 	  mText[i]->show();
 	}
@@ -359,8 +359,8 @@ TDEAboutContainerBase::TDEAboutContainerBase( int layoutType, TQWidget *_parent,
 
     vbox = new TQVBoxLayout( mImageFrame, 1 );
     mImageLabel = new KImageTrackLabel( mImageFrame );
-    connect( mImageLabel, TQT_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
-	     TQT_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
+    connect( mImageLabel, TQ_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
+	     TQ_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
     vbox->addStretch(10);
     vbox->addWidget( mImageLabel );
     vbox->addStretch(10);
@@ -386,8 +386,8 @@ TDEAboutContainerBase::TDEAboutContainerBase( int layoutType, TQWidget *_parent,
     gbox->setColStretch( 2, 10 );
 
     mImageLabel = new KImageTrackLabel( mImageFrame );
-    connect( mImageLabel, TQT_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
-	     TQT_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
+    connect( mImageLabel, TQ_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
+	     TQ_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
     gbox->addWidget( mImageLabel, 1, 1 );
     gbox->activate();
   }
@@ -410,8 +410,8 @@ TDEAboutContainerBase::TDEAboutContainerBase( int layoutType, TQWidget *_parent,
 
     vbox = new TQVBoxLayout( mImageFrame, 1 );
     mImageLabel = new KImageTrackLabel( mImageFrame );
-    connect( mImageLabel, TQT_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
-	     TQT_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
+    connect( mImageLabel, TQ_SIGNAL(mouseTrack( int, const TQMouseEvent * )),
+	     TQ_SLOT( slotMouseTrack( int, const TQMouseEvent * )) );
     vbox->addStretch(10);
     vbox->addWidget( mImageLabel );
     vbox->addStretch(10);
@@ -475,10 +475,10 @@ TQFrame *TDEAboutContainerBase::addTextPage( const TQString &title,
     browser->setMinimumHeight( fontMetrics().lineSpacing()*numLines );
 
     vbox->addWidget(browser);
-    connect(browser, TQT_SIGNAL(urlClick(const TQString &)),
-	    TQT_SLOT(slotUrlClick(const TQString &)));
-    connect(browser, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-	    TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+    connect(browser, TQ_SIGNAL(urlClick(const TQString &)),
+	    TQ_SLOT(slotUrlClick(const TQString &)));
+    connect(browser, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+	    TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
   }
   else
   {
@@ -527,10 +527,10 @@ TDEAboutContainer *TDEAboutContainerBase::addContainerPage( const TQString &titl
 						  innerAlignment );
   mPageTab->addTab( container, title );
 
-  connect(container, TQT_SIGNAL(urlClick(const TQString &)),
-	  TQT_SLOT(slotUrlClick(const TQString &)));
-  connect(container, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-	  TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+  connect(container, TQ_SIGNAL(urlClick(const TQString &)),
+	  TQ_SLOT(slotUrlClick(const TQString &)));
+  connect(container, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+	  TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
 
   return container;
 }
@@ -559,10 +559,10 @@ TDEAboutContainer *TDEAboutContainerBase::addScrolledContainerPage(
   scrollView->addChild( container );
 
 
-  connect(container, TQT_SIGNAL(urlClick(const TQString &)),
-	  TQT_SLOT(slotUrlClick(const TQString &)));
-  connect(container, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-	  TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+  connect(container, TQ_SIGNAL(urlClick(const TQString &)),
+	  TQ_SLOT(slotUrlClick(const TQString &)));
+  connect(container, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+	  TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
 
   return container;
 }
@@ -591,10 +591,10 @@ TDEAboutContainer *TDEAboutContainerBase::addContainer( int childAlignment,
     0, KDialog::spacingHint(), childAlignment, innerAlignment );
   mTopLayout->addWidget( container, 0, childAlignment );
 
-  connect(container, TQT_SIGNAL(urlClick(const TQString &)),
-	  TQT_SLOT(slotUrlClick(const TQString &)));
-  connect(container, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-	  TQT_SLOT(slotMailClick(const TQString &,const TQString &)));
+  connect(container, TQ_SIGNAL(urlClick(const TQString &)),
+	  TQ_SLOT(slotUrlClick(const TQString &)));
+  connect(container, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+	  TQ_SLOT(slotMailClick(const TQString &,const TQString &)));
 
   return container;
 }
@@ -800,7 +800,7 @@ void TDEAboutContainer::childEvent( TQChildEvent *e )
     ++itr;
     if( o->isWidgetType() )
     {
-        TQT_TQWIDGET(o)->setMinimumWidth( s.width() );
+        static_cast<TQWidget*>(o)->setMinimumWidth( s.width() );
     }
   }
 }
@@ -826,7 +826,7 @@ TQSize TDEAboutContainer::sizeHint( void ) const
     if( o->isWidgetType() )
     {
       ++numChild;
-      TQWidget* const w= TQT_TQWIDGET(o);
+      TQWidget* const w= static_cast<TQWidget*>(o);
 
       TQSize s = w->minimumSize();
       if( s.isEmpty() )
@@ -883,10 +883,10 @@ void TDEAboutContainer::addPerson( const TQString &_name, const TQString &_email
 
   TDEAboutContributor* const cont = new TDEAboutContributor( this, "pers",
     _name, _email, _url, _task, showHeader, showFrame, showBold );
-  connect( cont, TQT_SIGNAL( openURL(const TQString&)),
-	   this, TQT_SIGNAL( urlClick(const TQString &)));
-  connect( cont, TQT_SIGNAL( sendEmail(const TQString &, const TQString &)),
-	   this, TQT_SIGNAL( mailClick(const TQString &, const TQString &)));
+  connect( cont, TQ_SIGNAL( openURL(const TQString&)),
+	   this, TQ_SIGNAL( urlClick(const TQString &)));
+  connect( cont, TQ_SIGNAL( sendEmail(const TQString &, const TQString &)),
+	   this, TQ_SIGNAL( mailClick(const TQString &, const TQString &)));
 }
 
 
@@ -938,7 +938,7 @@ void TDEAboutContainer::addImage( const TQString &fileName, int alignment )
 class TDEAboutContributor : public QFrame
 {
   // ############################################################################
-  Q_OBJECT
+  TQ_OBJECT
   // ----------------------------------------------------------------------------
 public:
   /** The Qt constructor. */
@@ -1011,10 +1011,10 @@ TDEAboutContributor::TDEAboutContributor(TQWidget* parent, const char* n)
     }
   setFrameStyle(TQFrame::Panel | TQFrame::Raised);
   // -----
-  connect(email, TQT_SIGNAL(leftClickedURL(const TQString&)),
-	  TQT_SLOT(emailClickedSlot(const TQString&)));
-  connect(url, TQT_SIGNAL(leftClickedURL(const TQString&)),
-	  TQT_SLOT(urlClickedSlot(const TQString&)));
+  connect(email, TQ_SIGNAL(leftClickedURL(const TQString&)),
+	  TQ_SLOT(emailClickedSlot(const TQString&)));
+  connect(url, TQ_SIGNAL(leftClickedURL(const TQString&)),
+	  TQ_SLOT(urlClickedSlot(const TQString&)));
   // ############################################################
 }
 
@@ -1026,7 +1026,7 @@ TDEAboutContributor::setName(const TQString& n)
   // ############################################################
 }
 
-QString
+TQString
 TDEAboutContributor::getName()
 {
   // ###########################################################
@@ -1041,7 +1041,7 @@ TDEAboutContributor::setURL(const TQString& u)
   // ###########################################################
 }
 
-QString
+TQString
 TDEAboutContributor::getURL()
 {
   // ###########################################################
@@ -1057,7 +1057,7 @@ TDEAboutContributor::setEmail(const TQString& e)
   // ###########################################################
 }
 
-QString
+TQString
 TDEAboutContributor::getEmail()
 {
   // ###########################################################
@@ -1328,14 +1328,14 @@ TDEAboutWidget::TDEAboutWidget(TQWidget *_parent, const char *_name)
   logo->setFrameStyle(TQFrame::Panel | TQFrame::Raised);
   version->setAlignment(AlignCenter);
   // -----
-  connect(author, TQT_SIGNAL(sendEmail(const TQString&, const TQString&)),
-	  TQT_SLOT(sendEmailSlot(const TQString&, const TQString&)));
-  connect(author, TQT_SIGNAL(openURL(const TQString&)),
-	  TQT_SLOT(openURLSlot(const TQString&)));
-  connect(maintainer, TQT_SIGNAL(sendEmail(const TQString&, const TQString&)),
-	  TQT_SLOT(sendEmailSlot(const TQString&, const TQString&)));
-  connect(maintainer, TQT_SIGNAL(openURL(const TQString&)),
-	  TQT_SLOT(openURLSlot(const TQString&)));
+  connect(author, TQ_SIGNAL(sendEmail(const TQString&, const TQString&)),
+	  TQ_SLOT(sendEmailSlot(const TQString&, const TQString&)));
+  connect(author, TQ_SIGNAL(openURL(const TQString&)),
+	  TQ_SLOT(openURLSlot(const TQString&)));
+  connect(maintainer, TQ_SIGNAL(sendEmail(const TQString&, const TQString&)),
+	  TQ_SLOT(sendEmailSlot(const TQString&, const TQString&)));
+  connect(maintainer, TQ_SIGNAL(openURL(const TQString&)),
+	  TQ_SLOT(openURLSlot(const TQString&)));
   // #################################################################
 }
 
@@ -1439,9 +1439,9 @@ TDEAboutWidget::addContributor(const TQString &_name, const TQString &_email,
   c->setURL(_url);
   c->setWork(_w);
   contributors.append(c);
-  connect(c, TQT_SIGNAL(sendEmail(const TQString&, const TQString&)),
-	  TQT_SLOT(sendEmailSlot(const TQString&, const TQString&)));
-  connect(c, TQT_SIGNAL(openURL(const TQString&)), TQT_SLOT(openURLSlot(const TQString&)));
+  connect(c, TQ_SIGNAL(sendEmail(const TQString&, const TQString&)),
+	  TQ_SLOT(sendEmailSlot(const TQString&, const TQString&)));
+  connect(c, TQ_SIGNAL(openURL(const TQString&)), TQ_SLOT(openURLSlot(const TQString&)));
   // ############################################################################
 }
 
@@ -1515,10 +1515,10 @@ TDEAboutDialog::TDEAboutDialog(TQWidget *_parent, const char *_name, bool modal)
     tqApp->quit();
   }
   setMainWidget(about);
-  connect(about, TQT_SIGNAL(sendEmail(const TQString&, const TQString&)),
-	  TQT_SLOT(sendEmailSlot(const TQString&, const TQString&)));
-  connect(about, TQT_SIGNAL(openURL(const TQString&)),
-	  TQT_SLOT(openURLSlot(const TQString&)));
+  connect(about, TQ_SIGNAL(sendEmail(const TQString&, const TQString&)),
+	  TQ_SLOT(sendEmailSlot(const TQString&, const TQString&)));
+  connect(about, TQ_SIGNAL(openURL(const TQString&)),
+	  TQ_SLOT(openURLSlot(const TQString&)));
   // #################################################################
 }
 
@@ -1537,12 +1537,12 @@ TDEAboutDialog::TDEAboutDialog( int layoutType, const TQString &_caption,
   mContainerBase = new TDEAboutContainerBase( layoutType, this );
   setMainWidget(mContainerBase);
 
-  connect( mContainerBase, TQT_SIGNAL(urlClick(const TQString &)),
-	   this, TQT_SLOT(openURLSlot(const TQString &)));
-  connect( mContainerBase, TQT_SIGNAL(mailClick(const TQString &,const TQString &)),
-	   this, TQT_SLOT(sendEmailSlot(const TQString &,const TQString &)));
-  connect( mContainerBase, TQT_SIGNAL(mouseTrack(int, const TQMouseEvent *)),
-	   this, TQT_SLOT(mouseTrackSlot(int, const TQMouseEvent *)));
+  connect( mContainerBase, TQ_SIGNAL(urlClick(const TQString &)),
+	   this, TQ_SLOT(openURLSlot(const TQString &)));
+  connect( mContainerBase, TQ_SIGNAL(mailClick(const TQString &,const TQString &)),
+	   this, TQ_SLOT(sendEmailSlot(const TQString &,const TQString &)));
+  connect( mContainerBase, TQ_SIGNAL(mouseTrack(int, const TQMouseEvent *)),
+	   this, TQ_SLOT(mouseTrackSlot(int, const TQMouseEvent *)));
 }
 
 
