@@ -137,7 +137,7 @@ TDEToggleAction::~TDEToggleAction()
 
 int TDEToggleAction::plug( TQWidget* widget, int index )
 {
-  if ( !::tqqt_cast<TQPopupMenu *>( widget ) && !::tqqt_cast<TDEToolBar *>( widget ) )
+  if ( !::tqt_cast<TQPopupMenu *>( widget ) && !::tqt_cast<TDEToolBar *>( widget ) )
   {
     kdWarning() << "Can not plug TDEToggleAction in " << widget->className() << endl;
     return -1;
@@ -149,7 +149,7 @@ int TDEToggleAction::plug( TQWidget* widget, int index )
   if ( _index == -1 )
     return _index;
 
-  if ( ::tqqt_cast<TDEToolBar *>( widget ) ) {
+  if ( ::tqt_cast<TDEToolBar *>( widget ) ) {
     TDEToolBar *bar = static_cast<TDEToolBar *>( widget );
 
     bar->setToggle( itemId( _index ), true );
@@ -180,7 +180,7 @@ void TDEToggleAction::setChecked( bool c )
     if ( !list.isEmpty() ) {
       TQObjectListIt it( list );
       for( ; it.current(); ++it ) {
-          if ( ::tqqt_cast<TDEToggleAction *>( it.current() ) && it.current() != this &&
+          if ( ::tqt_cast<TDEToggleAction *>( it.current() ) && it.current() != this &&
             static_cast<TDEToggleAction*>(it.current())->exclusiveGroup() == exclusiveGroup() ) {
 	  TDEToggleAction *a = static_cast<TDEToggleAction*>(it.current());
 	  if( a->isChecked() ) {
@@ -197,7 +197,7 @@ void TDEToggleAction::updateChecked( int id )
 {
   TQWidget *w = container( id );
 
-  if ( ::tqqt_cast<TQPopupMenu *>( w ) ) {
+  if ( ::tqt_cast<TQPopupMenu *>( w ) ) {
     TQPopupMenu* pm = static_cast<TQPopupMenu*>(w);
     int itemId_ = itemId( id );
     if ( !d->m_checkedGuiItem )
@@ -219,12 +219,12 @@ void TDEToggleAction::updateChecked( int id )
       updateShortcut( pm, itemId_ );
     }
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( w ) ) // not handled in plug...
+  else if ( ::tqt_cast<TQMenuBar *>( w ) ) // not handled in plug...
     static_cast<TQMenuBar*>(w)->setItemChecked( itemId( id ), d->m_checked );
-  else if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  else if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
     TQWidget* r = static_cast<TDEToolBar*>( w )->getButton( itemId( id ) );
-    if ( r && ::tqqt_cast<TDEToolBarButton *>( r ) ) {
+    if ( r && ::tqt_cast<TDEToolBarButton *>( r ) ) {
       static_cast<TDEToolBar*>( w )->setButton( itemId( id ), d->m_checked );
       if ( d->m_checkedGuiItem && d->m_checkedGuiItem->hasIcon() ) {
         const KGuiItem* gui = d->m_checked ? d->m_checkedGuiItem : &guiItem();
@@ -324,7 +324,7 @@ void TDERadioAction::slotActivated()
   {
     const TQObject *senderObj = sender();
 
-    if ( !senderObj || !::tqqt_cast<const TDEToolBarButton *>( senderObj ) )
+    if ( !senderObj || !::tqt_cast<const TDEToolBarButton *>( senderObj ) )
       return;
 
     const_cast<TDEToolBarButton *>( static_cast<const TDEToolBarButton *>( senderObj ) )->on( true );
@@ -507,7 +507,7 @@ void TDESelectAction::setupMenu() const
     for( uint id = 0; it != d->m_list.end(); ++it, ++id ) {
         TQString text = *it;
         if ( !text.isEmpty() )
-            d->m_menu->insertItem( d->makeMenuText( text ), this, TQT_SLOT( slotActivated( int ) ), 0, id );
+            d->m_menu->insertItem( d->makeMenuText( text ), this, TQ_SLOT( slotActivated( int ) ), 0, id );
         else
             d->m_menu->insertSeparator();
     }
@@ -537,10 +537,10 @@ void TDESelectAction::changeItem( int id, int index, const TQString& text)
         return;
 
   TQWidget* w = container( id );
-  if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
      TQWidget* r = (static_cast<TDEToolBar*>( w ))->getWidget( itemId( id ) );
-     if ( ::tqqt_cast<TQComboBox *>( r ) )
+     if ( ::tqt_cast<TQComboBox *>( r ) )
      {
         TQComboBox *b = static_cast<TQComboBox*>( r );
         b->changeItem(text, index );
@@ -587,9 +587,9 @@ void TDESelectAction::updateCurrentItem( int id )
         return;
 
   TQWidget* w = container( id );
-  if ( ::tqqt_cast<TDEToolBar *>( w ) ) {
+  if ( ::tqt_cast<TDEToolBar *>( w ) ) {
     TQWidget* r = static_cast<TDEToolBar*>( w )->getWidget( itemId( id ) );
-    if ( ::tqqt_cast<TQComboBox *>( r ) ) {
+    if ( ::tqt_cast<TQComboBox *>( r ) ) {
       TQComboBox *b = static_cast<TQComboBox*>( r );
       b->setCurrentItem( d->m_current );
     }
@@ -604,9 +604,9 @@ int TDESelectAction::comboWidth() const
 void TDESelectAction::updateComboWidth( int id )
 {
   TQWidget* w = container( id );
-  if ( ::tqqt_cast<TDEToolBar *>( w ) ) {
+  if ( ::tqt_cast<TDEToolBar *>( w ) ) {
     TQWidget* r = static_cast<TDEToolBar*>( w )->getWidget( itemId( id ) );
-    if ( ::tqqt_cast<TQComboBox *>( r ) ) {
+    if ( ::tqt_cast<TQComboBox *>( r ) ) {
       TQComboBox *cb = static_cast<TQComboBox*>( r );
       cb->setMinimumWidth( d->m_comboWidth );
       cb->setMaximumWidth( d->m_comboWidth );
@@ -618,9 +618,9 @@ void TDESelectAction::updateItems( int id )
 {
   kdDebug(129) << "TDEAction::updateItems( " << id << ", lst )" << endl; // remove -- ellis
   TQWidget* w = container( id );
-  if ( ::tqqt_cast<TDEToolBar *>( w ) ) {
+  if ( ::tqt_cast<TDEToolBar *>( w ) ) {
     TQWidget* r = static_cast<TDEToolBar*>( w )->getWidget( itemId( id ) );
-    if ( ::tqqt_cast<TQComboBox *>( r ) ) {
+    if ( ::tqt_cast<TQComboBox *>( r ) ) {
       TQComboBox *cb = static_cast<TQComboBox*>( r );
       cb->clear();
       TQStringList lst = comboItems();
@@ -641,7 +641,7 @@ int TDESelectAction::plug( TQWidget *widget, int index )
   if (kapp && !kapp->authorizeTDEAction(name()))
     return -1;
   kdDebug(129) << "TDESelectAction::plug( " << widget << ", " << index << " )" << endl; // remove -- ellis
-  if ( ::tqqt_cast<TQPopupMenu *>( widget) )
+  if ( ::tqt_cast<TQPopupMenu *>( widget) )
   {
     // Create the PopupMenu and store it in m_menu
     (void)popupMenu();
@@ -661,17 +661,17 @@ int TDESelectAction::plug( TQWidget *widget, int index )
         menu->TQMenuData::setWhatsThis( id, wth );
 
     addContainer( menu, id );
-    connect( menu, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( menu, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     return containerCount() - 1;
   }
-  else if ( ::tqqt_cast<TDEToolBar *>( widget ) )
+  else if ( ::tqt_cast<TDEToolBar *>( widget ) )
   {
     TDEToolBar* bar = static_cast<TDEToolBar*>( widget );
     int id_ = TDEAction::getToolButtonID();
     bar->insertCombo( comboItems(), id_, isEditable(),
-                      TQT_SIGNAL( activated( const TQString & ) ), this,
-                      TQT_SLOT( slotActivated( const TQString & ) ), isEnabled(),
+                      TQ_SIGNAL( activated( const TQString & ) ), this,
+                      TQ_SLOT( slotActivated( const TQString & ) ), isEnabled(),
                       toolTip(), -1, index );
 
     TQComboBox *cb = bar->getCombo( id_ );
@@ -691,13 +691,13 @@ int TDESelectAction::plug( TQWidget *widget, int index )
 
     addContainer( bar, id_ );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     updateCurrentItem( containerCount() - 1 );
 
     return containerCount() - 1;
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( widget ) )
+  else if ( ::tqt_cast<TQMenuBar *>( widget ) )
   {
     // Create the PopupMenu and store it in m_menu
     (void)popupMenu();
@@ -713,7 +713,7 @@ int TDESelectAction::plug( TQWidget *widget, int index )
         menu->TQMenuData::setWhatsThis( id, wth );
 
     addContainer( menu, id );
-    connect( menu, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( menu, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     return containerCount() - 1;
   }
@@ -754,9 +754,9 @@ void TDESelectAction::clear()
 void TDESelectAction::updateClear( int id )
 {
   TQWidget* w = container( id );
-  if ( ::tqqt_cast<TDEToolBar *>( w ) ) {
+  if ( ::tqt_cast<TDEToolBar *>( w ) ) {
     TQWidget* r = static_cast<TDEToolBar*>( w )->getWidget( itemId( id ) );
-    if ( ::tqqt_cast<TQComboBox *>( r ) ) {
+    if ( ::tqt_cast<TQComboBox *>( r ) ) {
       TQComboBox *b = static_cast<TQComboBox*>( r );
       b->clear();
     }
@@ -771,7 +771,7 @@ void TDESelectAction::slotActivated( int id )
   setCurrentItem( id );
   // Delay this. Especially useful when the slot connected to activated() will re-create
   // the menu, e.g. in the recent files action. This prevents a crash.
-  TQTimer::singleShot( 0, this, TQT_SLOT( slotActivated() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( slotActivated() ) );
 }
 
 void TDESelectAction::slotActivated( const TQString &text )
@@ -793,7 +793,7 @@ void TDESelectAction::slotActivated( const TQString &text )
       setCurrentItem( comboItems().findIndex( text ) );
   // Delay this. Especially useful when the slot connected to activated() will re-create
   // the menu, e.g. in the recent files action. This prevents a crash.
-  TQTimer::singleShot( 0, this, TQT_SLOT( slotActivated() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( slotActivated() ) );
 }
 
 void TDESelectAction::slotActivated()
@@ -858,7 +858,7 @@ TDEListAction::TDEListAction( const TQString& text, const TDEShortcut& cut,
 {
   d = new TDEListActionPrivate;
   if ( receiver )
-    connect( this, TQT_SIGNAL( activated( int ) ), receiver, slot );
+    connect( this, TQ_SIGNAL( activated( int ) ), receiver, slot );
 }
 
 TDEListAction::TDEListAction( const TQString& text, const TQIconSet& pix,
@@ -885,7 +885,7 @@ TDEListAction::TDEListAction( const TQString& text, const TQIconSet& pix,
 {
   d = new TDEListActionPrivate;
   if ( receiver )
-    connect( this, TQT_SIGNAL( activated( int ) ), receiver, slot );
+    connect( this, TQ_SIGNAL( activated( int ) ), receiver, slot );
 }
 
 TDEListAction::TDEListAction( const TQString& text, const TQString& pix,
@@ -896,7 +896,7 @@ TDEListAction::TDEListAction( const TQString& text, const TQString& pix,
 {
   d = new TDEListActionPrivate;
   if ( receiver )
-    connect( this, TQT_SIGNAL( activated( int ) ), receiver, slot );
+    connect( this, TQ_SIGNAL( activated( int ) ), receiver, slot );
 }
 
 TDEListAction::TDEListAction( TQObject* parent, const char* name )
@@ -970,7 +970,7 @@ TDERecentFilesAction::TDERecentFilesAction( const TQString& text,
   init();
 
   if ( receiver )
-    connect( this,     TQT_SIGNAL(urlSelected(const KURL&)),
+    connect( this,     TQ_SIGNAL(urlSelected(const KURL&)),
              receiver, slot );
 }
 
@@ -1015,7 +1015,7 @@ TDERecentFilesAction::TDERecentFilesAction( const TQString& text,
   init();
 
   if ( receiver )
-    connect( this,     TQT_SIGNAL(urlSelected(const KURL&)),
+    connect( this,     TQ_SIGNAL(urlSelected(const KURL&)),
              receiver, slot );
 }
 
@@ -1034,7 +1034,7 @@ TDERecentFilesAction::TDERecentFilesAction( const TQString& text,
   init();
 
   if ( receiver )
-    connect( this,     TQT_SIGNAL(urlSelected(const KURL&)),
+    connect( this,     TQ_SIGNAL(urlSelected(const KURL&)),
              receiver, slot );
 }
 
@@ -1052,10 +1052,10 @@ void TDERecentFilesAction::init()
 {
   TDERecentFilesAction *that = const_cast<TDERecentFilesAction*>(this);
   that->d->m_popup = new TDEPopupMenu;
-  connect(d->m_popup, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(menuAboutToShow()));
-  connect(d->m_popup, TQT_SIGNAL(activated(int)), this, TQT_SLOT(menuItemActivated(int)));
-  connect( this, TQT_SIGNAL( activated( const TQString& ) ),
-           this, TQT_SLOT( itemSelected( const TQString& ) ) );
+  connect(d->m_popup, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(menuAboutToShow()));
+  connect(d->m_popup, TQ_SIGNAL(activated(int)), this, TQ_SLOT(menuItemActivated(int)));
+  connect( this, TQ_SIGNAL( activated( const TQString& ) ),
+           this, TQ_SLOT( itemSelected( const TQString& ) ) );
 
   setMenuAccelsEnabled( false );
 }
@@ -1272,7 +1272,7 @@ int TDERecentFilesAction::plug( TQWidget *widget, int index )
     return -1;
   // This is very related to TDEActionMenu::plug.
   // In fact this class could be an interesting base class for TDEActionMenu
-  if ( ::tqqt_cast<TDEToolBar *>( widget ) )
+  if ( ::tqt_cast<TDEToolBar *>( widget ) )
   {
     TDEToolBar *bar = (TDEToolBar *)widget;
 
@@ -1284,13 +1284,13 @@ int TDERecentFilesAction::plug( TQWidget *widget, int index )
     else
         instance = TDEGlobal::instance();
 
-    bar->insertButton( icon(), id_, TQT_SIGNAL( clicked() ), this,
-                       TQT_SLOT( slotClicked() ), isEnabled(), plainText(),
+    bar->insertButton( icon(), id_, TQ_SIGNAL( clicked() ), this,
+                       TQ_SLOT( slotClicked() ), isEnabled(), plainText(),
                        index, instance );
 
     addContainer( bar, id_ );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     bar->setDelayedPopup( id_, d->m_popup, true);
 
@@ -1526,20 +1526,20 @@ int TDEFontAction::plug( TQWidget *w, int index )
 {
   if (kapp && !kapp->authorizeTDEAction(name()))
     return -1;
-  if ( ::tqqt_cast<TDEToolBar *>( w ) )
+  if ( ::tqt_cast<TDEToolBar *>( w ) )
   {
     TDEToolBar* bar = static_cast<TDEToolBar*>( w );
     int id_ = TDEAction::getToolButtonID();
     TDEFontCombo *cb = new TDEFontCombo( items(), bar );
-    connect( cb, TQT_SIGNAL( activated( const TQString & ) ),
-             TQT_SLOT( slotActivated( const TQString & ) ) );
+    connect( cb, TQ_SIGNAL( activated( const TQString & ) ),
+             TQ_SLOT( slotActivated( const TQString & ) ) );
     cb->setEnabled( isEnabled() );
     bar->insertWidget( id_, comboWidth(), cb, index );
     cb->setMinimumWidth( cb->sizeHint().width() );
 
     addContainer( bar, id_ );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     updateCurrentItem( containerCount() - 1 );
 
@@ -1796,7 +1796,7 @@ int TDEActionMenu::plug( TQWidget* widget, int index )
   if (kapp && !kapp->authorizeTDEAction(name()))
     return -1;
   kdDebug(129) << "TDEActionMenu::plug( " << widget << ", " << index << " )" << endl; // remove -- ellis
-  if ( ::tqqt_cast<TQPopupMenu *>( widget ) )
+  if ( ::tqt_cast<TQPopupMenu *>( widget ) )
   {
     TQPopupMenu* menu = static_cast<TQPopupMenu*>( widget );
     int id;
@@ -1809,22 +1809,22 @@ int TDEActionMenu::plug( TQWidget* widget, int index )
       menu->setItemEnabled( id, false );
 
     addContainer( menu, id );
-    connect( menu, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( menu, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     if ( m_parentCollection )
       m_parentCollection->connectHighlight( menu, this );
 
     return containerCount() - 1;
   }
-  else if ( ::tqqt_cast<TDEToolBar *>( widget ) )
+  else if ( ::tqt_cast<TDEToolBar *>( widget ) )
   {
     TDEToolBar *bar = static_cast<TDEToolBar *>( widget );
 
     int id_ = TDEAction::getToolButtonID();
 
     if ( icon().isEmpty() && !iconSet().isNull() )
-      bar->insertButton( iconSet().pixmap(), id_, TQT_SIGNAL( clicked() ), this,
-                         TQT_SLOT( slotActivated() ), isEnabled(), plainText(),
+      bar->insertButton( iconSet().pixmap(), id_, TQ_SIGNAL( clicked() ), this,
+                         TQ_SLOT( slotActivated() ), isEnabled(), plainText(),
                          index );
     else
     {
@@ -1835,8 +1835,8 @@ int TDEActionMenu::plug( TQWidget* widget, int index )
       else
         instance = TDEGlobal::instance();
 
-      bar->insertButton( icon(), id_, TQT_SIGNAL( clicked() ), this,
-                         TQT_SLOT( slotActivated() ), isEnabled(), plainText(),
+      bar->insertButton( icon(), id_, TQ_SIGNAL( clicked() ), this,
+                         TQ_SLOT( slotActivated() ), isEnabled(), plainText(),
                          index, instance );
     }
 
@@ -1845,7 +1845,7 @@ int TDEActionMenu::plug( TQWidget* widget, int index )
     if (!whatsThis().isEmpty())
       TQWhatsThis::add( bar->getButton(id_), whatsThis() );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     if (delayed()) {
         bar->setDelayedPopup( id_, popupMenu(), stickyMenu() );
@@ -1858,7 +1858,7 @@ int TDEActionMenu::plug( TQWidget* widget, int index )
 
     return containerCount() - 1;
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( widget ) )
+  else if ( ::tqt_cast<TQMenuBar *>( widget ) )
   {
     TQMenuBar *bar = static_cast<TQMenuBar *>( widget );
 
@@ -1870,7 +1870,7 @@ int TDEActionMenu::plug( TQWidget* widget, int index )
         bar->setItemEnabled( id, false );
 
     addContainer( bar, id );
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     return containerCount() - 1;
   }
@@ -1943,15 +1943,15 @@ int TDEToolBarPopupAction::plug( TQWidget *widget, int index )
     return -1;
   // This is very related to TDEActionMenu::plug.
   // In fact this class could be an interesting base class for TDEActionMenu
-  if ( ::tqqt_cast<TDEToolBar *>( widget ) )
+  if ( ::tqt_cast<TDEToolBar *>( widget ) )
   {
     TDEToolBar *bar = (TDEToolBar *)widget;
 
     int id_ = TDEAction::getToolButtonID();
 
     if ( icon().isEmpty() && !iconSet().isNull() ) {
-        bar->insertButton( iconSet().pixmap(), id_, TQT_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
-                           TQT_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
+        bar->insertButton( iconSet().pixmap(), id_, TQ_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
+                           TQ_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
                            isEnabled(), plainText(),
                            index );
     } else {
@@ -1961,15 +1961,15 @@ int TDEToolBarPopupAction::plug( TQWidget *widget, int index )
         else
             instance = TDEGlobal::instance();
 
-        bar->insertButton( icon(), id_, TQT_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
-                           TQT_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
+        bar->insertButton( icon(), id_, TQ_SIGNAL( buttonClicked(int, TQt::ButtonState) ), this,
+                           TQ_SLOT( slotButtonClicked(int, TQt::ButtonState) ),
                            isEnabled(), plainText(),
                            index, instance );
     }
 
     addContainer( bar, id_ );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     if (delayed()) {
         bar->setDelayedPopup( id_, popupMenu(), stickyMenu() );
@@ -2028,7 +2028,7 @@ int TDEToggleToolBarAction::plug( TQWidget* w, int index )
     while ( !tl->isDialog() && ( n = tl->parentWidget() ) ) // lookup parent and store
       tl = n;
 
-    TDEMainWindow * mw = tqt_dynamic_cast<TDEMainWindow *>(tl); // try to see if it's a tdemainwindow
+    TDEMainWindow * mw = dynamic_cast<TDEMainWindow *>(tl); // try to see if it's a tdemainwindow
 
     if ( mw )
         m_toolBar = mw->toolBar( m_toolBarName );
@@ -2036,9 +2036,9 @@ int TDEToggleToolBarAction::plug( TQWidget* w, int index )
 
   if( m_toolBar ) {
     setChecked( m_toolBar->isVisible() );
-    connect( m_toolBar, TQT_SIGNAL(visibilityChanged(bool)), this, TQT_SLOT(setChecked(bool)) );
+    connect( m_toolBar, TQ_SIGNAL(visibilityChanged(bool)), this, TQ_SLOT(setChecked(bool)) );
     // Also emit toggled when the toolbar's visibility changes (see comment in header)
-    connect( m_toolBar, TQT_SIGNAL(visibilityChanged(bool)), this, TQT_SIGNAL(toggled(bool)) );
+    connect( m_toolBar, TQ_SIGNAL(visibilityChanged(bool)), this, TQ_SIGNAL(toggled(bool)) );
   } else {
     setEnabled( false );
   }
@@ -2055,7 +2055,7 @@ void TDEToggleToolBarAction::setChecked( bool c )
       m_toolBar->hide();
     }
     TQMainWindow* mw = m_toolBar->mainWindow();
-    if ( mw && ::tqqt_cast<TDEMainWindow *>( mw ) )
+    if ( mw && ::tqt_cast<TDEMainWindow *>( mw ) )
       static_cast<TDEMainWindow *>( mw )->setSettingsDirty();
   }
   TDEToggleAction::setChecked( c );
@@ -2122,7 +2122,7 @@ KWidgetAction::KWidgetAction( TQWidget* widget,
   , m_widget( widget )
   , m_autoSized( false )
 {
-  connect( this, TQT_SIGNAL(enabled(bool)), widget, TQT_SLOT(setEnabled(bool)) );
+  connect( this, TQ_SIGNAL(enabled(bool)), widget, TQ_SLOT(setEnabled(bool)) );
 }
 
 KWidgetAction::~KWidgetAction()
@@ -2153,7 +2153,7 @@ int KWidgetAction::plug( TQWidget* w, int index )
   if (kapp && !kapp->authorizeTDEAction(name()))
       return -1;
 
-  if ( !::tqqt_cast<TDEToolBar *>( w ) ) {
+  if ( !::tqt_cast<TDEToolBar *>( w ) ) {
     kdError() << "KWidgetAction::plug: KWidgetAction must be plugged into TDEToolBar." << endl;
     return -1;
   }
@@ -2173,8 +2173,8 @@ int KWidgetAction::plug( TQWidget* w, int index )
   TQWhatsThis::add( m_widget, whatsThis() );
   addContainer( toolBar, id );
 
-  connect( toolBar, TQT_SIGNAL( toolbarDestroyed() ), this, TQT_SLOT( slotToolbarDestroyed() ) );
-  connect( toolBar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+  connect( toolBar, TQ_SIGNAL( toolbarDestroyed() ), this, TQ_SLOT( slotToolbarDestroyed() ) );
+  connect( toolBar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
   return containerCount() - 1;
 }
@@ -2187,7 +2187,7 @@ void KWidgetAction::unplug( TQWidget *w )
   TDEToolBar* toolBar = (TDEToolBar*)m_widget->parent();
   if ( toolBar == w )
   {
-      disconnect( toolBar, TQT_SIGNAL( toolbarDestroyed() ), this, TQT_SLOT( slotToolbarDestroyed() ) );
+      disconnect( toolBar, TQ_SIGNAL( toolbarDestroyed() ), this, TQ_SLOT( slotToolbarDestroyed() ) );
       m_widget->reparent( 0L, TQPoint(), false /*showIt*/ );
   }
   TDEAction::unplug( w );
@@ -2217,18 +2217,18 @@ TDEActionSeparator::~TDEActionSeparator()
 
 int TDEActionSeparator::plug( TQWidget *widget, int index )
 {
-  if ( ::tqqt_cast<TQPopupMenu *>( widget) )
+  if ( ::tqt_cast<TQPopupMenu *>( widget) )
   {
     TQPopupMenu* menu = static_cast<TQPopupMenu*>( widget );
 
     int id = menu->insertSeparator( index );
 
     addContainer( menu, id );
-    connect( menu, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( menu, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     return containerCount() - 1;
   }
-  else if ( ::tqqt_cast<TQMenuBar *>( widget ) )
+  else if ( ::tqt_cast<TQMenuBar *>( widget ) )
   {
     TQMenuBar *menuBar = static_cast<TQMenuBar *>( widget );
 
@@ -2236,11 +2236,11 @@ int TDEActionSeparator::plug( TQWidget *widget, int index )
 
     addContainer( menuBar, id );
 
-    connect( menuBar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( menuBar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     return containerCount() - 1;
   }
-  else if ( ::tqqt_cast<TDEToolBar *>( widget ) )
+  else if ( ::tqt_cast<TDEToolBar *>( widget ) )
   {
     TDEToolBar *toolBar = static_cast<TDEToolBar *>( widget );
 
@@ -2248,7 +2248,7 @@ int TDEActionSeparator::plug( TQWidget *widget, int index )
 
     addContainer( toolBar, id );
 
-    connect( toolBar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( toolBar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     return containerCount() - 1;
   }
@@ -2265,8 +2265,8 @@ TDEPasteTextAction::TDEPasteTextAction( const TQString& text,
   : TDEAction( text, icon, cut, receiver, slot, parent, name )
 {
   m_popup = new TDEPopupMenu;
-  connect(m_popup, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(menuAboutToShow()));
-  connect(m_popup, TQT_SIGNAL(activated(int)), this, TQT_SLOT(menuItemActivated(int)));
+  connect(m_popup, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(menuAboutToShow()));
+  connect(m_popup, TQ_SIGNAL(activated(int)), this, TQ_SLOT(menuItemActivated(int)));
   m_popup->setCheckable(true);
   m_mixedMode = true;
 }
@@ -2285,7 +2285,7 @@ int TDEPasteTextAction::plug( TQWidget *widget, int index )
 {
   if (kapp && !kapp->authorizeTDEAction(name()))
     return -1;
-  if ( ::tqqt_cast<TDEToolBar *>( widget ) )
+  if ( ::tqt_cast<TDEToolBar *>( widget ) )
   {
     TDEToolBar *bar = (TDEToolBar *)widget;
 
@@ -2297,13 +2297,13 @@ int TDEPasteTextAction::plug( TQWidget *widget, int index )
     else
         instance = TDEGlobal::instance();
 
-    bar->insertButton( icon(), id_, TQT_SIGNAL( clicked() ), this,
-                       TQT_SLOT( slotActivated() ), isEnabled(), plainText(),
+    bar->insertButton( icon(), id_, TQ_SIGNAL( clicked() ), this,
+                       TQ_SLOT( slotActivated() ), isEnabled(), plainText(),
                        index, instance );
 
     addContainer( bar, id_ );
 
-    connect( bar, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
+    connect( bar, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( slotDestroyed() ) );
 
     bar->setDelayedPopup( id_, m_popup, true );
 
@@ -2357,7 +2357,7 @@ void TDEPasteTextAction::menuItemActivated( int id)
       if (reply.isValid())
         kdDebug(129) << "Clipboard: " << TQString(tqApp->clipboard()->text(TQClipboard::Clipboard)) << endl;
     }
-    TQTimer::singleShot(20, this, TQT_SLOT(slotActivated()));
+    TQTimer::singleShot(20, this, TQ_SLOT(slotActivated()));
 }
 
 void TDEPasteTextAction::slotActivated()
