@@ -49,7 +49,7 @@
 #include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <kstaticdeleter.h>
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
 #include <netwm.h>
 #endif
 
@@ -126,7 +126,7 @@ public:
                     TQApplication::sendEvent( window, &e );
                     canceled = !e.isAccepted();
 		    /* Don't even think_about deleting widgets with
-		     Qt::WDestructiveClose flag set at this point. We
+		     TQt::WDestructiveClose flag set at this point. We
 		     are faking a close event, but we are *not*_
 		     closing the window. The purpose of the faked
 		     close event is to prepare the application so it
@@ -184,7 +184,7 @@ void TDEMainWindow::initTDEMainWindow(const char *name, int cflags)
     mHelpMenu = 0;
     kapp->setTopWidget( this );
     actionCollection()->setWidget( this );
-    connect(kapp, TQT_SIGNAL(shutDown()), this, TQT_SLOT(shuttingDown()));
+    connect(kapp, TQ_SIGNAL(shutDown()), this, TQ_SLOT(shuttingDown()));
     if( !memberList )
         memberList = new TQPtrList<TDEMainWindow>;
 
@@ -290,7 +290,7 @@ void TDEMainWindow::parseGeometry(bool parsewidth)
     assert ( !kapp->geometryArgument().isNull() );
     assert ( d->care_about_geometry );
 
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
     int x, y;
     int w, h;
     int m = XParseGeometry( kapp->geometryArgument().latin1(), &x, &y, (unsigned int*)&w, (unsigned int*)&h);
@@ -340,8 +340,8 @@ TDEPopupMenu* TDEMainWindow::helpMenu( const TQString &aboutAppText, bool showWh
 
         if ( !mHelpMenu )
             return 0;
-        connect( mHelpMenu, TQT_SIGNAL( showAboutApplication() ),
-                 this, TQT_SLOT( showAboutApplication() ) );
+        connect( mHelpMenu, TQ_SIGNAL( showAboutApplication() ),
+                 this, TQ_SLOT( showAboutApplication() ) );
     }
 
     return mHelpMenu->menu();
@@ -351,8 +351,8 @@ TDEPopupMenu* TDEMainWindow::customHelpMenu( bool showWhatsThis )
 {
     if( !mHelpMenu ) {
         mHelpMenu = new KHelpMenu( this, TQString::null, showWhatsThis );
-        connect( mHelpMenu, TQT_SIGNAL( showAboutApplication() ),
-                 this, TQT_SLOT( showAboutApplication() ) );
+        connect( mHelpMenu, TQ_SIGNAL( showAboutApplication() ),
+                 this, TQ_SLOT( showAboutApplication() ) );
     }
 
     return mHelpMenu->menu();
@@ -433,7 +433,7 @@ bool TDEMainWindow::restore( int number, bool show )
 KXMLGUIFactory *TDEMainWindow::guiFactory()
 {
     if ( !factory_ )
-        factory_ = new KXMLGUIFactory( this, TQT_TQOBJECT(this), "guifactory" );
+        factory_ = new KXMLGUIFactory( this, this, "guifactory" );
     return factory_;
 }
 
@@ -441,7 +441,7 @@ int TDEMainWindow::configureToolbars()
 {
     saveMainWindowSettings(TDEGlobal::config());
     KEditToolbar dlg(actionCollection(), xmlFile(), true, this);
-    connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_SLOT(saveNewToolbarConfig()));
+    connect(&dlg, TQ_SIGNAL(newToolbarConfig()), TQ_SLOT(saveNewToolbarConfig()));
     return dlg.exec();
 }
 
@@ -458,7 +458,7 @@ void TDEMainWindow::setupGUI( int options, const TQString & xmlfile ) {
 void TDEMainWindow::setupGUI( TQSize defaultSize, int options, const TQString & xmlfile ) {
     if( options & Keys ){
         KStdAction::keyBindings(guiFactory(),
-                    TQT_SLOT(configureShortcuts()), actionCollection());
+                    TQ_SLOT(configureShortcuts()), actionCollection());
     }
 
     if( (options & StatusBar) && internalStatusBar() ){
@@ -467,8 +467,8 @@ void TDEMainWindow::setupGUI( TQSize defaultSize, int options, const TQString &
 
     if( options & ToolBar ){
         setStandardToolBarMenuEnabled( true );
-        KStdAction::configureToolbars(TQT_TQOBJECT(this),
-                      TQT_SLOT(configureToolbars() ), actionCollection());
+        KStdAction::configureToolbars(this,
+                      TQ_SLOT(configureToolbars() ), actionCollection());
     }
 
     if( options & Create ){
@@ -600,7 +600,7 @@ void TDEMainWindow::setCaption( const TQString &caption, bool modified )
 void TDEMainWindow::setPlainCaption( const TQString &caption )
 {
     TQMainWindow::setCaption( caption );
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
     NETWinInfo info( tqt_xdisplay(), winId(), tqt_xrootwin(), 0 );
     info.setName( caption.utf8().data() );
 #endif
@@ -659,7 +659,7 @@ void TDEMainWindow::closeEvent ( TQCloseEvent *e )
         if ( !no_query_exit && not_withdrawn <= 0 ) { // last window close accepted?
             if ( queryExit() && !kapp->sessionSaving() && !d->shuttingDown ) { // Yes, Quit app?
                 // don't call queryExit() twice
-                disconnect(kapp, TQT_SIGNAL(shutDown()), this, TQT_SLOT(shuttingDown()));
+                disconnect(kapp, TQ_SIGNAL(shutDown()), this, TQ_SLOT(shuttingDown()));
                 d->shuttingDown = true;
                 kapp->deref();             // ...and quit application.
             }  else {
@@ -804,9 +804,9 @@ bool TDEMainWindow::isStandardToolBarMenuEnabled() const
 
 void TDEMainWindow::createStandardStatusBarAction(){
   if(!d->showStatusBarAction){
-    d->showStatusBarAction = KStdAction::showStatusbar(TQT_TQOBJECT(this), TQT_SLOT(setSettingsDirty()), actionCollection());
+    d->showStatusBarAction = KStdAction::showStatusbar(this, TQ_SLOT(setSettingsDirty()), actionCollection());
     KStatusBar *sb = statusBar(); // Creates statusbar if it doesn't exist already.
-    connect(d->showStatusBarAction, TQT_SIGNAL(toggled(bool)), sb, TQT_SLOT(setShown(bool)));
+    connect(d->showStatusBarAction, TQ_SIGNAL(toggled(bool)), sb, TQ_SLOT(setShown(bool)));
     d->showStatusBarAction->setChecked(sb->isHidden());
   }
 }
@@ -913,7 +913,7 @@ void TDEMainWindow::saveWindowSize( TDEConfig * config ) const
   int scnum = TQApplication::desktop()->screenNumber(parentWidget());
   TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
   int w, h;
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
   // save maximalization as desktop size + 1 in that direction
   KWin::WindowInfo info = KWin::windowInfo( winId(), NET::WMState );
   w = info.state() & NET::MaxHoriz ? desk.width() + 1 : width();
@@ -963,7 +963,7 @@ void TDEMainWindow::restoreWindowSize( TDEConfig * config )
             }
         }
         if ( !size.isEmpty() ) {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
             int state = 0;
             if (size.width() > desk.width()) {
                 state = state | NET::MaxHoriz;
@@ -1017,7 +1017,7 @@ void TDEMainWindow::setSettingsDirty()
         if ( !d->settingsTimer )
         {
            d->settingsTimer = new TQTimer( this );
-           connect( d->settingsTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( saveAutoSaveSettings() ) );
+           connect( d->settingsTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( saveAutoSaveSettings() ) );
         }
         d->settingsTimer->start( 500, true );
     }
@@ -1039,10 +1039,10 @@ void TDEMainWindow::setAutoSaveSettings( const TQString & groupName, bool saveWi
     d->autoSaveGroup = groupName;
     d->autoSaveWindowSize = saveWindowSize;
     // Get notified when the user moves a toolbar around
-    disconnect( this, TQT_SIGNAL( dockWindowPositionChanged( TQDockWindow * ) ),
-                this, TQT_SLOT( setSettingsDirty() ) );
-    connect( this, TQT_SIGNAL( dockWindowPositionChanged( TQDockWindow * ) ),
-             this, TQT_SLOT( setSettingsDirty() ) );
+    disconnect( this, TQ_SIGNAL( dockWindowPositionChanged( TQDockWindow * ) ),
+                this, TQ_SLOT( setSettingsDirty() ) );
+    connect( this, TQ_SIGNAL( dockWindowPositionChanged( TQDockWindow * ) ),
+             this, TQ_SLOT( setSettingsDirty() ) );
 
     // Now read the previously saved settings
     applyMainWindowSettings( TDEGlobal::config(), groupName );
@@ -1244,7 +1244,7 @@ TQSize TDEMainWindow::sizeForCentralWidgetSize(TQSize size)
 void TDEMainWindow::setIcon( const TQPixmap& p )
 {
     TQMainWindow::setIcon( p );
-#ifdef Q_WS_X11 
+#ifdef TQ_WS_X11 
     // Qt3 doesn't support _NET_WM_ICON, but TDEApplication::setTopWidget(), which
     // is used by TDEMainWindow, sets it
     KWin::setIcons( winId(), p, TQPixmap());
