@@ -33,7 +33,7 @@ namespace KDEPrivate
 class ToolBarHandler : public TQObject,
                        public KXMLGUIClient
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ToolBarHandler( TDEMainWindow *mainWindow, const char *name = 0 );
     ToolBarHandler( TDEMainWindow *mainWindow, TQObject *parent, const char *name = 0 );
