@@ -6,7 +6,7 @@
 class TQWidget;
 class DockTest : public KDockArea
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   DockTest( TQWidget* parent=0 );
 
