@@ -8,7 +8,7 @@ class KDoubleNumInput;
 
 class TopLevel : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
 
     TopLevel( TQWidget *parent=0, const char *name=0 );
