@@ -6,7 +6,7 @@
 
 class Client : public TQObject, public KXMLGUIClient
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     Client() {}
 
