@@ -5,7 +5,7 @@
 
 class MainWindow : public TDEMainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     MainWindow();
 
