@@ -55,7 +55,7 @@
 #include <tqsplitter.h>
 #include <tqframe.h>
 #include "kplugininfo.h"
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tqptrdict.h>
 #include <tqstringlist.h>
 #include "tdecmoduleproxy.h"
@@ -184,14 +184,14 @@ void KPluginSelectionWidget::init( const TQValueList<KPluginInfo*> & plugininfos
     ( new TQVBoxLayout( this, 0, KDialog::spacingHint() ) )->setAutoAdd( true );
     TDEListView * listview = new TDEListView( this );
     d->tooltip = new KPluginListViewToolTip( listview->viewport(), listview );
-    connect( listview, TQT_SIGNAL( pressed( TQListViewItem * ) ), this,
-            TQT_SLOT( executed( TQListViewItem * ) ) );
-    connect( listview, TQT_SIGNAL( spacePressed( TQListViewItem * ) ), this,
-            TQT_SLOT( executed( TQListViewItem * ) ) );
-    connect( listview, TQT_SIGNAL( returnPressed( TQListViewItem * ) ), this,
-            TQT_SLOT( executed( TQListViewItem * ) ) );
-    connect( listview, TQT_SIGNAL( selectionChanged( TQListViewItem * ) ), this,
-            TQT_SLOT( executed( TQListViewItem * ) ) );
+    connect( listview, TQ_SIGNAL( pressed( TQListViewItem * ) ), this,
+            TQ_SLOT( executed( TQListViewItem * ) ) );
+    connect( listview, TQ_SIGNAL( spacePressed( TQListViewItem * ) ), this,
+            TQ_SLOT( executed( TQListViewItem * ) ) );
+    connect( listview, TQ_SIGNAL( returnPressed( TQListViewItem * ) ), this,
+            TQ_SLOT( executed( TQListViewItem * ) ) );
+    connect( listview, TQ_SIGNAL( selectionChanged( TQListViewItem * ) ), this,
+            TQ_SLOT( executed( TQListViewItem * ) ) );
     listview->setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Preferred );
     listview->setAcceptDrops( false );
     listview->setFullWidth( true );
@@ -246,7 +246,7 @@ TQWidget * KPluginSelectionWidget::insertKCM( TQWidget * parent,
     {
         //FIXME: not very verbose
         TQLabel * label = new TQLabel( i18n( "Error" ), parent );
-        label->setAlignment( Qt::AlignCenter );
+        label->setAlignment( TQt::AlignCenter );
 
         return label;
     }
@@ -256,7 +256,7 @@ TQWidget * KPluginSelectionWidget::insertKCM( TQWidget * parent,
             moduleinfo.service()->property(
                 "X-TDE-ParentComponents" ).toStringList() );
     d->moduleParentComponents.insert( module, parentComponents );
-    connect( module, TQT_SIGNAL( changed( bool ) ), TQT_SLOT( clientChanged( bool ) ) );
+    connect( module, TQ_SIGNAL( changed( bool ) ), TQ_SLOT( clientChanged( bool ) ) );
     return module;
 }
 
@@ -264,7 +264,7 @@ void KPluginSelectionWidget::embeddPluginKCMs( KPluginInfo * plugininfo, bool ch
 {
     //if we have Services for the plugin we should be able to
     //create KCM(s)
-    TQApplication::setOverrideCursor( Qt::WaitCursor );
+    TQApplication::setOverrideCursor( TQt::WaitCursor );
     if( plugininfo->kcmServices().size() > 1 )
     {
         // we need a tabwidget
@@ -523,7 +523,7 @@ KPluginSelector::KPluginSelector( TQWidget * parent, const char * name )
     TQBoxLayout * hbox = new TQHBoxLayout( this, 0, KDialog::spacingHint() );
     hbox->setAutoAdd( true );
 
-    TQSplitter* splitter = new TQSplitter( Qt::Horizontal, this );
+    TQSplitter* splitter = new TQSplitter( TQt::Horizontal, this );
     d->frame = new TQFrame( splitter, "KPluginSelector left frame" );
     d->frame->setFrameStyle( TQFrame::NoFrame );
     ( new TQVBoxLayout( d->frame, 0, KDialog::spacingHint() ) )->setAutoAdd( true );
@@ -536,7 +536,7 @@ KPluginSelector::KPluginSelector( TQWidget * parent, const char * name )
     TQLabel * label = new TQLabel( i18n( "(This plugin is not configurable)" ),
             d->widgetstack );
     ( new TQVBoxLayout( label, 0, KDialog::spacingHint() ) )->setAutoAdd( true );
-    label->setAlignment( Qt::AlignCenter );
+    label->setAlignment( TQt::AlignCenter );
     label->setMinimumSize( 200, 200 );
 
     d->widgetstack->addWidget( label, 1 );
@@ -564,8 +564,8 @@ void KPluginSelector::checkNeedForTabWidget()
                     "KPluginSelector TabWidget" );
             w->reparent( d->tabwidget, TQPoint( 0, 0 ) );
             d->tabwidget->addTab( w, w->catName() );
-            connect( d->tabwidget, TQT_SIGNAL( currentChanged( TQWidget * ) ), w,
-                    TQT_SLOT( tabWidgetChanged( TQWidget * ) ) );
+            connect( d->tabwidget, TQ_SIGNAL( currentChanged( TQWidget * ) ), w,
+                    TQ_SLOT( tabWidgetChanged( TQWidget * ) ) );
         }
     }
 }
@@ -605,16 +605,16 @@ void KPluginSelector::addPluginsInternal( const TQValueList<KPluginInfo*> plugin
         w = new KPluginSelectionWidget( plugininfos, this,
                 d->tabwidget, catname, category, cfgGroup );
         d->tabwidget->addTab( w, catname );
-        connect( d->tabwidget, TQT_SIGNAL( currentChanged( TQWidget * ) ), w,
-                TQT_SLOT( tabWidgetChanged( TQWidget * ) ) );
+        connect( d->tabwidget, TQ_SIGNAL( currentChanged( TQWidget * ) ), w,
+                TQ_SLOT( tabWidgetChanged( TQWidget * ) ) );
     }
     else
         w = new KPluginSelectionWidget( plugininfos, this, d->frame,
                 catname, category, cfgGroup );
     w->setMinimumSize( 200, 200 );
-    connect( w, TQT_SIGNAL( changed( bool ) ), this, TQT_SIGNAL( changed( bool ) ) );
-    connect( w, TQT_SIGNAL( configCommitted( const TQCString & ) ), this,
-            TQT_SIGNAL( configCommitted( const TQCString & ) ) );
+    connect( w, TQ_SIGNAL( changed( bool ) ), this, TQ_SIGNAL( changed( bool ) ) );
+    connect( w, TQ_SIGNAL( configCommitted( const TQCString & ) ), this,
+            TQ_SIGNAL( configCommitted( const TQCString & ) ) );
     d->pswidgets += w;
 }
 
@@ -696,7 +696,7 @@ void KPluginSelector::defaults()
     // tabwidget - defaults() will be called for all of them)
 
     TQWidget * pluginconfig = d->widgetstack->visibleWidget();
-    TDECModuleProxy * kcm = ::tqqt_cast<TDECModuleProxy*>(pluginconfig);
+    TDECModuleProxy * kcm = ::tqt_cast<TDECModuleProxy*>(pluginconfig);
     if( kcm )
     {
         kdDebug( 702 ) << "call TDECModule::defaults() for the plugins KCM"
