@@ -588,14 +588,14 @@ void Dialog::createDialogFromServices()
 
 	if( ! d->staticlistview )
 		d->dlg->addButtonBelowList( i18n( "Select Components..." ), this,
-			TQT_SLOT( configureTree() ) );
+			TQ_SLOT( configureTree() ) );
 
-	connect( d->dlg, TQT_SIGNAL( okClicked() ), Dispatcher::self(),
-		TQT_SLOT( syncConfiguration() ) );
-	connect( d->dlg, TQT_SIGNAL( applyClicked() ), Dispatcher::self(),
-		TQT_SLOT( syncConfiguration() ) );
-	connect( d->dlg, TQT_SIGNAL( configCommitted( const TQCString & ) ),
-		Dispatcher::self(), TQT_SLOT( reparseConfiguration( const TQCString & ) ) );
+	connect( d->dlg, TQ_SIGNAL( okClicked() ), Dispatcher::self(),
+		TQ_SLOT( syncConfiguration() ) );
+	connect( d->dlg, TQ_SIGNAL( applyClicked() ), Dispatcher::self(),
+		TQ_SLOT( syncConfiguration() ) );
+	connect( d->dlg, TQ_SIGNAL( configCommitted( const TQCString & ) ),
+		Dispatcher::self(), TQ_SLOT( reparseConfiguration( const TQCString & ) ) );
 
 	d->pagetree.addToDialog( d->dlg );
 
@@ -609,13 +609,13 @@ void Dialog::configureTree()
 	ComponentsDialog * subdlg = new ComponentsDialog( d->dlg );
 	subdlg->setPluginInfos( d->plugininfomap );
 	subdlg->show();
-	connect( subdlg, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( updateTreeList() ) );
-	connect( subdlg, TQT_SIGNAL( applyClicked() ), this, TQT_SLOT( updateTreeList() ) );
-	connect( subdlg, TQT_SIGNAL( okClicked() ), this,
-			TQT_SIGNAL( pluginSelectionChanged() ) );
-	connect( subdlg, TQT_SIGNAL( applyClicked() ), this,
-			TQT_SIGNAL( pluginSelectionChanged() ) );
-	connect( subdlg, TQT_SIGNAL( finished() ), subdlg, TQT_SLOT( delayedDestruct() ) );
+	connect( subdlg, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( updateTreeList() ) );
+	connect( subdlg, TQ_SIGNAL( applyClicked() ), this, TQ_SLOT( updateTreeList() ) );
+	connect( subdlg, TQ_SIGNAL( okClicked() ), this,
+			TQ_SIGNAL( pluginSelectionChanged() ) );
+	connect( subdlg, TQ_SIGNAL( applyClicked() ), this,
+			TQ_SIGNAL( pluginSelectionChanged() ) );
+	connect( subdlg, TQ_SIGNAL( finished() ), subdlg, TQ_SLOT( delayedDestruct() ) );
 }
 
 void Dialog::updateTreeList()
@@ -638,5 +638,3 @@ void Dialog::updateTreeList()
 } //namespace
 
 #include "dialog.moc"
-
-// vim: sw=4 ts=4 noet
