@@ -155,7 +155,7 @@ TDECModule * TDECModuleProxy::realModule() const
 	if( d->rootMode )
 		return 0;
 
-	TQApplication::setOverrideCursor( Qt::WaitCursor );
+	TQApplication::setOverrideCursor( TQt::WaitCursor );
 	
 	TDECModuleProxy * that = const_cast<TDECModuleProxy*>( this );
 
@@ -185,12 +185,12 @@ TDECModule * TDECModuleProxy::realModule() const
 		d->kcm = TDECModuleLoader::loadModule( moduleInfo(), TDECModuleLoader::Inline, d->withFallback,
 			that, name(), d->args );
 
-		connect( d->kcm, TQT_SIGNAL( changed( bool ) ),
-				TQT_SLOT(moduleChanged(bool)) );
-		connect( d->kcm, TQT_SIGNAL( destroyed() ),
-				TQT_SLOT( moduleDestroyed() ) );
-		connect( d->kcm, TQT_SIGNAL(quickHelpChanged()), 
-				TQT_SIGNAL(quickHelpChanged()));
+		connect( d->kcm, TQ_SIGNAL( changed( bool ) ),
+				TQ_SLOT(moduleChanged(bool)) );
+		connect( d->kcm, TQ_SIGNAL( destroyed() ),
+				TQ_SLOT( moduleDestroyed() ) );
+		connect( d->kcm, TQ_SIGNAL(quickHelpChanged()), 
+				TQ_SIGNAL(quickHelpChanged()));
 		TQWhatsThis::add( that, d->kcm->quickHelp() );
 
 		d->topLayout->addWidget( d->kcm );
@@ -234,8 +234,8 @@ TDECModule * TDECModuleProxy::realModule() const
 		d->dcopClient->attach();
 
 		d->dcopClient->setNotifications( true );
-		connect( d->dcopClient, TQT_SIGNAL( applicationRemoved( const TQCString& )),
-			TQT_SLOT( applicationRemoved( const TQCString& )));
+		connect( d->dcopClient, TQ_SIGNAL( applicationRemoved( const TQCString& )),
+			TQ_SLOT( applicationRemoved( const TQCString& )));
 
 		/* Figure out the name of where the module is already loaded */
 		TQByteArray replyData, data;
@@ -301,7 +301,7 @@ void TDECModuleProxy::runAsRoot()
 	if ( !moduleInfo().needsRootPrivileges() )
 		return;
 
-	TQApplication::setOverrideCursor( Qt::WaitCursor );
+	TQApplication::setOverrideCursor( TQt::WaitCursor );
 
 	delete d->rootProcess;
 	delete d->embedWidget;
@@ -367,7 +367,7 @@ void TDECModuleProxy::runAsRoot()
 		*d->rootProcess << TQString("%1 %2 --embed-proxy %3 --lang %4").arg(locate("exe", "tdecmshell"))
 			.arg(cmd).arg(d->embedWidget->winId()).arg(TDEGlobal::locale()->language());
 
-		connect(d->rootProcess, TQT_SIGNAL(processExited(TDEProcess*)), TQT_SLOT(rootExited()));
+		connect(d->rootProcess, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(rootExited()));
 
 		if ( !d->rootProcess->start( TDEProcess::NotifyOnExit ))
 		{
